_antonyms = {
    "ability": "inability",
    "abnormal": "normal",
    "abolish": "establish",
    "absence": "presence",
    "absent": "present",
    "absolute": "relative",
    "absorbent": "nonabsorbent",
    "abstain": "consume",
    "abstract": "concrete",
    "abundance": "scarcity",
    "abundant": "scarce",
    "accelerate": "decelerate",
    "acceleration": "deceleration",
    "accept": "refuse",
    "acceptable": "unacceptable",
    "acceptance": "rejection",
    "accessible": "inaccessible",
    "accidentally": "deliberately",
    "accuracy": "inaccuracy",
    "accurate": "inaccurate",
    "accustomed": "unaccustomed",
    "acidity": "alkalinity",
    "acknowledged": "unacknowledged",
    "acquaintance": "stranger",
    "act": "refrain",
    "action": "inaction",
    "active": "stative",
    "activity": "inactivity",
    "actual": "potential",
    "acutely": "chronically",
    "adaptable": "unadaptable",
    "add": "subtract",
    "addition": "subtraction",
    "additive": "subtractive",
    "adequacy": "inadequacy",
    "adequate": "inadequate",
    "adhesive": "nonadhesive",
    "adjective": "substantive",
    "admire": "look down on",
    "admissibility": "inadmissibility",
    "admissible": "inadmissible",
    "admit": "reject",
    "adult": "juvenile",
    "advance": "retreat",
    "advantage": "disadvantage",
    "advantageous": "disadvantageous",
    "adventurous": "unadventurous",
    "advisable": "inadvisable",
    "aesthetic": "inaesthetic",
    "affinity": "consanguinity",
    "affirm": "negate",
    "affirmation": "reversal",
    "affirmative": "negative",
    "afraid": "unafraid",
    "aft": "fore",
    "age": "rejuvenate",
    "aged": "young",
    "aggressive": "unaggressive",
    "agitated": "unagitated",
    "agitation": "calmness",
    "agnostic": "gnostic",
    "agree": "disagree",
    "agreeable": "disagreeable",
    "agreement": "disagreement",
    "aground": "afloat",
    "ahead": "back",
    "alarming": "unalarming",
    "alert": "unalert",
    "aligned": "nonaligned",
    "alignment": "nonalignment",
    "alike": "unalike",
    "aliquot": "aliquant",
    "alive": "dead",
    "allow": "disallow",
    "altered": "unaltered",
    "alternate": "opposite",
    "amateur": "professional",
    "ambiguity": "unambiguity",
    "ambiguous": "unambiguous",
    "ambitious": "unambitious",
    "amicable": "hostile",
    "amphibious": "terrestrial",
    "amply": "meagerly",
    "anal": "oral",
    "analogous": "heterologous",
    "analogue": "digital",
    "analysis": "synthesis",
    "analytic": "synthetic",
    "analyze": "synthesize",
    "ancestor": "descendant",
    "angry": "unangry",
    "angular": "rounded",
    "anhydrous": "hydrous",
    "animate": "inanimate",
    "animated": "unanimated",
    "anonymous": "onymous",
    "answer": "question",
    "antagonist": "synergist",
    "antagonistic": "conciliatory",
    "antecedent": "subsequent",
    "anterior": "posterior",
    "antiseptic": "septic",
    "apex": "antapex",
    "apologetic": "unapologetic",
    "appearance": "disappearance",
    "applicability": "inapplicability",
    "appreciation": "depreciation",
    "approbation": "disapprobation",
    "approval": "disapproval",
    "approve": "disapprove",
    "aptitude": "inaptitude",
    "aquatic": "amphibious",
    "aqueous": "igneous",
    "argumentative": "unargumentative",
    "arm": "disarm",
    "armament": "disarmament",
    "armed": "armless",
    "armored": "unarmored",
    "arrange": "disarrange",
    "arranged": "disarranged",
    "arrive": "leave",
    "artful": "artless",
    "articulate": "inarticulate",
    "ascend": "descend",
    "ascent": "descent",
    "ashamed": "unashamed",
    "asleep": "awake",
    "assemble": "disassemble",
    "assembly": "disassembly",
    "assent": "dissent",
    "assimilate": "dissimilate",
    "associate": "dissociate",
    "association": "disassociation",
    "astigmatism": "stigmatism",
    "astringent": "nonastringent",
    "asymmetry": "symmetry",
    "atheism": "theism",
    "attach": "detach",
    "attack": "defend",
    "attendance": "nonattendance",
    "attention": "inattention",
    "attentive": "inattentive",
    "attraction": "repulsion",
    "attractiveness": "unattractiveness",
    "attributable": "unattributable",
    "audible": "inaudible",
    "augmentation": "diminution",
    "aunt": "uncle",
    "auspicious": "inauspicious",
    "authorized": "unauthorized",
    "automatic": "manual",
    "avoid": "confront",
    "awake": "asleep",
    "awaken": "cause to sleep",
    "awkwardness": "gracefulness",
    "back": "veer",
    "background": "foreground",
    "backward": "forward",
    "bad": "good",
    "badly": "well",
    "badness": "goodness",
    "balance": "unbalance",
    "balanced": "unbalanced",
    "bar": "unbar",
    "bear": "bull",
    "bearing": "nonbearing",
    "beautiful": "ugly",
    "beautify": "uglify",
    "beauty": "ugliness",
    "begin": "end",
    "beginning": "ending",
    "belief": "unbelief",
    "believe": "disbelieve",
    "belt": "unbelt",
    "bend": "unbend",
    "benevolence": "malevolence",
    "benign": "malignant",
    "bequeath": "disinherit",
    "biennial": "annual",
    "big": "little",
    "bind": "unbind",
    "birth": "death",
    "bisexual": "heterosexual",
    "black": "white",
    "blame": "absolve",
    "bless": "curse",
    "blessed": "cursed",
    "blind": "sighted",
    "block": "unblock",
    "blond": "brunet",
    "bloodless": "bloody",
    "bloody": "bloodless",
    "blur": "focus",
    "boil": "freeze",
    "bold": "timid",
    "boldness": "timidity",
    "bolt": "unbolt",
    "bony": "boneless",
    "boo": "applaud",
    "bore": "interest",
    "borrow": "lend",
    "borrower": "lender",
    "bottom": "top",
    "bottomless": "bottomed",
    "bounce": "clear",
    "bound": "unbound",
    "bowed": "plucked",
    "box": "unbox",
    "boy": "girl",
    "boycott": "patronise",
    "braid": "unbraid",
    "break": "repair",
    "breakable": "unbreakable",
    "bridle": "unbridle",
    "brighten": "darken",
    "brightness": "dullness",
    "bring": "take away",
    "broken": "unbroken",
    "brother": "sister",
    "brotherly": "sisterly",
    "buckle": "unbuckle",
    "bull": "bear",
    "burden": "unburden",
    "buried": "unburied",
    "busy": "idle",
    "button": "unbutton",
    "buy": "sell",
    "calm": "agitate",
    "calmness": "agitation",
    "capability": "incapability",
    "capable": "incapable",
    "capacity": "incapacity",
    "captor": "liberator",
    "cardinal": "ordinal",
    "careful": "careless",
    "carefully": "carelessly",
    "carelessness": "carefulness",
    "carnivorous": "herbivorous",
    "cash": "credit",
    "catabolism": "anabolism",
    "caudal": "cephalic",
    "caution": "incaution",
    "cautious": "incautious",
    "cautiously": "incautiously",
    "cellular": "noncellular",
    "center": "left",
    "central": "peripheral",
    "centrality": "marginality",
    "centralization": "decentralization",
    "centralize": "decentralize",
    "centrally": "peripherally",
    "centrifugal": "centripetal",
    "cerebral": "emotional",
    "certainty": "uncertainty",
    "certify": "decertify",
    "chain": "unchain",
    "change": "stay",
    "changeable": "unchangeable",
    "changed": "unchanged",
    "characteristic": "uncharacteristic",
    "charge": "pay cash",
    "charitable": "uncharitable",
    "chartered": "unchartered",
    "cheap": "expensive",
    "cheer": "complain",
    "cheerful": "depressing",
    "cheerfulness": "uncheerfulness",
    "child": "parent",
    "chromatic": "diatonic",
    "chronic": "acute",
    "citizen": "noncitizen",
    "civil": "uncivil",
    "civilian": "serviceman",
    "civility": "incivility",
    "civilized": "noncivilized",
    "claim": "forfeit",
    "clarify": "obfuscate",
    "clarity": "opacity",
    "clasp": "unclasp",
    "classical": "nonclassical",
    "classification": "declassification",
    "classify": "declassify",
    "clean": "unclean",
    "cleanliness": "uncleanliness",
    "clearness": "unclearness",
    "clergy": "laity",
    "clergyman": "layman",
    "clip": "unclip",
    "clog": "unclog",
    "close": "distant",
    "closed": "open",
    "closeness": "openness",
    "cloudy": "clear",
    "clutter": "unclutter",
    "coastal": "inland",
    "coherence": "incoherence",
    "coherent": "incoherent",
    "coil": "uncoil",
    "coiled": "uncoiled",
    "cold": "hot",
    "coldness": "hotness",
    "collateral": "lineal",
    "collected": "uncollected",
    "collective": "distributive",
    "color": "colorlessness",
    "colored": "uncolored",
    "colorless": "colorful",
    "combined": "uncombined",
    "combustible": "noncombustible",
    "comedy": "tragedy",
    "comfort": "discomfort",
    "commensurate": "incommensurate",
    "commercial": "noncommercial",
    "committed": "uncommitted",
    "common": "individual",
    "communicate": "excommunicate",
    "communicative": "uncommunicative",
    "compact": "loose",
    "comparable": "incomparable",
    "compassionate": "uncompassionate",
    "compatibility": "incompatibility",
    "compatible": "incompatible",
    "competence": "incompetence",
    "competent": "incompetent",
    "competition": "cooperation",
    "competitive": "noncompetitive",
    "complain": "cheer",
    "completeness": "incompleteness",
    "complex": "simple",
    "complexity": "simplicity",
    "compliance": "noncompliance",
    "compliant": "defiant",
    "complicate": "simplify",
    "composed": "discomposed",
    "composure": "discomposure",
    "compound": "simple",
    "comprehension": "incomprehension",
    "comprehensive": "noncomprehensive",
    "compress": "decompress",
    "compressible": "incompressible",
    "compression": "decompression",
    "con": "pro",
    "concave": "convex",
    "concealed": "unconcealed",
    "conceit": "humility",
    "concentrate": "deconcentrate",
    "concentration": "distribution",
    "concentric": "eccentric",
    "conception": "misconception",
    "concern": "unconcern",
    "concerned": "unconcerned",
    "concise": "prolix",
    "concrete": "abstract",
    "conditional": "unconditional",
    "conditionally": "unconditionally",
    "conditioned": "unconditioned",
    "conductor": "insulator",
    "confidence": "diffidence",
    "confident": "diffident",
    "confine": "free",
    "confined": "unconfined",
    "confirmed": "unconfirmed",
    "conformity": "nonconformity",
    "confront": "avoid",
    "congenial": "uncongenial",
    "conjunctive": "disjunctive",
    "connect": "disconnect",
    "connected": "unconnected",
    "conscientious": "unconscientious",
    "consciousness": "unconsciousness",
    "consequence": "inconsequence",
    "conservative": "liberal",
    "conserve": "waste",
    "considerable": "inconsiderable",
    "considerate": "inconsiderate",
    "consistency": "inconsistency",
    "consistent": "inconsistent",
    "consonant": "vowel",
    "conspicuous": "inconspicuous",
    "constancy": "inconstancy",
    "constant": "inconstant",
    "constitutional": "unconstitutional",
    "construction": "misconstruction",
    "consume": "abstain",
    "contaminate": "decontaminate",
    "contaminated": "uncontaminated",
    "contamination": "decontamination",
    "contemptible": "estimable",
    "content": "discontent",
    "continent": "incontinent",
    "continental": "intercontinental",
    "continual": "sporadic",
    "continuance": "discontinuance",
    "continuation": "discontinuation",
    "continue": "discontinue",
    "continued": "discontinued",
    "continuity": "discontinuity",
    "continuous": "discontinuous",
    "contract": "expand",
    "contracted": "expanded",
    "contraction": "expansion",
    "controversial": "uncontroversial",
    "convenience": "inconvenience",
    "convenient": "inconvenient",
    "conventional": "nuclear",
    "converge": "diverge",
    "convergence": "divergence",
    "convergent": "divergent",
    "convertible": "inconvertible",
    "convex": "concave",
    "convict": "acquit",
    "conviction": "acquittal",
    "convinced": "unconvinced",
    "convincing": "unconvincing",
    "cool": "warm",
    "cooperation": "competition",
    "cooperative": "uncooperative",
    "cork": "uncork",
    "corporeal": "incorporeal",
    "correctness": "incorrectness",
    "corrupt": "incorrupt",
    "cortex": "medulla",
    "cosmopolitan": "provincial",
    "couple": "uncouple",
    "courage": "cowardice",
    "courteous": "discourteous",
    "courtesy": "discourtesy",
    "cover": "uncover",
    "covered": "bare",
    "covert": "overt",
    "cowardice": "courage",
    "cowardly": "brave",
    "crate": "uncrate",
    "creative": "uncreative",
    "credibility": "incredibility",
    "credible": "incredible",
    "credit": "debit",
    "creditor": "debtor",
    "crescendo": "decrescendo",
    "criticize": "praise",
    "cross": "uncross",
    "crossed": "uncrossed",
    "crowded": "uncrowded",
    "crucial": "noncrucial",
    "cry": "laugh",
    "crystalline": "noncrystalline",
    "cultivated": "uncultivated",
    "curable": "incurable",
    "current": "noncurrent",
    "curse": "bless",
    "cursed": "blessed",
    "curve": "straight line",
    "curved": "straight",
    "cut": "uncut",
    "cyclone": "anticyclone",
    "danger": "safety",
    "dangerous": "safe",
    "dark": "light",
    "darken": "brighten",
    "darkness": "lightness",
    "daughter": "son",
    "day": "night",
    "deaf": "hearing",
    "death": "birth",
    "debit": "credit",
    "debtor": "creditor",
    "deceive": "undeceive",
    "decency": "indecency",
    "decent": "indecent",
    "deciduous": "evergreen",
    "decision": "indecision",
    "decisive": "indecisive",
    "declaratory": "interrogatory",
    "decline": "improvement",
    "decorum": "indecorum",
    "decrease": "increase",
    "decreased": "increased",
    "decreasing": "increasing",
    "decrement": "increment",
    "default": "pay up",
    "defeat": "victory",
    "defeated": "undefeated",
    "defend": "prosecute",
    "defendant": "plaintiff",
    "defense": "prosecution",
    "defensive": "offensive",
    "defiant": "compliant",
    "deficit": "lead",
    "defined": "undefined",
    "deflate": "inflate",
    "deflation": "disinflation",
    "defy": "lend oneself",
    "degrade": "aggrade",
    "delay": "rush",
    "demand": "supply",
    "demanding": "undemanding",
    "demonstrative": "undemonstrative",
    "deny": "allow",
    "depart": "stay",
    "dependent": "independent",
    "deposit": "withdraw",
    "depreciate": "appreciate",
    "depreciation": "appreciation",
    "depress": "elate",
    "depressing": "cheerful",
    "depression": "elation",
    "descend": "ascend",
    "descendant": "ancestor",
    "descending": "ascending",
    "descent": "ascent",
    "descriptive": "undescriptive",
    "designed": "undesigned",
    "desirability": "undesirability",
    "desirable": "undesirable",
    "desirous": "undesirous",
    "despair": "hope",
    "desperate": "hope",
    "desperation": "hope",
    "destroyed": "preserved",
    "destructive": "constructive",
    "detach": "attach",
    "detached": "attached",
    "deteriorate": "recuperate",
    "determinable": "indeterminable",
    "determinate": "indeterminate",
    "determined": "undetermined",
    "development": "nondevelopment",
    "deviate": "conform",
    "devolution": "evolution",
    "die": "be born",
    "differ": "equal",
    "difference": "sameness",
    "difficult": "easy",
    "difficulty": "ease",
    "dignified": "undignified",
    "diligent": "negligent",
    "diluted": "undiluted",
    "dilution": "concentration",
    "diminution": "augmentation",
    "diplomatic": "undiplomatic",
    "directly": "indirectly",
    "dirty": "clean",
    "disable": "enable",
    "disadvantage": "advantage",
    "disagree": "agree",
    "disagreeable": "agreeable",
    "disagreement": "agreement",
    "disallow": "allow",
    "disappear": "appear",
    "disappearance": "appearance",
    "disapproval": "approval",
    "disapprove": "approve",
    "disarm": "arm",
    "disbelieve": "believe",
    "discernible": "indiscernible",
    "discerning": "undiscerning",
    "discharge": "enlist",
    "discipline": "indiscipline",
    "disclaim": "claim",
    "discolor": "color",
    "discomfort": "comfort",
    "disconnect": "connect",
    "discontent": "content",
    "discontinuance": "continuance",
    "discontinue": "continue",
    "discontinuity": "continuity",
    "discontinuous": "continuous",
    "discourage": "encourage",
    "discouragement": "encouragement",
    "discreet": "indiscreet",
    "discriminate": "indiscriminate",
    "discriminating": "undiscriminating",
    "disengage": "engage",
    "dishonest": "honest",
    "dishonesty": "honesty",
    "dishonor": "honor",
    "disinfect": "infect",
    "disingenuous": "ingenuous",
    "disintegrate": "integrate",
    "disjunctive": "conjunctive",
    "dislike": "liking",
    "disliked": "liked",
    "dislodge": "lodge",
    "disobedience": "obedience",
    "disobedient": "obedient",
    "disobey": "obey",
    "disorder": "order",
    "disorderly": "orderly",
    "disorganized": "organized",
    "disparage": "flatter",
    "displeased": "pleased",
    "dispose": "indispose",
    "disprove": "prove",
    "disqualify": "qualify",
    "disreputable": "reputable",
    "disrepute": "repute",
    "disrespect": "respect",
    "disrespectful": "respectful",
    "dissatisfaction": "satisfaction",
    "dissent": "assent",
    "disservice": "service",
    "dissimilar": "similar",
    "dissonance": "harmony",
    "dissuade": "persuade",
    "distal": "mesial",
    "distant": "close",
    "distinguishable": "indistinguishable",
    "distribution": "concentration",
    "distrust": "trust",
    "diurnal": "nocturnal",
    "diverge": "converge",
    "divergence": "convergence",
    "divergent": "convergent",
    "diversified": "undiversified",
    "diversify": "specialise",
    "divest": "invest",
    "divide": "unite",
    "divided": "united",
    "divisible": "indivisible",
    "docile": "stubborn",
    "dock": "undock",
    "domestic": "undomestic",
    "dominant": "recessive",
    "dormant": "active",
    "dorsal": "ventral",
    "double": "single",
    "dove": "hawk",
    "drained": "undrained",
    "dramatic": "undramatic",
    "driver": "nondriver",
    "drunkenness": "soberness",
    "dry": "phlegmy",
    "dryness": "wetness",
    "due": "undue",
    "dull": "sharp",
    "dying": "nascent",
    "dynamic": "undynamic",
    "eager": "uneager",
    "early": "middle",
    "earthly": "heavenly",
    "ease": "difficulty",
    "easy": "uneasy",
    "ebb": "tide",
    "eccentric": "concentric",
    "eccentricity": "concentricity",
    "edible": "inedible",
    "educated": "uneducated",
    "effective": "ineffective",
    "effectually": "ineffectually",
    "efficacious": "inefficacious",
    "efficacy": "inefficacy",
    "efficiency": "inefficiency",
    "efficient": "inefficient",
    "egress": "ingress",
    "elastic": "inelastic",
    "elasticity": "inelasticity",
    "elated": "dejected",
    "elegance": "inelegance",
    "elegant": "inelegant",
    "eligible": "ineligible",
    "embark": "disembark",
    "embarrassment": "disembarrassment",
    "emigrate": "immigrate",
    "emit": "absorb",
    "emotional": "unemotional",
    "empirical": "theoretical",
    "employer": "employee",
    "employment": "unemployment",
    "emptiness": "fullness",
    "empty": "fill",
    "enable": "disable",
    "enchant": "disenchant",
    "enchanted": "disenchanted",
    "encode": "decode",
    "encourage": "discourage",
    "encouragement": "discouragement",
    "end": "begin",
    "endemic": "ecdemic",
    "ending": "beginning",
    "endowed": "unendowed",
    "energetic": "lethargic",
    "enforce": "exempt",
    "engage": "disengage",
    "engagement": "non-engagement",
    "enjoy": "suffer",
    "enlightenment": "unenlightenment",
    "enlist": "discharge",
    "enliven": "deaden",
    "enrich": "impoverish",
    "enter": "drop out",
    "enterprising": "unenterprising",
    "epidemic": "ecdemic",
    "equal": "unequal",
    "equality": "inequality",
    "equally": "unequally",
    "equatorial": "polar",
    "equilibrium": "disequilibrium",
    "equitable": "inequitable",
    "equity": "inequity",
    "equivalence": "nonequivalence",
    "equivocal": "unequivocal",
    "erase": "record",
    "erect": "unerect",
    "escalate": "de-escalate",
    "esoteric": "exoteric",
    "essential": "inessential",
    "establish": "abolish",
    "established": "unestablished",
    "esteem": "disesteem",
    "ethical": "unethical",
    "eugenics": "dysgenics",
    "euphemism": "dysphemism",
    "eventful": "uneventful",
    "evergreen": "deciduous",
    "evil": "good",
    "evolution": "devolution",
    "excitable": "unexcitable",
    "excited": "unexcited",
    "exciting": "unexciting",
    "exclude": "include",
    "exclusion": "inclusion",
    "exempt": "nonexempt",
    "exhale": "inhale",
    "exhausted": "unexhausted",
    "existence": "nonexistence",
    "existent": "nonexistent",
    "exit": "enter",
    "expand": "contract",
    "expanded": "contracted",
    "expansion": "contraction",
    "expansive": "unexpansive",
    "expatriate": "repatriate",
    "expected": "unexpected",
    "expediency": "inexpediency",
    "expedient": "inexpedient",
    "expensive": "cheap",
    "experience": "inexperience",
    "experienced": "inexperienced",
    "expired": "unexpired",
    "explode": "implode",
    "explosive": "nonexplosive",
    "export": "import",
    "express": "local",
    "extant": "extinct",
    "extended": "unextended",
    "extension": "flexion",
    "extensive": "intensive",
    "exterior": "interior",
    "external": "internal",
    "externally": "internally",
    "extinct": "extant",
    "extinguish": "ignite",
    "extramural": "intramural",
    "extraordinary": "ordinary",
    "extrinsic": "intrinsic",
    "failing": "passing",
    "failure": "success",
    "fair": "unfair",
    "fairly": "unfairly",
    "faithful": "unfaithful",
    "fall": "rise",
    "fallible": "infallible",
    "falling": "rising",
    "falsehood": "truth",
    "falsify": "correct",
    "falsity": "truth",
    "fame": "infamy",
    "familiar": "strange",
    "familiarity": "unfamiliarity",
    "fancy": "plain",
    "fashionable": "unfashionable",
    "fasten": "unfasten",
    "fat": "thin",
    "fatal": "nonfatal",
    "father": "mother",
    "fatty": "nonfat",
    "fauna": "flora",
    "favorable": "unfavorable",
    "fear": "fearlessness",
    "fearfully": "fearlessly",
    "feasibility": "infeasibility",
    "febrile": "afebrile",
    "federal": "unitary",
    "feed": "starve",
    "felicity": "infelicity",
    "female": "male",
    "feminine": "neuter",
    "femininity": "masculinity",
    "fertile": "sterile",
    "fidelity": "infidelity",
    "figurative": "literal",
    "figure": "ground",
    "fill": "empty",
    "financial": "nonfinancial",
    "find": "lose",
    "finish": "start",
    "finite": "infinite",
    "fire": "hire",
    "fissile": "nonfissile",
    "fitness": "unfitness",
    "fixed": "unfixed",
    "flashback": "flash-forward",
    "flat": "contrasty",
    "flatten": "sharpen",
    "flattering": "unflattering",
    "flexibility": "inflexibility",
    "flexible": "inflexible",
    "flexion": "extension",
    "float": "sink",
    "flora": "fauna",
    "flowering": "flowerless",
    "fluency": "disfluency",
    "focus": "blur",
    "foe": "friend",
    "fold": "unfold",
    "follow": "precede",
    "follower": "leader",
    "folly": "wisdom",
    "foolish": "wise",
    "foot": "head",
    "forbid": "permit",
    "fore": "aft",
    "foreground": "background",
    "foreign": "native",
    "forfeit": "claim",
    "forget": "remember",
    "forgiving": "unforgiving",
    "formalism": "imitation",
    "formality": "informality",
    "formed": "unformed",
    "forte": "piano",
    "fortunate": "unfortunate",
    "forward": "backward",
    "foul": "fair",
    "found": "lost",
    "fractional": "whole",
    "fragrant": "malodorous",
    "fraternal": "identical",
    "freelance": "salaried",
    "freeze": "unfreeze",
    "frequent": "infrequent",
    "frequently": "infrequently",
    "friend": "foe",
    "friendliness": "unfriendliness",
    "friendly": "unfriendly",
    "frivolous": "serious",
    "front": "rear",
    "frozen": "unfrozen",
    "fruitful": "unfruitful",
    "full": "empty",
    "fullness": "emptiness",
    "function": "malfunction",
    "functional": "nonfunctional",
    "fuse": "defuse",
    "future": "present",
    "gain": "reduce",
    "gaseous": "liquid",
    "gather": "spread",
    "general": "specific",
    "generality": "particularity",
    "generally": "specifically",
    "generative": "consumptive",
    "generic": "varietal",
    "generosity": "stinginess",
    "generous": "ungenerous",
    "genuine": "counterfeit",
    "girl": "boy",
    "glad": "sad",
    "good": "evil",
    "goodness": "evilness",
    "graceful": "awkward",
    "gracious": "ungracious",
    "graciously": "ungraciously",
    "gradual": "sudden",
    "grassy": "grassless",
    "grateful": "ungrateful",
    "gratitude": "ingratitude",
    "gravitation": "levitation",
    "gravity": "levity",
    "greater": "lesser",
    "green": "ripe",
    "gregarious": "ungregarious",
    "gross": "net",
    "ground": "figure",
    "grudgingly": "ungrudgingly",
    "guilt": "innocence",
    "guilty": "innocent",
    "hairy": "hairless",
    "half": "whole",
    "happily": "unhappily",
    "happiness": "unhappiness",
    "happy": "unhappy",
    "harden": "soften",
    "hardened": "soft",
    "hardness": "softness",
    "hardware": "software",
    "harmful": "harmless",
    "harmony": "dissonance",
    "harness": "unharness",
    "hate": "love",
    "hateful": "lovable",
    "hawk": "dove",
    "head": "tail",
    "healthful": "unhealthful",
    "healthy": "unhealthy",
    "hearing": "deaf",
    "heat": "cool",
    "heavenly": "earthly",
    "heavily": "lightly",
    "heaviness": "lightness",
    "helpful": "unhelpful",
    "heterogeneity": "homogeneity",
    "hibernate": "aestivate",
    "hide": "show",
    "hierarchical": "nonhierarchical",
    "high": "low spirits",
    "highland": "lowland",
    "hire": "fire",
    "hit": "miss",
    "hold": "let go of",
    "holiness": "unholiness",
    "hollow": "solid",
    "holy": "unholy",
    "homeopathic": "allopathic",
    "homeopathy": "allopathy",
    "homogeneity": "heterogeneity",
    "homogeneous": "heterogeneous",
    "homologous": "autologous",
    "homosexual": "bisexual",
    "honest": "dishonest",
    "honesty": "dishonesty",
    "honor": "dishonor",
    "honorable": "dishonorable",
    "hook": "unhook",
    "hope": "desperation",
    "hopeful": "hopeless",
    "hopeless": "hopeful",
    "hopelessness": "hopefulness",
    "horizontal": "vertical",
    "hospitality": "inhospitality",
    "hostile": "amicable",
    "hot": "cold",
    "human": "nonhuman",
    "humane": "inhumane",
    "humble": "proud",
    "humility": "pride",
    "humorous": "humorless",
    "hungry": "thirsty",
    "hurried": "unhurried",
    "identical": "fraternal",
    "idle": "run",
    "igneous": "aqueous",
    "ignite": "extinguish",
    "ignore": "know",
    "ill": "well",
    "illegal": "legal",
    "illegality": "legality",
    "illegible": "legible",
    "illegitimate": "legitimate",
    "illicit": "licit",
    "illiterate": "literate",
    "illness": "wellness",
    "illogical": "logical",
    "imitation": "formalism",
    "immaterial": "material",
    "immature": "mature",
    "immaturity": "maturity",
    "immeasurable": "measurable",
    "immeasurably": "measurably",
    "immediacy": "mediacy",
    "immersion": "emersion",
    "immoral": "moral",
    "immorality": "morality",
    "immortal": "mortal",
    "immortality": "mortality",
    "immutable": "mutable",
    "impartial": "partial",
    "impartiality": "partiality",
    "impassable": "passable",
    "impatience": "patience",
    "impatient": "patient",
    "impenetrable": "penetrable",
    "imperative": "beseeching",
    "imperceptible": "perceptible",
    "imperfection": "perfection",
    "imperfectly": "perfectly",
    "impermeable": "permeable",
    "impermissible": "permissible",
    "impersonal": "personal",
    "impervious": "pervious",
    "implacable": "placable",
    "impolite": "polite",
    "import": "export",
    "importance": "unimportance",
    "important": "unimportant",
    "impossibility": "possibility",
    "impossible": "possible",
    "impotence": "potence",
    "impotent": "potent",
    "impressionable": "unimpressionable",
    "improbable": "probable",
    "impropriety": "propriety",
    "improved": "unimproved",
    "improvement": "decline",
    "imprudent": "prudent",
    "impure": "pure",
    "impurity": "purity",
    "inability": "ability",
    "inaccessible": "accessible",
    "inaccurate": "accurate",
    "inaction": "action",
    "inactivate": "activate",
    "inactivation": "activation",
    "inactive": "active",
    "inactivity": "activity",
    "inadequacy": "adequacy",
    "inadequate": "adequate",
    "inadmissible": "admissible",
    "inadvertently": "advertently",
    "inalienable": "alienable",
    "inanimate": "animate",
    "inappropriate": "appropriate",
    "inattention": "attention",
    "inaudible": "audible",
    "inaugural": "exaugural",
    "inbred": "outbred",
    "incalculable": "calculable",
    "incapable": "capable",
    "incapacity": "capacity",
    "incentive": "disincentive",
    "inclement": "clement",
    "inclination": "disinclination",
    "inclined": "disinclined",
    "include": "exclude",
    "inclusion": "exclusion",
    "inclusive": "exclusive",
    "incoherent": "coherent",
    "income": "outgo",
    "incoming": "outgoing",
    "incompatible": "compatible",
    "incompetence": "competence",
    "incompetent": "competent",
    "incompleteness": "completeness",
    "incomprehensible": "comprehensible",
    "inconclusive": "conclusive",
    "incongruous": "congruous",
    "inconsiderate": "considerate",
    "inconsistency": "consistency",
    "inconspicuous": "conspicuous",
    "inconvenient": "convenient",
    "incorrect": "correct",
    "increase": "decrease",
    "increased": "decreased",
    "incredulous": "credulous",
    "increment": "decrement",
    "incurable": "curable",
    "indecency": "decency",
    "indecent": "decent",
    "indecision": "decision",
    "indecisive": "decisive",
    "independent": "dependent",
    "indestructible": "destructible",
    "indeterminate": "determinate",
    "indicate": "contraindicate",
    "indication": "contraindication",
    "indirect": "direct",
    "indispensable": "dispensable",
    "indistinct": "distinct",
    "indistinguishable": "distinguishable",
    "individuality": "commonality",
    "indivisible": "divisible",
    "indoor": "outdoor",
    "induced": "spontaneous",
    "indulgent": "nonindulgent",
    "ineffective": "effective",
    "inefficiency": "efficiency",
    "inefficient": "efficient",
    "inelastic": "elastic",
    "ineligible": "eligible",
    "inequality": "equality",
    "inequitable": "equitable",
    "inevitable": "evitable",
    "inexact": "exact",
    "inexcusable": "excusable",
    "inexhaustible": "exhaustible",
    "inexperience": "experience",
    "inexperienced": "experienced",
    "inexplicable": "explicable",
    "infallibility": "fallibility",
    "infallible": "fallible",
    "infamy": "fame",
    "infect": "disinfect",
    "infectious": "noninfectious",
    "inferior": "superior",
    "inferiority": "superiority",
    "infertility": "fertility",
    "infidelity": "fidelity",
    "infinite": "finite",
    "infinitely": "finitely",
    "inflation": "deflation",
    "influential": "uninfluential",
    "influx": "efflux",
    "informal": "formal",
    "informed": "uninformed",
    "infrequent": "frequent",
    "infrequently": "frequently",
    "ingress": "egress",
    "inhabited": "uninhabited",
    "inhale": "exhale",
    "inhospitable": "hospitable",
    "initiate": "uninitiate",
    "injured": "uninjured",
    "injustice": "justice",
    "inland": "coastal",
    "innocence": "guilt",
    "innocent": "guilty",
    "innocuous": "noxious",
    "inoperative": "operative",
    "inorganic": "organic",
    "inquiring": "uninquiring",
    "insane": "sane",
    "insanity": "sanity",
    "insecure": "secure",
    "insecurity": "security",
    "inside": "outside",
    "insignificance": "significance",
    "insignificant": "significant",
    "insoluble": "soluble",
    "insolvency": "solvency",
    "insolvent": "solvent",
    "instability": "stability",
    "instructive": "uninstructive",
    "instrumental": "vocal",
    "insufficiency": "sufficiency",
    "insufficient": "sufficient",
    "insufficiently": "sufficiently",
    "insurmountable": "surmountable",
    "intangible": "tangible",
    "integrate": "differentiate",
    "integration": "segregation",
    "intellectual": "nonintellectual",
    "intelligence": "stupidity",
    "intelligent": "unintelligent",
    "intelligibility": "unintelligibility",
    "intelligible": "unintelligible",
    "intended": "unintended",
    "intense": "mild",
    "intentionally": "unintentionally",
    "interest": "bore",
    "interested": "uninterested",
    "interesting": "uninteresting",
    "interference": "noninterference",
    "interior": "exterior",
    "intermediate": "terminal",
    "internal": "external",
    "internally": "externally",
    "international": "national",
    "intervention": "nonintervention",
    "intestate": "testate",
    "intolerable": "tolerable",
    "intolerance": "tolerance",
    "intolerant": "tolerant",
    "intoxicated": "sober",
    "intractable": "tractable",
    "intramural": "extramural",
    "intrinsic": "extrinsic",
    "introspective": "extrospective",
    "intrusive": "unintrusive",
    "invalid": "valid",
    "invalidate": "validate",
    "inverse": "direct",
    "invisibility": "visibility",
    "invisible": "visible",
    "inviting": "uninviting",
    "involuntary": "voluntary",
    "involvement": "non-involvement",
    "irrational": "rational",
    "irreconcilable": "reconcilable",
    "irreducible": "reducible",
    "irregular": "regular",
    "irregularity": "regularity",
    "irregularly": "regularly",
    "irrelevant": "relevant",
    "irreparable": "reparable",
    "irresistible": "resistible",
    "irresponsible": "responsible",
    "irreverent": "reverent",
    "irreversible": "reversible",
    "irrevocable": "revocable",
    "issue": "recall",
    "join": "disjoin",
    "joint": "separate",
    "joy": "sorrow",
    "joyful": "sorrowful",
    "joyous": "joyless",
    "juicy": "juiceless",
    "junior": "senior",
    "justice": "injustice",
    "juvenile": "adult",
    "kern": "kern",
    "kind": "unkind",
    "kindness": "unkindness",
    "king": "queen",
    "knot": "unknot",
    "knowingly": "unknowingly",
    "lack": "have",
    "laity": "clergy",
    "landed": "landless",
    "large": "small",
    "lash": "unlash",
    "late": "early",
    "lateness": "earliness",
    "laugh": "cry",
    "lawful": "unlawful",
    "lax": "tense",
    "laxative": "costive",
    "layman": "clergyman",
    "lead": "deficit",
    "leader": "follower",
    "leading": "following",
    "leafy": "leafless",
    "leaky": "tight",
    "lean": "rich",
    "leave": "arrive",
    "left": "center",
    "legal": "illegal",
    "legality": "illegality",
    "legalize": "outlaw",
    "legibility": "illegibility",
    "legible": "illegible",
    "legitimacy": "illegitimacy",
    "lend": "borrow",
    "lender": "borrower",
    "lengthen": "shorten",
    "lengthwise": "crosswise",
    "lesser": "greater",
    "lethargic": "energetic",
    "level": "raise",
    "liability": "asset",
    "liar": "square shooter",
    "liberal": "conservative",
    "lie": "sit",
    "light": "heavy",
    "lighten": "weigh down",
    "lightness": "heaviness",
    "likelihood": "unlikelihood",
    "likeness": "unlikeness",
    "liking": "dislike",
    "limited": "unlimited",
    "lineal": "collateral",
    "linear": "nonlinear",
    "lined": "unlined",
    "linger": "rush",
    "linguistic": "nonlinguistic",
    "liquid": "gaseous",
    "literally": "figuratively",
    "living": "dead",
    "local": "national",
    "location": "studio",
    "lock": "unlock",
    "lodge": "dislodge",
    "logical": "illogical",
    "long": "short",
    "loosen": "stiffen",
    "loosening": "tightening",
    "lose": "win",
    "loss": "gain",
    "lost": "won",
    "loud": "soft",
    "loudly": "softly",
    "loudness": "softness",
    "lovable": "hateful",
    "love": "hate",
    "loving": "unloving",
    "lower": "raise",
    "lowland": "upland",
    "loyal": "disloyal",
    "loyalty": "disloyalty",
    "lucky": "unlucky",
    "lyric": "dramatic",
    "major": "minor",
    "majority": "minority",
    "make": "unmake",
    "male": "androgynous",
    "malicious": "unmalicious",
    "malign": "benign",
    "malignancy": "benignancy",
    "malignant": "benign",
    "man": "woman",
    "manage": "fail",
    "manly": "unmanly",
    "manual": "automatic",
    "marked": "unmarked",
    "married": "unmarried",
    "masculine": "feminine",
    "masculinity": "femininity",
    "mask": "unmask",
    "material": "immaterial",
    "materiality": "immateriality",
    "materialize": "dematerialize",
    "maternal": "paternal",
    "maturity": "immaturity",
    "maximum": "minimum",
    "meaningless": "meaningful",
    "measurable": "immeasurable",
    "mechanical": "nonmechanical",
    "mediate": "immediate",
    "medical": "surgical",
    "melodious": "unmelodious",
    "member": "nonmember",
    "mental": "physical",
    "merciful": "merciless",
    "merciless": "merciful",
    "merit": "demerit",
    "middle": "early",
    "migratory": "nonmigratory",
    "military": "unmilitary",
    "mind": "forget",
    "mindful": "unmindful",
    "mindfulness": "unmindfulness",
    "minimize": "maximize",
    "minimum": "maximum",
    "minor": "major",
    "minority": "majority",
    "minuscule": "majuscule",
    "misconception": "conception",
    "misfortune": "good fortune",
    "mismatched": "matched",
    "miss": "attend",
    "mistrust": "trust",
    "mobile": "stabile",
    "mobility": "immobility",
    "mobilization": "demobilization",
    "mobilize": "demobilize",
    "moderate": "immoderate",
    "moderately": "immoderately",
    "moderating": "intensifying",
    "moderation": "immoderation",
    "modern": "old style",
    "modest": "immodest",
    "modesty": "immodesty",
    "modifiable": "unmodifiable",
    "modified": "unmodified",
    "molar": "molecular",
    "molecular": "molar",
    "moral": "immoral",
    "morality": "immorality",
    "mortal": "immortal",
    "mortality": "immortality",
    "mother": "father",
    "motion": "motionlessness",
    "move": "stand still",
    "moving": "unmoving",
    "multilateral": "unilateral",
    "multiple": "single",
    "multiply": "singly",
    "mushroom": "toadstool",
    "musical": "unmusical",
    "mutable": "immutable",
    "muzzle": "unmuzzle",
    "myopia": "hyperopia",
    "nadir": "zenith",
    "naive": "sophisticated",
    "narrow": "widen",
    "narrowing": "widening",
    "nascent": "dying",
    "nasty": "nice",
    "national": "local",
    "native": "nonnative",
    "naturally": "unnaturally",
    "nay": "yea",
    "necessarily": "unnecessarily",
    "necessitate": "obviate",
    "negative": "positive",
    "neglect": "attend to",
    "negligent": "diligent",
    "nephew": "niece",
    "net": "gross",
    "neurotic": "unneurotic",
    "neuter": "feminine",
    "neutral": "negative",
    "newness": "oldness",
    "niece": "nephew",
    "night": "day",
    "noble": "lowborn",
    "nobleman": "noblewoman",
    "nocturnal": "diurnal",
    "node": "antinode",
    "noisy": "quiet",
    "nominal": "real",
    "noncompliance": "compliance",
    "nonexistent": "existent",
    "nonpayment": "payment",
    "nonresident": "resident",
    "normal": "paranormal",
    "normality": "abnormality",
    "notice": "ignore",
    "noticeable": "unnoticeable",
    "noxious": "innocuous",
    "numerical": "verbal",
    "obedience": "disobedience",
    "obedient": "disobedient",
    "obediently": "disobediently",
    "obey": "disobey",
    "objective": "subjective",
    "obligatory": "optional",
    "oblige": "disoblige",
    "oblique": "nominative",
    "obscurity": "prominence",
    "observance": "nonobservance",
    "obstruct": "free",
    "obtuse": "acute",
    "obverse": "reverse",
    "obvious": "unobvious",
    "occupied": "unoccupied",
    "offense": "defense",
    "offensive": "inoffensive",
    "official": "unofficial",
    "offside": "onside",
    "opacity": "transparency",
    "opaque": "clear",
    "open": "shut",
    "opening": "closing",
    "openness": "closeness",
    "operative": "inoperative",
    "opportune": "inopportune",
    "opposed": "unopposed",
    "opposite": "alternate",
    "optimism": "pessimism",
    "optimist": "pessimist",
    "optional": "obligatory",
    "optionally": "obligatorily",
    "oral": "aboral",
    "order": "disorder",
    "orderly": "disorderly",
    "ordinary": "extraordinary",
    "organic": "inorganic",
    "organize": "disorganize",
    "organized": "unorganized",
    "orient": "disorient",
    "originality": "unoriginality",
    "orthodox": "unorthodox",
    "orthodoxy": "unorthodoxy",
    "outdoor": "indoor",
    "outlaw": "legalise",
    "outward": "inward",
    "overcast": "clear up",
    "overcharge": "undercharge",
    "overestimate": "underestimate",
    "overhead": "subsurface",
    "overpay": "underpay",
    "overstate": "understate",
    "overstock": "understock",
    "overt": "covert",
    "pack": "unpack",
    "pain": "pleasure",
    "painful": "painless",
    "painfully": "painlessly",
    "painless": "painful",
    "painted": "unpainted",
    "palatable": "unpalatable",
    "palpable": "impalpable",
    "parallel": "oblique",
    "parasite": "host",
    "parent": "child",
    "parental": "filial",
    "partiality": "impartiality",
    "participation": "nonparticipation",
    "particular": "universal",
    "particularity": "generality",
    "partisan": "nonpartisan",
    "partly": "wholly",
    "pass": "fail",
    "passable": "impassable",
    "passing": "failing",
    "passionate": "passionless",
    "passive": "active",
    "past": "future",
    "paternal": "maternal",
    "patience": "impatience",
    "patient": "impatient",
    "patriarchal": "matriarchal",
    "patriotic": "unpatriotic",
    "patronize": "boycott",
    "payment": "nonpayment",
    "peace": "war",
    "peaceful": "unpeaceful",
    "penalty": "reward",
    "perceptible": "imperceptible",
    "perceptive": "unperceptive",
    "perennial": "annual",
    "perfect": "imperfect",
    "perfection": "imperfection",
    "periodic": "aperiodic",
    "perishable": "imperishable",
    "permanence": "impermanence",
    "permeable": "impermeable",
    "permissible": "impermissible",
    "permissive": "unpermissive",
    "permit": "forbid",
    "perpendicular": "oblique",
    "perplexed": "unperplexed",
    "persistent": "caducous",
    "personal": "impersonal",
    "persuade": "dissuade",
    "persuasion": "dissuasion",
    "persuasive": "dissuasive",
    "pessimism": "optimism",
    "pessimist": "optimist",
    "physical": "mental",
    "piano": "forte",
    "piety": "impiety",
    "pin": "unpin",
    "pious": "impious",
    "plain": "patterned",
    "plaintiff": "defendant",
    "planned": "unplanned",
    "plausibility": "implausibility",
    "playful": "unplayful",
    "pleasant": "unpleasant",
    "pleased": "displeased",
    "plowed": "unplowed",
    "plural": "singular",
    "pointless": "pointed",
    "polar": "equatorial",
    "polished": "unpolished",
    "polite": "impolite",
    "politeness": "impoliteness",
    "politic": "impolitic",
    "popular": "unpopular",
    "popularity": "unpopularity",
    "porosity": "solidity",
    "porous": "nonporous",
    "portable": "unportable",
    "possibility": "impossibility",
    "possibly": "impossibly",
    "posterior": "anterior",
    "potency": "impotency",
    "potent": "impotent",
    "potential": "actual",
    "poverty": "wealth",
    "powerful": "powerless",
    "powerless": "powerful",
    "practical": "impractical",
    "praise": "criticize",
    "precede": "succeed",
    "preceding": "succeeding",
    "precise": "imprecise",
    "precisely": "imprecisely",
    "precision": "imprecision",
    "precocious": "retarded",
    "prefix": "suffix",
    "prejudiced": "unprejudiced",
    "premature": "full-term",
    "premeditated": "unpremeditated",
    "preparation": "resolution",
    "prepared": "unprepared",
    "prescription": "nonprescription",
    "prescriptive": "descriptive",
    "presence": "absence",
    "present": "future",
    "preserved": "destroyed",
    "prevent": "let",
    "preventive": "permissive",
    "pride": "humility",
    "priestly": "unpriestly",
    "primary": "secondary",
    "priority": "posteriority",
    "private": "public",
    "privately": "publicly",
    "privileged": "underprivileged",
    "probability": "improbability",
    "probable": "improbable",
    "productive": "unproductive",
    "profane": "sacred",
    "professional": "unprofessional",
    "profit": "break even",
    "progress": "regress",
    "progressive": "regressive",
    "prominence": "obscurity",
    "promote": "demote",
    "promotion": "demotion",
    "proper": "improper",
    "prophetic": "unprophetic",
    "proportion": "disproportion",
    "proportionate": "disproportionate",
    "proprietary": "nonproprietary",
    "propriety": "impropriety",
    "prosecute": "defend",
    "prosecution": "defense",
    "prospective": "retrospective",
    "protected": "unprotected",
    "protective": "unprotective",
    "proud": "humble",
    "prove": "disprove",
    "providence": "improvidence",
    "provincial": "cosmopolitan",
    "provocative": "unprovocative",
    "proximal": "distal",
    "proximate": "ultimate",
    "prudence": "imprudence",
    "prudent": "imprudent",
    "public": "private",
    "publicly": "privately",
    "published": "unpublished",
    "pull": "push",
    "punctual": "unpunctual",
    "punctuality": "tardiness",
    "punished": "unpunished",
    "punitive": "rehabilitative",
    "purge": "rehabilitate",
    "purity": "impurity",
    "push": "pull",
    "qualified": "unqualified",
    "qualify": "disqualify",
    "quantitative": "qualitative",
    "queen": "king",
    "question": "answer",
    "questionable": "unquestionable",
    "quickly": "slowly",
    "quiet": "unquiet",
    "quietly": "unquietly",
    "radioactive": "nonradioactive",
    "raise": "lower",
    "raised": "lowered",
    "rarely": "often",
    "rational": "irrational",
    "ready": "unready",
    "real": "unreal",
    "realistic": "unrealistic",
    "reality": "unreality",
    "rear": "front",
    "reassure": "worry",
    "reassuring": "unreassuring",
    "recall": "issue",
    "recede": "advance",
    "reciprocal": "nonreciprocal",
    "record": "erase",
    "recoverable": "unrecoverable",
    "reflective": "nonreflective",
    "refrain": "act",
    "refuse": "accept",
    "regenerate": "unregenerate",
    "regress": "progress",
    "regressive": "progressive",
    "regular": "irregular",
    "regularity": "irregularity",
    "regulate": "deregulate",
    "regulated": "unregulated",
    "rehabilitate": "purge",
    "reject": "admit",
    "rejection": "acceptance",
    "rejuvenate": "age",
    "related": "unrelated",
    "relative": "absolute",
    "relaxed": "tense",
    "relevant": "irrelevant",
    "reliability": "unreliability",
    "reliable": "unreliable",
    "religious": "irreligious",
    "remarkably": "unremarkably",
    "remember": "forget",
    "repair": "break",
    "reported": "unreported",
    "representative": "nonrepresentative",
    "repulsion": "attraction",
    "reputable": "disreputable",
    "repute": "disrepute",
    "requisition": "derequisition",
    "resentful": "unresentful",
    "reserved": "unreserved",
    "resident": "nonresident",
    "resist": "surrender",
    "resolute": "irresolute",
    "resolutely": "irresolutely",
    "resolution": "preparation",
    "respect": "disrespect",
    "respectability": "unrespectability",
    "respectable": "unrespectable",
    "respectful": "disrespectful",
    "responsibility": "irresponsibility",
    "responsible": "irresponsible",
    "responsive": "unresponsive",
    "rest": "be active",
    "restful": "restless",
    "restrained": "unrestrained",
    "restraint": "unrestraint",
    "restrict": "derestrict",
    "restricted": "unrestricted",
    "restrictive": "unrestrictive",
    "retail": "wholesale",
    "retentive": "unretentive",
    "retroactive": "proactive",
    "retrograde": "anterograde",
    "retrospective": "prospective",
    "reverence": "irreverence",
    "reverent": "irreverent",
    "reversal": "affirmation",
    "reverse": "obverse",
    "revolutionary": "counterrevolutionary",
    "reward": "penalty",
    "rhetorical": "unrhetorical",
    "rhythmical": "unrhythmical",
    "ribbed": "ribless",
    "ride": "walk",
    "righteous": "unrighteous",
    "rigid": "nonrigid",
    "ripe": "green",
    "rise": "set",
    "rising": "falling",
    "robust": "frail",
    "rotor": "stator",
    "rough": "smooth",
    "roughness": "smoothness",
    "round": "square",
    "rounded": "angular",
    "rugged": "delicate",
    "running": "passing",
    "rural": "urban",
    "rush": "linger",
    "sacred": "profane",
    "saddle": "unsaddle",
    "sadly": "happily",
    "sadness": "happiness",
    "safe": "out",
    "safety": "danger",
    "salient": "re-entrant",
    "salty": "fresh",
    "sameness": "difference",
    "sane": "insane",
    "sanitary": "unsanitary",
    "sanity": "insanity",
    "satisfaction": "dissatisfaction",
    "satisfactorily": "unsatisfactorily",
    "saturated": "unsaturated",
    "savory": "unsavory",
    "scarce": "abundant",
    "scarcity": "abundance",
    "scholarly": "unscholarly",
    "scientific": "unscientific",
    "scramble": "unscramble",
    "screw": "unscrew",
    "scrupulous": "unscrupulous",
    "seal": "unseal",
    "seamless": "seamed",
    "seasoned": "unseasoned",
    "secondary": "primary",
    "sectarian": "nonsectarian",
    "secular": "religious",
    "security": "insecurity",
    "sedate": "stimulate",
    "seductive": "unseductive",
    "segregate": "desegregate",
    "segregated": "integrated",
    "segregation": "integration",
    "selfish": "unselfish",
    "selfishness": "unselfishness",
    "sell": "buy",
    "senior": "junior",
    "sensational": "unsensational",
    "sensibility": "insensibility",
    "sensitive": "insensitive",
    "sensory": "extrasensory",
    "sentient": "insentient",
    "separate": "joint",
    "separation": "union",
    "septic": "antiseptic",
    "seriousness": "frivolity",
    "service": "disservice",
    "serviceable": "unserviceable",
    "servile": "unservile",
    "set": "rise",
    "settled": "unsettled",
    "sexy": "unsexy",
    "shapely": "unshapely",
    "sharpen": "soften",
    "sharpness": "dullness",
    "short": "tall",
    "shorten": "lengthen",
    "shortness": "tallness",
    "shout": "whisper",
    "show": "hide",
    "shrink": "stretch",
    "shut": "open",
    "side": "bottom",
    "significance": "insignificance",
    "significant": "nonsignificant",
    "similar": "dissimilar",
    "similarity": "dissimilarity",
    "simple": "compound",
    "simplify": "complicate",
    "sincere": "insincere",
    "sincerity": "insincerity",
    "single": "multiple",
    "singly": "multiply",
    "singular": "plural",
    "sink": "source",
    "sister": "brother",
    "skilled": "unskilled",
    "sleep": "wake",
    "sleeping": "waking",
    "sleeveless": "sleeved",
    "slow": "fast",
    "slowly": "quickly",
    "small": "large",
    "smoker": "nonsmoker",
    "smoky": "smokeless",
    "smoothness": "roughness",
    "snarl": "unsnarl",
    "sociable": "unsociable",
    "social": "unsocial",
    "socialism": "capitalism",
    "softness": "sharpness",
    "solid": "hollow",
    "solidity": "hollowness",
    "solubility": "insolubility",
    "soluble": "insoluble",
    "solvency": "insolvency",
    "solvent": "insolvent",
    "son": "daughter",
    "soothe": "irritate",
    "sorrow": "joy",
    "sorrowful": "joyful",
    "sound": "unsound",
    "soundness": "unsoundness",
    "sour": "sweeten",
    "source": "sink",
    "speaking": "nonspeaking",
    "specialist": "generalist",
    "specialize": "diversify",
    "specific": "nonspecific",
    "spherical": "nonspherical",
    "spoken": "written",
    "sporadic": "continual",
    "spread": "gather",
    "square": "round",
    "stability": "instability",
    "stable": "unstable",
    "staccato": "legato",
    "stale": "fresh",
    "stand": "yield",
    "standard": "nonstandard",
    "standing": "seated",
    "staple": "unstaple",
    "starboard": "larboard",
    "starry": "starless",
    "start": "stop",
    "stator": "rotor",
    "stay": "move",
    "steady": "unsteady",
    "steep": "gradual",
    "sterile": "fertile",
    "stiffen": "loosen",
    "stifle": "stimulate",
    "stingy": "generous",
    "stop": "start",
    "stormy": "calm",
    "straight": "curly",
    "straighten": "bend",
    "stranger": "acquaintance",
    "strap": "unstrap",
    "strength": "weakness",
    "strengthen": "weaken",
    "strengthening": "weakening",
    "stretch": "shrink",
    "string": "unstring",
    "strongly": "weakly",
    "stuck": "unstuck",
    "studied": "unstudied",
    "studio": "location",
    "stuff": "unstuff",
    "stupid": "smart",
    "stupidity": "intelligence",
    "stylish": "styleless",
    "subjective": "objective",
    "submersible": "surface ship",
    "subordinate": "insubordinate",
    "subordination": "insubordination",
    "subsequent": "antecedent",
    "substantive": "adjective",
    "subtract": "add",
    "subtraction": "addition",
    "succeed": "fail",
    "succeeding": "preceding",
    "success": "failure",
    "successful": "unsuccessful",
    "succumb": "survive",
    "sudden": "gradual",
    "suffer": "be well",
    "sufficiency": "insufficiency",
    "sufficient": "insufficient",
    "sufficiently": "insufficiently",
    "suffix": "prefix",
    "sunrise": "sunset",
    "sunset": "sunrise",
    "superficial": "profound",
    "superhuman": "subhuman",
    "superior": "inferior",
    "superiority": "inferiority",
    "supernatural": "natural",
    "supply": "demand",
    "supported": "unsupported",
    "surface": "overhead",
    "surprised": "unsurprised",
    "surprising": "unsurprising",
    "surrender": "resist",
    "survive": "succumb",
    "susceptibility": "unsusceptibility",
    "susceptible": "unsusceptible",
    "suspected": "unsuspected",
    "sweet": "sour",
    "sweeten": "sour",
    "symmetrical": "asymmetrical",
    "symmetry": "asymmetry",
    "sympathetic": "unsympathetic",
    "synchronize": "desynchronize",
    "synchronous": "asynchronous",
    "synergistic": "antagonistic",
    "synonym": "antonym",
    "synonymous": "antonymous",
    "synthesis": "analysis",
    "synthetic": "analytic",
    "systematic": "unsystematic",
    "systematically": "unsystematically",
    "tail": "head",
    "talented": "untalented",
    "talk": "keep quiet",
    "tall": "short",
    "tangled": "untangled",
    "tanned": "untanned",
    "tardiness": "punctuality",
    "tasteful": "tasteless",
    "tasteless": "tasty",
    "tasty": "tasteless",
    "tearful": "tearless",
    "technical": "nontechnical",
    "temperance": "intemperance",
    "temperate": "intemperate",
    "tempered": "untempered",
    "temporarily": "permanently",
    "tender": "tough",
    "tense": "relax",
    "terminal": "intermediate",
    "terrestrial": "amphibious",
    "territorial": "nonterritorial",
    "theatrical": "untheatrical",
    "theism": "atheism",
    "theoretical": "applied",
    "thermal": "nonthermal",
    "thick": "thin",
    "thicken": "thin",
    "thickness": "thinness",
    "thin": "thicken",
    "thirsty": "hungry",
    "thoughtful": "thoughtless",
    "thoughtfulness": "unthoughtfulness",
    "thoughtless": "thoughtful",
    "thrifty": "wasteful",
    "tide": "ebb",
    "tie": "untie",
    "tightness": "looseness",
    "timeliness": "untimeliness",
    "timid": "brave",
    "timidity": "boldness",
    "tire": "refresh",
    "tired": "rested",
    "tolerance": "intolerance",
    "tolerant": "intolerant",
    "tonic": "atonic",
    "toothed": "toothless",
    "toothless": "toothed",
    "top": "bottom",
    "touched": "untouched",
    "tough": "tender",
    "toxic": "nontoxic",
    "tractable": "intractable",
    "traditional": "nontraditional",
    "tragedy": "comedy",
    "trained": "untrained",
    "transitive": "intransitive",
    "transparency": "opacity",
    "travel": "stay in place",
    "tributary": "distributary",
    "true": "false",
    "trust": "mistrust",
    "truth": "falsity",
    "truthful": "untruthful",
    "truthfulness": "untruthfulness",
    "tune": "untune",
    "twine": "untwine",
    "twist": "untwist",
    "type": "antitype",
    "typically": "atypically",
    "ugliness": "beauty",
    "ugly": "beautiful",
    "ultimate": "proximate",
    "unable": "able",
    "unacceptable": "acceptable",
    "unaccompanied": "accompanied",
    "unacknowledged": "acknowledged",
    "unaltered": "altered",
    "unambiguous": "ambiguous",
    "unarmed": "armed",
    "unassisted": "assisted",
    "unattached": "attached",
    "unattractive": "attractive",
    "unauthorized": "authorized",
    "unaware": "aware",
    "unbalanced": "balanced",
    "unbelief": "belief",
    "unborn": "born",
    "unbound": "bound",
    "unbreakable": "breakable",
    "unbroken": "broken",
    "uncertain": "certain",
    "uncertainty": "certainty",
    "unchangeable": "changeable",
    "unchanged": "changed",
    "uncle": "aunt",
    "unclean": "clean",
    "uncomfortable": "comfortable",
    "uncommon": "common",
    "uncompromising": "compromising",
    "unconcerned": "concerned",
    "unconfirmed": "confirmed",
    "unconnected": "connected",
    "unconscious": "conscious",
    "unconsciousness": "consciousness",
    "unconstitutional": "constitutional",
    "uncontested": "contested",
    "uncontrolled": "controlled",
    "unconventional": "conventional",
    "unconvinced": "convinced",
    "uncover": "cover",
    "uncritical": "critical",
    "uncut": "cut",
    "undefined": "defined",
    "undeniable": "deniable",
    "underestimate": "overestimate",
    "underpay": "overpay",
    "understood": "ununderstood",
    "undesirable": "desirable",
    "undeveloped": "developed",
    "undress": "dress",
    "undue": "due",
    "unearned": "earned",
    "uneasy": "easy",
    "uneducated": "educated",
    "unemployed": "employed",
    "unencumbered": "encumbered",
    "unequal": "equal",
    "unequivocal": "equivocal",
    "uneven": "even",
    "uneventful": "eventful",
    "unexpected": "expected",
    "unfair": "fair",
    "unfairness": "fairness",
    "unfaithful": "faithful",
    "unfamiliar": "familiar",
    "unfavorable": "favorable",
    "unfinished": "finished",
    "unfold": "fold",
    "unforgiving": "forgiving",
    "unfortunate": "fortunate",
    "unfriendly": "friendly",
    "unfurnished": "furnished",
    "ungrateful": "grateful",
    "unhappiness": "happiness",
    "unhappy": "happy",
    "unhealthy": "healthy",
    "unholy": "holy",
    "uniform": "multiform",
    "uniformity": "nonuniformity",
    "unimportant": "important",
    "unimproved": "improved",
    "uninformed": "informed",
    "uninhabited": "inhabited",
    "unintelligible": "intelligible",
    "unintended": "intended",
    "unintentionally": "intentionally",
    "uninterested": "interested",
    "uninteresting": "interesting",
    "union": "nonunion",
    "unitary": "federal",
    "unite": "divide",
    "united": "divided",
    "universal": "particular",
    "unjust": "just",
    "unkind": "kind",
    "unknowable": "knowable",
    "unknown": "known",
    "unlawful": "lawful",
    "unlike": "like",
    "unlimited": "limited",
    "unloaded": "loaded",
    "unlock": "lock",
    "unlucky": "lucky",
    "unmanageable": "manageable",
    "unmarked": "marked",
    "unmarried": "married",
    "unmask": "mask",
    "unmitigated": "mitigated",
    "unmoved": "moved",
    "unnatural": "natural",
    "unnecessary": "necessary",
    "unnoticed": "noticed",
    "unobstructed": "obstructed",
    "unobtrusive": "obtrusive",
    "unoccupied": "occupied",
    "unofficial": "official",
    "unopposed": "opposed",
    "unorganized": "organized",
    "unorthodox": "orthodox",
    "unpack": "pack",
    "unpaid": "paid",
    "unpleasant": "pleasant",
    "unpopular": "popular",
    "unprecedented": "precedented",
    "unpredictable": "predictable",
    "unprepared": "prepared",
    "unpretentious": "pretentious",
    "unproductive": "productive",
    "unprofitable": "profitable",
    "unprotected": "protected",
    "unpublished": "published",
    "unquestionable": "questionable",
    "unreal": "real",
    "unrealistic": "realistic",
    "unregistered": "registered",
    "unregulated": "regulated",
    "unrelated": "related",
    "unreliable": "reliable",
    "unrepentant": "repentant",
    "unrestrained": "restrained",
    "unrestricted": "restricted",
    "unsatisfactory": "satisfactory",
    "unsavory": "savory",
    "unscientific": "scientific",
    "unscrupulous": "scrupulous",
    "unselfish": "selfish",
    "unsettled": "settled",
    "unspecified": "specified",
    "unstable": "stable",
    "unsteady": "steady",
    "unsuccessful": "successful",
    "unsupported": "supported",
    "unsympathetic": "sympathetic",
    "unthinkable": "thinkable",
    "untidy": "tidy",
    "untie": "tie",
    "untouched": "touched",
    "untrained": "trained",
    "untrustworthy": "trustworthy",
    "unusual": "usual",
    "unveil": "veil",
    "unwary": "wary",
    "unwelcome": "welcome",
    "unwilling": "willing",
    "unwillingly": "willingly",
    "unwillingness": "willingness",
    "unwind": "wind",
    "unwitting": "witting",
    "unwittingly": "wittingly",
    "unworthy": "worthy",
    "unwritten": "written",
    "upland": "lowland",
    "upstairs": "downstairs",
    "upwards": "downwards",
    "urban": "rural",
    "usefully": "uselessly",
    "usefulness": "uselessness",
    "useless": "useful",
    "usual": "unusual",
    "utility": "inutility",
    "utopian": "dystopian",
    "valuable": "worthless",
    "variable": "invariable",
    "varied": "unvaried",
    "vascular": "avascular",
    "veer": "back",
    "veil": "unveil",
    "veiled": "unveiled",
    "veracity": "mendacity",
    "verbal": "numerical",
    "vernal": "autumnal",
    "vertical": "horizontal",
    "victory": "defeat",
    "violent": "nonviolent",
    "violently": "nonviolently",
    "virtuous": "wicked",
    "visibility": "invisibility",
    "visible": "invisible",
    "visibly": "invisibly",
    "vocal": "instrumental",
    "voice": "devoice",
    "volley": "ground stroke",
    "voluntarily": "involuntarily",
    "voluntary": "involuntary",
    "volunteer": "draftee",
    "vomit": "keep down",
    "vowel": "consonant",
    "vulnerability": "invulnerability",
    "vulnerable": "invulnerable",
    "wake": "sleep",
    "walk": "ride",
    "wane": "wax",
    "waning": "waxing",
    "war": "make peace",
    "wary": "unwary",
    "waste": "conserve",
    "wasteful": "thrifty",
    "wax": "wane",
    "weakly": "strongly",
    "weakness": "strength",
    "wealth": "poverty",
    "weave": "unweave",
    "weed": "cultivated plant",
    "weedy": "weedless",
    "weightless": "weighty",
    "weighty": "weightless",
    "welcome": "say farewell",
    "western": "eastern",
    "wet": "dry",
    "whisper": "shout",
    "white": "black",
    "wholesome": "unwholesome",
    "wholly": "partly",
    "wicked": "virtuous",
    "wide": "narrow",
    "widen": "narrow",
    "wife": "husband",
    "wild": "tame",
    "willingly": "unwillingly",
    "willingness": "unwillingness",
    "wind": "unwind",
    "winged": "wingless",
    "winner": "loser",
    "winnings": "losings",
    "wintry": "autumnal",
    "wire": "unwire",
    "wireless": "wired",
    "wisdom": "folly",
    "wise": "foolish",
    "withdraw": "deposit",
    "woman": "man",
    "womanly": "unwomanly",
    "woody": "nonwoody",
    "work": "idle",
    "worker": "nonworker",
    "worldly": "unworldly",
    "worn": "new",
    "worry": "reassure",
    "worse": "better",
    "worsening": "bettering",
    "worth": "worthlessness",
    "worthless": "valuable",
    "worthy": "unworthy",
    "wrap": "unwrap",
    "wrinkled": "unwrinkled",
    "written": "unwritten",
    "wrong": "right",
    "wrongly": "right",
    "yea": "nay",
    "yield": "stand",
    "yoke": "unyoke",
    "young": "old",
    "zenith": "nadir",
    "nonabsorbent": "absorbent",
    "decelerate": "accelerate",
    "deceleration": "acceleration",
    "deliberately": "accidentally",
    "inaccuracy": "accuracy",
    "unaccustomed": "accustomed",
    "alkalinity": "acidity",
    "stative": "active",
    "chronically": "acutely",
    "unadaptable": "adaptable",
    "take away": "bring",
    "subtractive": "additive",
    "nonadhesive": "adhesive",
    "look down on": "admire",
    "inadmissibility": "admissibility",
    "retreat": "advance",
    "disadvantageous": "advantageous",
    "unadventurous": "adventurous",
    "inadvisable": "advisable",
    "inaesthetic": "aesthetic",
    "consanguinity": "affinity",
    "negate": "affirm",
    "unafraid": "afraid",
    "unaggressive": "aggressive",
    "unagitated": "agitated",
    "gnostic": "agnostic",
    "afloat": "aground",
    "unalarming": "alarming",
    "unalert": "alert",
    "nonaligned": "aligned",
    "nonalignment": "alignment",
    "unalike": "alike",
    "aliquant": "aliquot",
    "dead": "living",
    "unambiguity": "ambiguity",
    "unambitious": "ambitious",
    "meagerly": "amply",
    "heterologous": "analogous",
    "digital": "analogue",
    "synthesize": "analyze",
    "unangry": "angry",
    "hydrous": "anhydrous",
    "unanimated": "animated",
    "onymous": "anonymous",
    "agonist": "antagonist",
    "synergist": "antagonist",
    "conciliatory": "antagonistic",
    "antapex": "apex",
    "unapologetic": "apologetic",
    "inapplicability": "applicability",
    "disapprobation": "approbation",
    "inaptitude": "aptitude",
    "unargumentative": "argumentative",
    "disarmament": "armament",
    "armless": "armed",
    "unarmored": "armored",
    "disarrange": "arrange",
    "disarranged": "arranged",
    "artless": "artful",
    "inarticulate": "articulate",
    "unashamed": "ashamed",
    "disassemble": "assemble",
    "disassembly": "assembly",
    "dissimilate": "assimilate",
    "dissociate": "associate",
    "disassociation": "association",
    "stigmatism": "astigmatism",
    "nonastringent": "astringent",
    "nonattendance": "attendance",
    "inattentive": "attentive",
    "unattractiveness": "attractiveness",
    "unattributable": "attributable",
    "inauspicious": "auspicious",
    "cause to sleep": "awaken",
    "gracefulness": "awkwardness",
    "well": "ill",
    "imbalance": "balance",
    "unbalance": "balance",
    "unbar": "bar",
    "nonbearing": "bearing",
    "uglify": "beautify",
    "unbelt": "belt",
    "unbend": "bend",
    "malevolence": "benevolence",
    "disinherit": "bequeath",
    "annual": "perennial",
    "little": "big",
    "unbind": "bind",
    "heterosexual": "bisexual",
    "absolve": "blame",
    "sighted": "blind",
    "unblock": "block",
    "brunet": "blond",
    "unbolt": "bolt",
    "boneless": "bony",
    "applaud": "boo",
    "bottomed": "bottomless",
    "clear": "opaque",
    "free": "obstruct",
    "plucked": "bowed",
    "unbox": "box",
    "patronise": "boycott",
    "unbraid": "braid",
    "keep": "lose",
    "unbridle": "bridle",
    "dullness": "brightness",
    "sisterly": "brotherly",
    "unbuckle": "buckle",
    "unburden": "burden",
    "unburied": "buried",
    "unbutton": "button",
    "agitate": "calm",
    "incapability": "capability",
    "liberator": "captor",
    "ordinal": "cardinal",
    "careless": "careful",
    "carelessly": "carefully",
    "carefulness": "carelessness",
    "herbivorous": "carnivorous",
    "anabolism": "catabolism",
    "cephalic": "caudal",
    "incaution": "caution",
    "incautious": "cautious",
    "incautiously": "cautiously",
    "noncellular": "cellular",
    "peripheral": "central",
    "marginality": "centrality",
    "decentralization": "centralization",
    "decentralize": "centralize",
    "peripherally": "centrally",
    "centripetal": "centrifugal",
    "decertify": "certify",
    "unchain": "chain",
    "uncharacteristic": "characteristic",
    "pay cash": "charge",
    "uncharitable": "charitable",
    "unchartered": "chartered",
    "cheerlessness": "cheerfulness",
    "uncheerfulness": "cheerfulness",
    "achromatic": "chromatic",
    "diatonic": "chromatic",
    "acute": "obtuse",
    "noncitizen": "citizen",
    "sidereal": "civil",
    "uncivil": "civil",
    "serviceman": "civilian",
    "incivility": "civility",
    "noncivilized": "civilized",
    "obfuscate": "clarify",
    "unclasp": "clasp",
    "nonclassical": "classical",
    "declassification": "classification",
    "declassify": "classify",
    "uncleanliness": "cleanliness",
    "unclearness": "clearness",
    "unclip": "clip",
    "unclog": "clog",
    "unclutter": "clutter",
    "incoherence": "coherence",
    "uncoil": "coil",
    "uncoiled": "coiled",
    "hotness": "coldness",
    "uncollected": "collected",
    "distributive": "collective",
    "black-and-white": "color",
    "colorlessness": "color",
    "uncolored": "colored",
    "colorful": "colorless",
    "uncombined": "combined",
    "noncombustible": "combustible",
    "incommensurate": "commensurate",
    "noncommercial": "commercial",
    "uncommitted": "committed",
    "individual": "common",
    "excommunicate": "communicate",
    "uncommunicative": "communicative",
    "loose": "compact",
    "incomparable": "comparable",
    "uncompassionate": "compassionate",
    "incompatibility": "compatibility",
    "noncompetitive": "competitive",
    "simplicity": "complexity",
    "discomposed": "composed",
    "discomposure": "composure",
    "incomprehension": "comprehension",
    "noncomprehensive": "comprehensive",
    "decompress": "compress",
    "incompressible": "compressible",
    "decompression": "compression",
    "pro": "con",
    "unconcealed": "concealed",
    "deconcentrate": "concentrate",
    "unconcern": "concern",
    "prolix": "concise",
    "unconditional": "conditional",
    "unconditionally": "conditionally",
    "unconditioned": "conditioned",
    "insulator": "conductor",
    "diffidence": "confidence",
    "diffident": "confident",
    "invasive": "confined",
    "unconfined": "confined",
    "nonconformity": "conformity",
    "uncongenial": "congenial",
    "unconscientious": "conscientious",
    "inconsequence": "consequence",
    "inconsiderable": "considerable",
    "inconsistent": "consistent",
    "inconstancy": "constancy",
    "inconstant": "constant",
    "misconstruction": "construction",
    "decontaminate": "contaminate",
    "uncontaminated": "contaminated",
    "decontamination": "contamination",
    "estimable": "contemptible",
    "incontinent": "continent",
    "intercontinental": "continental",
    "discontinuation": "continuation",
    "discontinued": "continued",
    "uncontroversial": "controversial",
    "inconvenience": "convenience",
    "nuclear": "conventional",
    "inconvertible": "convertible",
    "acquit": "convict",
    "acquittal": "conviction",
    "unconvincing": "convincing",
    "warm": "cool",
    "uncooperative": "cooperative",
    "uncork": "cork",
    "incorporeal": "corporeal",
    "incorrectness": "correctness",
    "incorrupt": "corrupt",
    "medulla": "cortex",
    "uncouple": "couple",
    "discourteous": "courteous",
    "discourtesy": "courtesy",
    "bare": "covered",
    "brave": "timid",
    "uncrate": "crate",
    "uncreative": "creative",
    "incredibility": "credibility",
    "incredible": "credible",
    "decrescendo": "crescendo",
    "uncross": "cross",
    "uncrossed": "crossed",
    "uncrowded": "crowded",
    "noncrucial": "crucial",
    "noncrystalline": "crystalline",
    "uncultivated": "cultivated",
    "noncurrent": "current",
    "straight line": "curve",
    "anticyclone": "cyclone",
    "undeceive": "deceive",
    "interrogatory": "declaratory",
    "indecorum": "decorum",
    "increasing": "decreasing",
    "pay up": "default",
    "undefeated": "defeated",
    "inflate": "deflate",
    "disinflation": "deflation",
    "lend oneself": "defy",
    "aggrade": "degrade",
    "undemanding": "demanding",
    "undemonstrative": "demonstrative",
    "appreciate": "depreciate",
    "elate": "depress",
    "elation": "depression",
    "ascending": "descending",
    "undescriptive": "descriptive",
    "undesigned": "designed",
    "undesirability": "desirability",
    "undesirous": "desirous",
    "constructive": "destructive",
    "attached": "unattached",
    "recuperate": "deteriorate",
    "indeterminable": "determinable",
    "undetermined": "determined",
    "nondevelopment": "development",
    "conform": "deviate",
    "be born": "die",
    "undignified": "dignified",
    "undiluted": "diluted",
    "undiplomatic": "diplomatic",
    "indirectly": "directly",
    "appear": "disappear",
    "indiscernible": "discernible",
    "undiscerning": "discerning",
    "indiscipline": "discipline",
    "indiscreet": "discreet",
    "indiscriminate": "discriminate",
    "undiscriminating": "discriminating",
    "ingenuous": "disingenuous",
    "like": "unlike",
    "liked": "disliked",
    "flatter": "disparage",
    "indispose": "dispose",
    "mesial": "distal",
    "undiversified": "diversified",
    "specialise": "diversify",
    "invest": "divest",
    "stubborn": "docile",
    "undock": "dock",
    "undomestic": "domestic",
    "recessive": "dominant",
    "ventral": "dorsal",
    "undrained": "drained",
    "undramatic": "dramatic",
    "nondriver": "driver",
    "soberness": "drunkenness",
    "phlegmy": "dry",
    "wetness": "dryness",
    "bright": "dull",
    "lively": "dull",
    "sharp": "dull",
    "undynamic": "dynamic",
    "uneager": "eager",
    "concentricity": "eccentricity",
    "inedible": "edible",
    "ineffectually": "effectually",
    "inefficacious": "efficacious",
    "inefficacy": "efficacy",
    "inelasticity": "elasticity",
    "dejected": "elated",
    "inelegance": "elegance",
    "inelegant": "elegant",
    "disembark": "embark",
    "disembarrassment": "embarrassment",
    "immigrate": "emigrate",
    "absorb": "emit",
    "unemotional": "emotional",
    "employee": "employer",
    "unemployment": "employment",
    "disenchant": "enchant",
    "disenchanted": "enchanted",
    "decode": "encode",
    "ecdemic": "epidemic",
    "unendowed": "endowed",
    "non-engagement": "engagement",
    "unenlightenment": "enlightenment",
    "deaden": "enliven",
    "deprive": "enrich",
    "impoverish": "enrich",
    "drop out": "enter",
    "unenterprising": "enterprising",
    "unequally": "equally",
    "disequilibrium": "equilibrium",
    "inequity": "equity",
    "nonequivalence": "equivalence",
    "unerect": "erect",
    "de-escalate": "escalate",
    "exoteric": "esoteric",
    "inessential": "essential",
    "unestablished": "established",
    "disesteem": "esteem",
    "unethical": "ethical",
    "dysgenics": "eugenics",
    "dysphemism": "euphemism",
    "unexcitable": "excitable",
    "unexcited": "excited",
    "unexciting": "exciting",
    "nonexempt": "exempt",
    "unexhausted": "exhausted",
    "nonexistence": "existence",
    "unexpansive": "expansive",
    "repatriate": "expatriate",
    "inexpediency": "expediency",
    "inexpedient": "expedient",
    "unexpired": "expired",
    "implode": "explode",
    "nonexplosive": "explosive",
    "unextended": "extended",
    "intensive": "extensive",
    "unfairly": "fairly",
    "correct": "incorrect",
    "strange": "familiar",
    "unfamiliarity": "familiarity",
    "unfashionable": "fashionable",
    "unfasten": "fasten",
    "nonfatal": "fatal",
    "nonfat": "fatty",
    "fearlessness": "fear",
    "fearlessly": "fearfully",
    "infeasibility": "feasibility",
    "afebrile": "febrile",
    "starve": "feed",
    "infelicity": "felicity",
    "androgynous": "male",
    "literal": "figurative",
    "nonfinancial": "financial",
    "nonfissile": "fissile",
    "unfitness": "fitness",
    "unfixed": "fixed",
    "flash-forward": "flashback",
    "contrasty": "flat",
    "natural": "unnatural",
    "unflattering": "flattering",
    "inflexibility": "flexibility",
    "inflexible": "flexible",
    "flowerless": "flowering",
    "disfluency": "fluency",
    "informality": "formality",
    "unformed": "formed",
    "whole": "half",
    "malodorous": "fragrant",
    "salaried": "freelance",
    "unfreeze": "freeze",
    "unfriendliness": "friendliness",
    "serious": "frivolous",
    "unfrozen": "frozen",
    "unfruitful": "fruitful",
    "malfunction": "function",
    "nonfunctional": "functional",
    "defuse": "fuse",
    "fall back": "gain",
    "reduce": "gain",
    "specifically": "generally",
    "consumptive": "generative",
    "varietal": "generic",
    "stinginess": "generosity",
    "ungenerous": "generous",
    "counterfeit": "genuine",
    "sad": "glad",
    "evilness": "goodness",
    "awkward": "graceful",
    "ungracious": "gracious",
    "ungraciously": "graciously",
    "grassless": "grassy",
    "ingratitude": "gratitude",
    "levitation": "gravitation",
    "levity": "gravity",
    "ungregarious": "gregarious",
    "ungrudgingly": "grudgingly",
    "hairless": "hairy",
    "unhappily": "happily",
    "soften": "sharpen",
    "soft": "loud",
    "software": "hardware",
    "harmless": "harmful",
    "unharness": "harness",
    "unhealthful": "healthful",
    "lightly": "heavily",
    "unhelpful": "helpful",
    "aestivate": "hibernate",
    "nonhierarchical": "hierarchical",
    "low": "high",
    "low spirits": "high",
    "let go of": "hold",
    "unholiness": "holiness",
    "allopathic": "homeopathic",
    "allopathy": "homeopathy",
    "heterogeneous": "homogeneous",
    "autologous": "homologous",
    "dishonorable": "honorable",
    "unhook": "hook",
    "hopefulness": "hopelessness",
    "inhospitality": "hospitality",
    "nonhuman": "human",
    "inhumane": "humane",
    "humorless": "humorous",
    "unhurried": "hurried",
    "run": "idle",
    "know": "ignore",
    "legitimate": "illegitimate",
    "licit": "illicit",
    "literate": "illiterate",
    "wellness": "illness",
    "mature": "immature",
    "measurably": "immeasurably",
    "mediacy": "immediacy",
    "emersion": "immersion",
    "partial": "impartial",
    "penetrable": "impenetrable",
    "beseeching": "imperative",
    "perfectly": "imperfectly",
    "pervious": "impervious",
    "placable": "implacable",
    "unimportance": "importance",
    "possible": "impossible",
    "potence": "impotence",
    "unimpressionable": "impressionable",
    "pure": "impure",
    "activate": "inactivate",
    "activation": "inactivation",
    "advertently": "inadvertently",
    "alienable": "inalienable",
    "appropriate": "inappropriate",
    "exaugural": "inaugural",
    "outbred": "inbred",
    "calculable": "incalculable",
    "disincentive": "incentive",
    "clement": "inclement",
    "disinclination": "inclination",
    "disinclined": "inclined",
    "exclusive": "inclusive",
    "outgo": "income",
    "outgoing": "incoming",
    "comprehensible": "incomprehensible",
    "conclusive": "inconclusive",
    "congruous": "incongruous",
    "credulous": "incredulous",
    "destructible": "indestructible",
    "contraindicate": "indicate",
    "contraindication": "indication",
    "direct": "retrograde",
    "dispensable": "indispensable",
    "distinct": "indistinct",
    "commonality": "individuality",
    "spontaneous": "induced",
    "nonindulgent": "indulgent",
    "evitable": "inevitable",
    "exact": "inexact",
    "excusable": "inexcusable",
    "exhaustible": "inexhaustible",
    "explicable": "inexplicable",
    "fallibility": "infallibility",
    "noninfectious": "infectious",
    "fertility": "infertility",
    "finitely": "infinitely",
    "uninfluential": "influential",
    "efflux": "influx",
    "formal": "informal",
    "hospitable": "inhospitable",
    "uninitiate": "initiate",
    "uninjured": "injured",
    "uninquiring": "inquiring",
    "secure": "insecure",
    "outside": "inside",
    "uninstructive": "instructive",
    "surmountable": "insurmountable",
    "tangible": "intangible",
    "differentiate": "integrate",
    "nonintellectual": "intellectual",
    "unintelligent": "intelligent",
    "unintelligibility": "intelligibility",
    "mild": "intense",
    "noninterference": "interference",
    "nonintervention": "intervention",
    "testate": "intestate",
    "tolerable": "intolerable",
    "sober": "intoxicated",
    "extrospective": "introspective",
    "extrusive": "intrusive",
    "protrusive": "intrusive",
    "unintrusive": "intrusive",
    "valid": "invalid",
    "validate": "invalidate",
    "uninviting": "inviting",
    "non-involvement": "involvement",
    "reconcilable": "irreconcilable",
    "reducible": "irreducible",
    "regularly": "irregularly",
    "reparable": "irreparable",
    "resistible": "irresistible",
    "reversible": "irreversible",
    "revocable": "irrevocable",
    "disjoin": "join",
    "joyless": "joyous",
    "juiceless": "juicy",
    "unkindness": "kindness",
    "unknot": "knot",
    "unknowingly": "knowingly",
    "have": "lack",
    "landless": "landed",
    "unlash": "lash",
    "earliness": "lateness",
    "costive": "laxative",
    "following": "leading",
    "leafless": "leafy",
    "tight": "leaky",
    "rich": "lean",
    "right": "wrongly",
    "illegibility": "legibility",
    "illegitimacy": "legitimacy",
    "crosswise": "lengthwise",
    "asset": "liability",
    "square shooter": "liar",
    "sit": "lie",
    "heavy": "light",
    "weigh down": "lighten",
    "unlikelihood": "likelihood",
    "unlikeness": "likeness",
    "cubic": "linear",
    "nonlinear": "linear",
    "unlined": "lined",
    "nonlinguistic": "linguistic",
    "figuratively": "literally",
    "tightening": "loosening",
    "break even": "profit",
    "win": "lose",
    "saved": "lost",
    "won": "lost",
    "softly": "loudly",
    "unloving": "loving",
    "disloyal": "loyal",
    "disloyalty": "loyalty",
    "unmake": "make",
    "unmalicious": "malicious",
    "benignancy": "malignancy",
    "fail": "pass",
    "unmanly": "manly",
    "immateriality": "materiality",
    "dematerialize": "materialize",
    "meaningful": "meaningless",
    "nonmechanical": "mechanical",
    "immediate": "mediate",
    "surgical": "medical",
    "unmelodious": "melodious",
    "nonmember": "member",
    "demerit": "merit",
    "nonmigratory": "migratory",
    "unmilitary": "military",
    "unmindful": "mindful",
    "unmindfulness": "mindfulness",
    "maximize": "minimize",
    "majuscule": "minuscule",
    "good fortune": "misfortune",
    "matched": "mismatched",
    "attend": "miss",
    "immobile": "mobile",
    "stabile": "mobile",
    "immobility": "mobility",
    "demobilization": "mobilization",
    "demobilize": "mobilize",
    "immoderate": "moderate",
    "immoderately": "moderately",
    "intensifying": "moderating",
    "immoderation": "moderation",
    "nonmodern": "modern",
    "old style": "modern",
    "immodest": "modest",
    "immodesty": "modesty",
    "unmodifiable": "modifiable",
    "unmodified": "modified",
    "motionlessness": "motion",
    "stand still": "move",
    "nonmoving": "moving",
    "still": "moving",
    "unmoving": "moving",
    "unilateral": "multilateral",
    "toadstool": "mushroom",
    "unmusical": "musical",
    "unmuzzle": "muzzle",
    "hyperopia": "myopia",
    "sophisticated": "naive",
    "widening": "narrowing",
    "nice": "nasty",
    "adopted": "native",
    "nonnative": "native",
    "artificially": "naturally",
    "unnaturally": "naturally",
    "unnecessarily": "necessarily",
    "obviate": "necessitate",
    "positive": "negative",
    "attend to": "neglect",
    "unneurotic": "neurotic",
    "oldness": "newness",
    "ignoble": "noble",
    "lowborn": "noble",
    "noblewoman": "nobleman",
    "antinode": "node",
    "paranormal": "normal",
    "abnormality": "normality",
    "unnoticeable": "noticeable",
    "disobediently": "obediently",
    "disoblige": "oblige",
    "nominative": "oblique",
    "nonobservance": "observance",
    "unobvious": "obvious",
    "inoffensive": "offensive",
    "onside": "offside",
    "closing": "opening",
    "inopportune": "opportune",
    "obligatorily": "optionally",
    "aboral": "oral",
    "disorganize": "organize",
    "disorient": "orient",
    "unoriginality": "originality",
    "unorthodoxy": "orthodoxy",
    "legalise": "outlaw",
    "inward": "outward",
    "clear up": "overcast",
    "undercharge": "overcharge",
    "subsurface": "overhead",
    "understate": "overstate",
    "understock": "overstock",
    "pleasure": "pain",
    "painlessly": "painfully",
    "unpainted": "painted",
    "unpalatable": "palatable",
    "impalpable": "palpable",
    "host": "parasite",
    "filial": "parental",
    "nonparticipation": "participation",
    "nonpartisan": "partisan",
    "passionless": "passionate",
    "matriarchal": "patriarchal",
    "unpatriotic": "patriotic",
    "unpeaceful": "peaceful",
    "unperceptive": "perceptive",
    "imperfect": "perfect",
    "aperiodic": "periodic",
    "imperishable": "perishable",
    "impermanence": "permanence",
    "unpermissive": "permissive",
    "unperplexed": "perplexed",
    "caducous": "persistent",
    "dissuasion": "persuasion",
    "dissuasive": "persuasive",
    "impiety": "piety",
    "unpin": "pin",
    "impious": "pious",
    "patterned": "plain",
    "unplanned": "planned",
    "implausibility": "plausibility",
    "unplayful": "playful",
    "unplowed": "plowed",
    "pointed": "pointless",
    "unpolished": "polished",
    "impoliteness": "politeness",
    "impolitic": "politic",
    "unpopularity": "popularity",
    "nonporous": "porous",
    "unportable": "portable",
    "impossibly": "possibly",
    "impotency": "potency",
    "impractical": "practical",
    "imprecise": "precise",
    "imprecisely": "precisely",
    "imprecision": "precision",
    "retarded": "precocious",
    "unprejudiced": "prejudiced",
    "full-term": "premature",
    "unpremeditated": "premeditated",
    "nonprescription": "prescription",
    "fresh": "stale",
    "let": "prevent",
    "unpriestly": "priestly",
    "posteriority": "priority",
    "underprivileged": "privileged",
    "improbability": "probability",
    "nonprofessional": "professional",
    "unprofessional": "professional",
    "demote": "promote",
    "demotion": "promotion",
    "improper": "proper",
    "unprophetic": "prophetic",
    "disproportion": "proportion",
    "disproportionate": "proportionate",
    "nonproprietary": "proprietary",
    "unprotective": "protective",
    "improvidence": "providence",
    "unprovocative": "provocative",
    "imprudence": "prudence",
    "unpunctual": "punctual",
    "unpunished": "punished",
    "rehabilitative": "punitive",
    "unqualified": "qualified",
    "accentual": "quantitative",
    "qualitative": "quantitative",
    "unquiet": "quiet",
    "noisily": "quietly",
    "unquietly": "quietly",
    "nonradioactive": "radioactive",
    "lowered": "raised",
    "often": "rarely",
    "unready": "ready",
    "unreality": "reality",
    "unreassuring": "reassuring",
    "nonreciprocal": "reciprocal",
    "unrecoverable": "recoverable",
    "nonreflective": "reflective",
    "unregenerate": "regenerate",
    "deregulate": "regulate",
    "unreliability": "reliability",
    "irreligious": "religious",
    "unremarkably": "remarkably",
    "unreported": "reported",
    "nonrepresentative": "representative",
    "derequisition": "requisition",
    "unresentful": "resentful",
    "unreserved": "reserved",
    "irresolute": "resolute",
    "irresolutely": "resolutely",
    "unrespectability": "respectability",
    "unrespectable": "respectable",
    "irresponsibility": "responsibility",
    "unresponsive": "responsive",
    "be active": "rest",
    "restless": "restful",
    "unrestraint": "restraint",
    "derestrict": "restrict",
    "unrestrictive": "restrictive",
    "wholesale": "retail",
    "unretentive": "retentive",
    "proactive": "retroactive",
    "anterograde": "retrograde",
    "irreverence": "reverence",
    "counterrevolutionary": "revolutionary",
    "unrhetorical": "rhetorical",
    "unrhythmical": "rhythmical",
    "ribless": "ribbed",
    "unrighteous": "righteous",
    "nonrigid": "rigid",
    "frail": "robust",
    "smooth": "rough",
    "delicate": "rugged",
    "unsaddle": "saddle",
    "out": "safe",
    "re-entrant": "salient",
    "unsanitary": "sanitary",
    "unsatisfactorily": "satisfactorily",
    "unsaturated": "saturated",
    "unscholarly": "scholarly",
    "unscramble": "scramble",
    "unscrew": "screw",
    "unseal": "seal",
    "seamed": "seamless",
    "unseasoned": "seasoned",
    "nonsectarian": "sectarian",
    "stimulate": "stifle",
    "unseductive": "seductive",
    "desegregate": "segregate",
    "integrated": "segregated",
    "unselfishness": "selfishness",
    "unsensational": "sensational",
    "insensibility": "sensibility",
    "insensitive": "sensitive",
    "extrasensory": "sensory",
    "insentient": "sentient",
    "frivolity": "seriousness",
    "unserviceable": "serviceable",
    "unservile": "servile",
    "unsexy": "sexy",
    "unshapely": "shapely",
    "longness": "shortness",
    "tallness": "shortness",
    "nonsignificant": "significant",
    "dissimilarity": "similarity",
    "insincere": "sincere",
    "insincerity": "sincerity",
    "unskilled": "skilled",
    "waking": "sleeping",
    "sleeved": "sleeveless",
    "fast": "slow",
    "nonsmoker": "smoker",
    "smokeless": "smoky",
    "unsnarl": "snarl",
    "unsociable": "sociable",
    "unsocial": "social",
    "capitalism": "socialism",
    "hollowness": "solidity",
    "insolubility": "solubility",
    "irritate": "soothe",
    "silence": "sound",
    "unsound": "sound",
    "unsoundness": "soundness",
    "nonspeaking": "speaking",
    "generalist": "specialist",
    "nonspecific": "specific",
    "nonspherical": "spherical",
    "legato": "staccato",
    "nonstandard": "standard",
    "seated": "standing",
    "unstaple": "staple",
    "larboard": "starboard",
    "starless": "starry",
    "crooked": "straight",
    "curly": "straight",
    "unstrap": "strap",
    "weaken": "strengthen",
    "weakening": "strengthening",
    "unstring": "string",
    "unstuck": "stuck",
    "unstudied": "studied",
    "unstuff": "stuff",
    "smart": "stupid",
    "styleless": "stylish",
    "nonsubmersible": "submersible",
    "surface ship": "submersible",
    "insubordinate": "subordinate",
    "insubordination": "subordination",
    "be well": "suffer",
    "profound": "superficial",
    "subhuman": "superhuman",
    "unsurprised": "surprised",
    "unsurprising": "surprising",
    "unsusceptibility": "susceptibility",
    "unsusceptible": "susceptible",
    "unsuspected": "suspected",
    "asymmetrical": "symmetrical",
    "desynchronize": "synchronize",
    "asynchronous": "synchronous",
    "antonym": "synonym",
    "antonymous": "synonymous",
    "unsystematic": "systematic",
    "unsystematically": "systematically",
    "untalented": "talented",
    "keep quiet": "talk",
    "untangled": "tangled",
    "untanned": "tanned",
    "tearless": "tearful",
    "nontechnical": "technical",
    "intemperance": "temperance",
    "intemperate": "temperate",
    "untempered": "tempered",
    "permanently": "temporarily",
    "relax": "tense",
    "extraterritorial": "territorial",
    "nonterritorial": "territorial",
    "untheatrical": "theatrical",
    "applied": "theoretical",
    "nonthermal": "thermal",
    "thinness": "thickness",
    "thoughtlessness": "thoughtfulness",
    "unthoughtfulness": "thoughtfulness",
    "looseness": "tightness",
    "untimeliness": "timeliness",
    "refresh": "tire",
    "rested": "tired",
    "atonic": "tonic",
    "nontoxic": "toxic",
    "nontraditional": "traditional",
    "intransitive": "transitive",
    "stay in place": "travel",
    "distributary": "tributary",
    "false": "true",
    "untruthful": "truthful",
    "untruthfulness": "truthfulness",
    "untune": "tune",
    "untwine": "twine",
    "untwist": "twist",
    "antitype": "type",
    "atypically": "typically",
    "able": "unable",
    "accompanied": "unaccompanied",
    "assisted": "unassisted",
    "attractive": "unattractive",
    "aware": "unaware",
    "born": "unborn",
    "certain": "uncertain",
    "comfortable": "uncomfortable",
    "compromising": "uncompromising",
    "conscious": "unconscious",
    "contested": "uncontested",
    "controlled": "uncontrolled",
    "critical": "uncritical",
    "deniable": "undeniable",
    "ununderstood": "understood",
    "developed": "undeveloped",
    "dress": "undress",
    "earned": "unearned",
    "employed": "unemployed",
    "encumbered": "unencumbered",
    "even": "uneven",
    "fairness": "unfairness",
    "finished": "unfinished",
    "furnished": "unfurnished",
    "multiform": "uniform",
    "nonuniformity": "uniformity",
    "disunion": "union",
    "nonunion": "union",
    "just": "unjust",
    "knowable": "unknowable",
    "known": "unknown",
    "loaded": "unloaded",
    "manageable": "unmanageable",
    "mitigated": "unmitigated",
    "moved": "unmoved",
    "necessary": "unnecessary",
    "noticed": "unnoticed",
    "obstructed": "unobstructed",
    "obtrusive": "unobtrusive",
    "paid": "unpaid",
    "precedented": "unprecedented",
    "predictable": "unpredictable",
    "pretentious": "unpretentious",
    "profitable": "unprofitable",
    "registered": "unregistered",
    "repentant": "unrepentant",
    "satisfactory": "unsatisfactory",
    "specified": "unspecified",
    "thinkable": "unthinkable",
    "tidy": "untidy",
    "trustworthy": "untrustworthy",
    "willing": "unwilling",
    "witting": "unwitting",
    "wittingly": "unwittingly",
    "downstairs": "upstairs",
    "downwards": "upwards",
    "uselessly": "usefully",
    "uselessness": "usefulness",
    "useful": "useless",
    "inutility": "utility",
    "dystopian": "utopian",
    "invariable": "variable",
    "unvaried": "varied",
    "avascular": "vascular",
    "unveiled": "veiled",
    "mendacity": "veracity",
    "autumnal": "wintry",
    "nonviolent": "violent",
    "nonviolently": "violently",
    "invisibly": "visibly",
    "devoice": "voice",
    "ground stroke": "volley",
    "involuntarily": "voluntarily",
    "draftee": "volunteer",
    "keep down": "vomit",
    "invulnerability": "vulnerability",
    "invulnerable": "vulnerable",
    "waxing": "waning",
    "make peace": "war",
    "unweave": "weave",
    "cultivated plant": "weed",
    "weedless": "weedy",
    "say farewell": "welcome",
    "eastern": "western",
    "unwholesome": "wholesome",
    "husband": "wife",
    "tame": "wild",
    "wingless": "winged",
    "loser": "winner",
    "losings": "winnings",
    "unwire": "wire",
    "wired": "wireless",
    "unwomanly": "womanly",
    "nonwoody": "woody",
    "nonworker": "worker",
    "unworldly": "worldly",
    "new": "worn",
    "better": "worse",
    "bettering": "worsening",
    "worthlessness": "worth",
    "unwrap": "wrap",
    "unwrinkled": "wrinkled",
    "unyoke": "yoke",
    "old": "young",
    "a la carte": "table d'hote",
    "a posteriori": "a priori",
    "a priori": "a posteriori",
    "abactinal": "actinal",
    "abaxial": "adaxial",
    "abducent": "adductive",
    "abducting": "adducent",
    "abient": "adient",
    "above": "to a lower place",
    "aboveboard": "dishonestly",
    "abranchial": "branchiate",
    "abranchiate": "gilled",
    "abranchious": "branchiate",
    "abridged": "unabridged",
    "absorbable": "adsorbate",
    "abstemious": "gluttonous",
    "abstinent": "drinker",
    "abused": "unabused",
    "acarpellous": "carpellate",
    "acarpelous": "pistillate",
    "acatalectic": "hypercatalectic",
    "acaudal": "caudate",
    "acaudate": "caudated",
    "acaulescent": "cauline",
    "acceptive": "rejective",
    "accommodating": "unobliging",
    "accommodative": "unaccommodating",
    "accordant": "discordant",
    "accusatorial": "inquisitorial",
    "achlamydeous": "chlamydeous",
    "achondritic": "granular",
    "achromatinic": "chromatinic",
    "acid-loving": "alkaline-loving",
    "acidic": "amphoteric",
    "acquisitive": "unacquisitive",
    "acrocarpous": "pleurocarpous",
    "acropetal": "basipetal",
    "acroscopic": "basiscopic",
    "actable": "unactable",
    "actinal": "abactinal",
    "actinomorphic": "zygomorphous",
    "actinomorphous": "zygomorphic",
    "acyclic": "cyclic",
    "adaptative": "maladaptive",
    "adaptive": "maladaptive",
    "adaxial": "abaxial",
    "addicted": "unaddicted",
    "addictive": "nonaddictive",
    "addressed": "unaddressed",
    "adducent": "abducting",
    "adducting": "abducent",
    "adductive": "abducent",
    "adiabatic": "diabatic",
    "adient": "abient",
    "adjusted": "unadjusted",
    "adnate": "connate",
    "adoptable": "unadoptable",
    "adoptive": "biological",
    "adorned": "undecorated",
    "adroit": "maladroit",
    "adscript": "subscript",
    "adsorbable": "absorbable",
    "adsorbate": "absorbable",
    "adsorbent": "nonadsorptive",
    "adsorptive": "nonadsorbent",
    "adulterant": "purifying",
    "adulterating": "purifying",
    "advised": "ill-advised",
    "aerobic": "anaerobiotic",
    "aerophilic": "anaerobic",
    "aerophilous": "anaerobic",
    "affected": "unaffected",
    "afferent": "motorial",
    "affixed": "unaffixed",
    "ahistorical": "historical",
    "air-to-air": "air-to-surface",
    "air-to-ground": "air-to-air",
    "air-to-surface": "surface-to-air",
    "airworthy": "unairworthy",
    "alcoholic": "nonalcoholic",
    "algorithmic": "heuristic",
    "aligning": "skew",
    "alkalic": "amphoteric",
    "alkaline": "acidic",
    "alkaline-loving": "acid-loving",
    "allochthonous": "autochthonous",
    "allogeneic": "xenogeneic",
    "allopatric": "sympatric",
    "alphabetic": "analphabetic",
    "alphabetical": "analphabetic",
    "alterable": "unalterable",
    "altricial": "precocial",
    "altruistic": "self-centred",
    "ambidextrous": "left-handed",
    "ambiversive": "extroversive",
    "ameliorating": "worsen",
    "amended": "unamended",
    "ametabolic": "metabolous",
    "ametabolous": "metabolic",
    "ametropic": "emmetropic",
    "amphiprotic": "acidic",
    "amphitropous": "inverted",
    "amphoteric": "alkaline",
    "ample": "scrimpy",
    "anabatic": "katabatic",
    "anabolic": "katabolic",
    "anaclinal": "cataclinal",
    "anadromous": "diadromous",
    "anaerobic": "aerophilous",
    "anaerobiotic": "aerobic",
    "analphabetic": "alphabetical",
    "analyzed": "unanalyzed",
    "anaphrodisiac": "aphrodisiacal",
    "anastigmatic": "astigmatic",
    "anatropous": "amphitropous",
    "anemophilous": "entomophilous",
    "anestrous": "estrous",
    "anglican": "chapelgoer",
    "anionic": "cationic",
    "anisotropic": "isotropous",
    "anodal": "cathodic",
    "anodic": "cathodic",
    "anorthic": "monoclinic",
    "antemeridian": "postmeridian",
    "antemortem": "postmortem",
    "antenatal": "perinatal",
    "antenuptial": "postnuptial",
    "antepartum": "perinatal",
    "anti-american": "pro-american",
    "anticholinergic": "cholinergic",
    "anticlimactic": "climactic",
    "anticlinal": "synclinal",
    "anticlockwise": "clockwise",
    "antimagnetic": "magnetized",
    "antipyretic": "pyretic",
    "antrorse": "retrorse",
    "apetalous": "petalous",
    "aphrodisiac": "anaphrodisiac",
    "aphrodisiacal": "anaphrodisiac",
    "aplacental": "placental",
    "apocarpous": "syncarpous",
    "apocrine": "eccrine",
    "appealable": "unappealable",
    "appealing": "unappealing",
    "appendaged": "unappendaged",
    "appetising": "unappetizing",
    "appetizing": "unappetizing",
    "appointed": "elective",
    "appointive": "elective",
    "apposable": "unopposable",
    "approachable": "unapproachable",
    "apropos": "malapropos",
    "apteral": "peripteral",
    "arbitrable": "nonarbitrable",
    "arbitrary": "unarbitrary",
    "arboreal": "nonarboreal",
    "arboreous": "nonarboreal",
    "arenaceous": "clayey",
    "argillaceous": "sandy",
    "aroused": "fall asleep",
    "artesian": "subartesian",
    "articulated": "unarticulated",
    "artiodactyl": "odd-toed ungulate",
    "asexual": "sexual",
    "asserting": "interrogative",
    "assertive": "unassertive",
    "assigned": "unassigned",
    "associative": "nonassociative",
    "associatory": "nonassociative",
    "astigmatic": "stigmatic",
    "astomatous": "stomatous",
    "asyndetic": "syndetic",
    "atomistic": "holistic",
    "atomistical": "holistic",
    "atonal": "tonal",
    "atrophied": "hypertrophied",
    "attachable": "detachable",
    "attired": "underdress",
    "attributive": "predicative",
    "atypical": "typical",
    "autochthonous": "allochthonous",
    "autoecious": "heteroecious",
    "autogamic": "endogamous",
    "autogamous": "exogamous",
    "autogenic": "heterogenous",
    "autogenous": "heterogenous",
    "autophytic": "heterotrophic",
    "autotrophic": "heterotrophic",
    "available": "unavailable",
    "avenged": "unavenged",
    "avirulent": "virulent",
    "avowed": "disavow",
    "awakened": "unawakened",
    "away": "home",
    "awed": "unawed",
    "awestricken": "unawed",
    "awestruck": "unawed",
    "awned": "awnless",
    "awnless": "awny",
    "awny": "awnless",
    "azonal": "zonal",
    "backed": "backless",
    "backhand": "forehanded",
    "backhanded": "forehand",
    "backless": "backed",
    "balconied": "unbalconied",
    "banded": "unbanded",
    "baptised": "unbaptized",
    "baptized": "unbaptized",
    "barreled": "unbarrelled",
    "barrelled": "unbarreled",
    "basal": "cauline",
    "basic": "incidental",
    "basipetal": "acropetal",
    "basiscopic": "acroscopic",
    "beaked": "beakless",
    "beakless": "beaked",
    "bedded": "bedless",
    "bedless": "bedded",
    "bellied": "flat-bellied",
    "bellyless": "bellied",
    "belted": "unbelted",
    "beltless": "belted",
    "beneficed": "unbeneficed",
    "beneficent": "maleficent",
    "biaural": "monaural",
    "bibbed": "bibless",
    "bibless": "bibbed",
    "bicameral": "unicameral",
    "bidirectional": "unidirectional",
    "bilaterally symmetrical": "actinomorphic",
    "bimodal": "unimodal",
    "binaural": "monaural",
    "binuclear": "trinucleate",
    "binucleate": "mononucleate",
    "binucleated": "trinucleate",
    "biological": "adoptive",
    "biped": "quadrupedal",
    "bipedal": "quadrupedal",
    "bipolar": "unipolar",
    "bivalent": "univalent",
    "bivalve": "univalve",
    "bivalved": "univalve",
    "blackened": "whiten",
    "blemished": "unmutilated",
    "blended": "unblended",
    "blue-collar": "white-collar",
    "bodied": "unbodied",
    "bordered": "unbordered",
    "bottle-fed": "breast-fed",
    "bottom-up": "top-down",
    "brachycephalic": "dolichocranic",
    "brachycranial": "dolichocephalic",
    "brachycranic": "dolichocephalic",
    "bracteate": "ebracteate",
    "bracted": "ebracteate",
    "brainwashed": "unbrainwashed",
    "branchiate": "gill-less",
    "branchless": "branchy",
    "branchy": "branchless",
    "branded": "unbranded",
    "breast-fed": "bottle-fed",
    "breasted": "breastless",
    "breastless": "breasted",
    "breathing": "dyspnoeic",
    "breathless": "eupnoeic",
    "bridgeable": "unbridgeable",
    "broad-minded": "shockable",
    "broadnosed": "catarrhine",
    "burdened": "unburdened",
    "buttoned": "unbuttoned",
    "cacogenic": "eugenic",
    "cacophonic": "euphonious",
    "cacophonous": "euphonous",
    "calced": "unshod",
    "calcicolous": "calcifugous",
    "calcifugous": "calcicolous",
    "camphorated": "uncamphorated",
    "campylotropous": "orthotropous",
    "cancelled": "on",
    "capital": "lowercase",
    "capitalist": "socialistic",
    "capitalistic": "socialistic",
    "cared-for": "uncared-for",
    "carinate": "ratite bird",
    "carpellate": "acarpelous",
    "carpeted": "uncarpeted",
    "carved": "uncarved",
    "carvel-built": "lap-streaked",
    "carven": "uncarved",
    "castrated": "uncastrated",
    "catabatic": "anabatic",
    "catabolic": "anabolic",
    "cataclinal": "anaclinal",
    "catadromous": "anadromous",
    "catalectic": "acatalectic",
    "catarrhine": "platyrrhinic",
    "catarrhinian": "leptorrhine",
    "catching": "unhitch",
    "categorematic": "syncategorematic",
    "cathodic": "anodic",
    "cationic": "anionic",
    "caudate": "acaudate",
    "caudated": "acaudate",
    "caulescent": "acaulescent",
    "cauline": "radical",
    "caulked": "uncaulked",
    "causative": "noncausative",
    "ceilinged": "floored",
    "cenobitic": "eremitical",
    "cenobitical": "eremitic",
    "cenogenetic": "palingenetic",
    "censored": "uncensored",
    "centralised": "decentralized",
    "centralising": "decentralizing",
    "centralized": "decentralized",
    "centralizing": "decentralizing",
    "certified": "uncertified",
    "charged": "uncharged",
    "chaste": "unchaste",
    "cheering": "dishearten",
    "chlamydeous": "achlamydeous",
    "cholinergic": "anticholinergic",
    "chondritic": "achondritic",
    "christian": "unchristian",
    "chromatinic": "achromatinic",
    "cismontane": "transmontane",
    "clad": "unclothed",
    "classified": "unclassified",
    "clayey": "arenaceous",
    "clear-thinking": "confused",
    "cleared": "uncleared",
    "clearheaded": "confused",
    "climactic": "anticlimactic",
    "clincher-built": "carvel-built",
    "clinker-built": "carvel-built",
    "clockwise": "counterclockwise",
    "clothed": "unclothed",
    "clotted": "homogenize",
    "coarse": "finer",
    "coated": "uncoated",
    "coenobitic": "eremitic",
    "coenobitical": "eremitic",
    "cold-blooded": "warm-blooded",
    "coldhearted": "warmhearted",
    "collapsable": "noncollapsible",
    "collapsible": "noncollapsible",
    "colonised": "decolonize",
    "colonized": "decolonize",
    "columned": "uncolumned",
    "combed": "uncombed",
    "combinative": "noncombinative",
    "combinatory": "noncombinative",
    "coming": "go",
    "commissioned": "noncommissioned",
    "commodious": "incommodious",
    "commutable": "incommutable",
    "compartmented": "uncompartmented",
    "complaining": "uncomplaining",
    "complaintive": "uncomplaining",
    "complete": "uncomplete",
    "complimentary": "uncomplimentary",
    "concealing": "revealing",
    "concentrated": "distributed",
    "conductive": "nonconductive",
    "conformist": "unconformist",
    "confused": "clearheaded",
    "conjunct": "disjunct",
    "connate": "adnate",
    "connotative": "denotive",
    "conquerable": "unconquerable",
    "consecrate": "unhallow",
    "consecrated": "desecrated",
    "consolable": "unconsolable",
    "consonantal": "vocalic",
    "constipated": "unconstipated",
    "constricted": "unconstricted",
    "consummated": "unconsummated",
    "contented": "discontented",
    "contestable": "incontestible",
    "continuant": "stop consonant",
    "contraclockwise": "clockwise",
    "contralateral": "ipsilateral",
    "contrapuntal": "monophonic",
    "cooked": "raw",
    "coordinating": "subordinative",
    "coordinative": "subordinating",
    "corrected": "uncorrected",
    "corrigible": "incorrigible",
    "counterclockwise": "clockwise",
    "cousinly": "uncousinly",
    "crannied": "uncrannied",
    "cross-eyed": "walleyed",
    "crossbred": "purebred",
    "crowned": "uncrowned",
    "crownless": "crowned",
    "crude": "refined",
    "crystallised": "uncrystallized",
    "crystallized": "uncrystallized",
    "curdled": "homogenize",
    "curious": "incurious",
    "cursorial": "fossorial",
    "curtained": "uncurtained",
    "curtainless": "curtained",
    "custom": "ready-made",
    "custom-built": "ready-made",
    "custom-made": "ready-made",
    "cutting": "switch on",
    "cyclic": "open-chain",
    "cyclical": "noncyclic",
    "damaged": "undamaged",
    "datable": "undatable",
    "dateable": "undatable",
    "de-iodinating": "iodinating",
    "de facto": "de jure",
    "de jure": "de facto",
    "debilitating": "invigorating",
    "decentralised": "centralized",
    "decentralising": "centralizing",
    "decentralized": "centralized",
    "decentralizing": "centralizing",
    "deciphered": "undeciphered",
    "declarative": "interrogative",
    "declared": "undeclared",
    "deconsecrated": "consecrate",
    "decorated": "unadorned",
    "decorous": "indelicate",
    "dedicated": "undedicated",
    "deductible": "nondeductible",
    "deductive": "inductive",
    "deep": "shallow",
    "defeasible": "indefeasible",
    "definite": "indefinite",
    "deflationary": "inflationary",
    "dehiscent": "indehiscent",
    "dehumanised": "humanize",
    "dehumanized": "humanize",
    "dehydrated": "hydrate",
    "delighted": "displease",
    "delineate": "undelineated",
    "delineated": "undelineated",
    "democratic": "undemocratic",
    "demythologised": "mythologize",
    "demythologized": "mythologize",
    "denotative": "connotative",
    "denotive": "connotative",
    "departed": "come",
    "depressant": "stimulative",
    "derivational": "inflectional",
    "derived": "underived",
    "desecrated": "consecrated",
    "desensitising": "sensitizing",
    "desensitizing": "sensitizing",
    "deserved": "unmerited",
    "desiccate": "hydrate",
    "desiccated": "hydrate",
    "detachable": "attachable",
    "detected": "undetected",
    "dextral": "sinistral",
    "diabatic": "adiabatic",
    "diachronic": "synchronic",
    "diadromous": "catadromous",
    "diclinous": "monoclinous",
    "dicotyledonous": "monocotyledonous",
    "different": "same",
    "differentiated": "undifferentiated",
    "diffuse": "hard",
    "diffused": "hard",
    "digestible": "indigestible",
    "digitigrade": "plantigrade",
    "dim": "undimmed",
    "diminished": "hypertrophied",
    "dimmed": "undimmed",
    "dioecian": "monoecious",
    "dioecious": "monoicous",
    "diploid": "monoploid",
    "directional": "omnidirectional",
    "disabling": "enabling",
    "discalceate": "calced",
    "discalced": "calced",
    "disconsolate": "consolable",
    "discontented": "contented",
    "discordant": "accordant",
    "discouraging": "encouraging",
    "disenfranchised": "enfranchised",
    "disentangled": "entangle",
    "disfranchised": "enfranchised",
    "disheartened": "hearten",
    "disheartening": "hearten",
    "disintegrative": "integrative",
    "disjunct": "conjunct",
    "disordered": "ordered",
    "disorienting": "orienting",
    "displeasing": "pleasing",
    "disposable": "nondisposable",
    "disqualifying": "enabling",
    "dissatisfied": "satisfy",
    "distressed": "euphoric",
    "distributed": "concentrated",
    "distrustful": "trusting",
    "documented": "undocumented",
    "dolichocephalic": "brachycranic",
    "dolichocranial": "brachycephalic",
    "dolichocranic": "brachycephalic",
    "domineering": "submissive",
    "double-barreled": "single-barrelled",
    "double-barrelled": "single-barreled",
    "double-breasted": "single-breasted",
    "down": "upwardly",
    "downmarket": "upmarket",
    "downstage": "upstager",
    "downstream": "upriver",
    "downtown": "uptown",
    "downward": "up",
    "downwind": "into the wind",
    "drinkable": "undrinkable",
    "driven": "attract",
    "driving": "attract",
    "dysgenic": "eugenic",
    "dysphemistic": "euphemistic",
    "dysphoric": "euphoric",
    "dyspneal": "breathing",
    "dyspneic": "breathing",
    "dyspnoeal": "breathing",
    "dyspnoeic": "breathing",
    "eared": "earless",
    "earless": "eared",
    "east": "wester",
    "easterly": "westerly",
    "ebracteate": "bracted",
    "eccrine": "apocrine",
    "echoic": "nonechoic",
    "ectomorphic": "muscular",
    "edifying": "unedifying",
    "efferent": "afferent",
    "effortful": "effortless",
    "effortless": "effortful",
    "egalitarian": "elitist",
    "egocentric": "altruistic",
    "egoistic": "selfless",
    "egoistical": "altruistic",
    "elected": "appointive",
    "elective": "appointive",
    "emboldened": "dishearten",
    "emmetropic": "ametropic",
    "employable": "unemployable",
    "enabling": "disqualifying",
    "enclosed": "unenclosed",
    "encouraging": "discouraging",
    "end-stopped": "run-on",
    "endergonic": "exergonic",
    "endocentric": "exocentric",
    "endocrinal": "exocrine",
    "endocrine": "exocrine",
    "endoergic": "exoergic",
    "endogamic": "exogamous",
    "endogamous": "autogamous",
    "endogenic": "exogenous",
    "endogenous": "exogenous",
    "endomorphic": "ectomorphic",
    "endothermal": "exothermic",
    "endothermic": "heat-releasing",
    "endozoic": "epizoic",
    "energy-absorbing": "exoergic",
    "energy-releasing": "endoergic",
    "enforceable": "unenforceable",
    "enforced": "unenforced",
    "enfranchised": "voteless",
    "enlarged": "atrophied",
    "enlightened": "unenlightened",
    "enlightening": "unilluminating",
    "enlivened": "unenlivened",
    "entangled": "disentangle",
    "enthusiastic": "unenthusiastic",
    "entomophilous": "anemophilous",
    "entozoan": "epizoic",
    "entozoic": "epizoic",
    "epizoic": "entozoic",
    "equipped": "unequipped",
    "equipt": "unequipped",
    "eradicable": "ineradicable",
    "eremitic": "coenobitical",
    "eremitical": "cenobitic",
    "estrous": "anestrous",
    "eucaryotic": "prokaryotic",
    "eugenic": "dysgenic",
    "eukaryotic": "prokaryotic",
    "euphemistic": "dysphemistic",
    "euphonious": "cacophonous",
    "euphonous": "cacophonous",
    "euphoric": "dysphoric",
    "eupneic": "breathless",
    "eupnoeic": "breathless",
    "eusporangiate": "leptosporangiate",
    "ex vivo": "in vivo",
    "exacting": "unfastidious",
    "exchangeable": "unexchangeable",
    "exculpatory": "inculpatory",
    "exergonic": "endergonic",
    "exocentric": "endocentric",
    "exocrine": "endocrine",
    "exoergic": "energy-absorbing",
    "exogamic": "autogamous",
    "exogamous": "endogamous",
    "exogenic": "endogenous",
    "exogenous": "endogenous",
    "exothermal": "endothermic",
    "exothermic": "heat-absorbing",
    "expendable": "unexpendable",
    "explicit": "inexplicit",
    "exploited": "unexploited",
    "explorative": "nonexploratory",
    "exploratory": "unexploratory",
    "exportable": "unexportable",
    "expressed": "implicit",
    "expressible": "unexpressible",
    "extensible": "nonextensile",
    "extensile": "nonprotractile",
    "extinguishable": "inextinguishable",
    "extracellular": "intracellular",
    "extraversive": "ambiversive",
    "extravert": "introvert",
    "extricable": "inextricable",
    "extroversive": "introvertive",
    "extrovert": "introvert",
    "eyed": "eyeless",
    "eyeless": "eyed",
    "faced": "faceless",
    "faceless": "faced",
    "faceted": "unfaceted",
    "factory-made": "homemade",
    "facultative": "obligate",
    "famished": "be full",
    "far": "nighest",
    "farsighted": "shortsighted",
    "fastened": "unfastened",
    "fastidious": "unfastidious",
    "fathomable": "unfathomable",
    "feathered": "unfeathered",
    "featherless": "feathered",
    "felicitous": "infelicitous",
    "ferned": "fernless",
    "fernless": "ferny",
    "ferny": "fernless",
    "few": "many",
    "fewer": "more",
    "fewest": "most",
    "fictional": "nonfictional",
    "filled": "unfilled",
    "fine": "harsh",
    "finer": "coarse",
    "fingered": "fingerless",
    "fingerless": "fingered",
    "first": "second",
    "fissionable": "nonfissionable",
    "fit": "unfit",
    "fitter": "unfit",
    "flat-bellied": "bellied",
    "fledged": "unfledged",
    "floored": "ceilinged",
    "focused": "unfocussed",
    "focussed": "unfocused",
    "footed": "footless",
    "footless": "footed",
    "forceful": "unforceful",
    "forceless": "forceful",
    "foregoing": "postdate",
    "foregone": "postdate",
    "forehand": "backhander",
    "forehanded": "backhand",
    "forgettable": "unforgettable",
    "former": "latter",
    "fortissimo": "very softly",
    "fossorial": "cursorial",
    "four-footed": "bipedal",
    "framed": "unframed",
    "fretted": "unfretted",
    "fueled": "unfueled",
    "fulfilled": "fall short of",
    "full-time": "parttime",
    "functioning": "malfunctioning",
    "funded": "unfunded",
    "furrowed": "unfurrowed",
    "gabled": "hipped",
    "geared": "ungeared",
    "generalised": "specify",
    "generalized": "specify",
    "geocentric": "heliocentric",
    "geographic": "magnetic",
    "geographical": "magnetic",
    "germfree": "germy",
    "germy": "germfree",
    "gill-less": "branchiate",
    "gilled": "abranchiate",
    "given": "take",
    "giving": "take",
    "gladdened": "sadden",
    "glassed": "unglazed",
    "glassless": "glazed",
    "glazed": "unglazed",
    "glorious": "inglorious",
    "gloved": "gloveless",
    "gloveless": "gloved",
    "gluttonous": "abstemious",
    "go": "come up",
    "good-natured": "ill-natured",
    "grammatical": "ungrammatical",
    "granular": "achondritic",
    "gratified": "dissatisfy",
    "gratifying": "dissatisfy",
    "greased": "unlubricated",
    "groomed": "ungroomed",
    "guided": "unguided",
    "gusseted": "ungusseted",
    "gutless": "plucky",
    "gutsy": "gutless",
    "habit-forming": "nonaddictive",
    "half-time": "full-time",
    "hallowed": "desecrate",
    "hand-crafted": "machine-made",
    "handed": "handless",
    "handled": "handleless",
    "handleless": "handled",
    "handless": "handed",
    "handmade": "machine-made",
    "haploid": "polyploid",
    "haploidic": "diploid",
    "hardhearted": "softhearted",
    "harmonic": "nonharmonic",
    "harmonious": "unharmonious",
    "harsh": "fine",
    "hatless": "hatted",
    "hatted": "hatless",
    "headed": "unheaded",
    "headless": "headed",
    "heartening": "dishearten",
    "heartless": "softhearted",
    "heat-absorbing": "exothermic",
    "heat-releasing": "endothermic",
    "heavy-duty": "light-duty",
    "heavy-footed": "light-footed",
    "heedful": "unheeding",
    "heedless": "paying attention",
    "heliocentric": "geocentric",
    "here": "thither",
    "heritable": "noninheritable",
    "heterocercal": "homocercal",
    "heterodactyl": "zygodactyl",
    "heteroecious": "homoecious",
    "heterotrophic": "autotrophic",
    "heterozygous": "homozygous",
    "heuristic": "algorithmic",
    "hi-tech": "low-tech",
    "hibernating": "estivate",
    "high-interest": "low-interest",
    "high-resolution": "low-resolution",
    "high-rise": "low-rise",
    "high-sudsing": "low-sudsing",
    "high-tech": "low-tech",
    "high-tension": "low-voltage",
    "hipless": "hipped",
    "hipped": "hipless",
    "historical": "ahistorical",
    "holistic": "atomistical",
    "holophytic": "holozoic",
    "holozoic": "holophytic",
    "home": "away",
    "homemade": "factory-made",
    "homocercal": "heterocercal",
    "homochromatic": "polychromatic",
    "homoecious": "heteroecious",
    "homogenised": "curdle",
    "homogenized": "curdle",
    "homozygous": "heterozygous",
    "hoofed": "unguiculate",
    "hooved": "unguiculate",
    "horned": "hornless",
    "hornless": "horned",
    "husbandly": "wifely",
    "hushed": "louden",
    "hydric": "xeric",
    "hydrokinetic": "hydrostatic",
    "hydrophilic": "hydrophobic",
    "hydrophobic": "hydrophilic",
    "hydrostatic": "hydrokinetic",
    "hypercatalectic": "catalectic",
    "hypertensive": "normotensive",
    "hypertonic": "isotonic",
    "hypertrophied": "wasted",
    "hypognathous": "opisthognathous",
    "hypotensive": "hypertensive",
    "hypotonic": "hypertonic",
    "identifiable": "unidentifiable",
    "idiographic": "nomothetic",
    "ill-advised": "well-advised",
    "ill-defined": "well-defined",
    "ill-formed": "grammatical",
    "ill-natured": "good-natured",
    "ill-treated": "unabused",
    "illuminating": "unenlightening",
    "imitative": "nonimitative",
    "immanent": "transient",
    "immiscible": "mixable",
    "immunocompetent": "immunodeficient",
    "immunodeficient": "immunocompetent",
    "impaired": "unimpaired",
    "impenitent": "penitent",
    "impermanent": "permanent",
    "implausible": "plausible",
    "implemented": "unenforced",
    "implicit": "expressed",
    "imponderable": "ponderable",
    "impressive": "unimpressive",
    "improvident": "provident",
    "improving": "worsen",
    "in vitro": "in vivo",
    "in vivo": "in vitro",
    "inalterable": "alterable",
    "inboard": "outboard",
    "incarnate": "disincarnate",
    "incident": "basic",
    "incidental": "basic",
    "incommodious": "commodious",
    "incommutable": "commutable",
    "incomplete": "complete",
    "incongruent": "congruent",
    "inconsolable": "consolable",
    "incontestable": "contestable",
    "incontestible": "contestable",
    "incorrigible": "corrigible",
    "inculpative": "exculpatory",
    "inculpatory": "exculpatory",
    "incurious": "curious",
    "indecorous": "decorous",
    "indefeasible": "defeasible",
    "indefinite": "definite",
    "indehiscent": "dehiscent",
    "indelicate": "decorous",
    "indigestible": "digestible",
    "individualised": "depersonalize",
    "individualized": "depersonalize",
    "inductive": "deductive",
    "industrial": "nonindustrial",
    "ineradicable": "eradicable",
    "inexplicit": "explicit",
    "inexpressible": "expressible",
    "inextensible": "extensile",
    "inextinguishable": "extinguishable",
    "inextricable": "extricable",
    "infelicitous": "felicitous",
    "infernal": "supernal",
    "inflationary": "deflationary",
    "inflected": "uninflected",
    "inflectional": "derivational",
    "informative": "uninformative",
    "informatory": "uninformative",
    "inglorious": "glorious",
    "inharmonious": "harmonious",
    "inheritable": "noninheritable",
    "inhibited": "uninhibited",
    "injectable": "uninjectable",
    "inner": "outer",
    "innumerate": "numerate",
    "inodorous": "odorous",
    "inoperable": "operable",
    "inquisitorial": "accusatorial",
    "insatiable": "satiate",
    "insatiate": "satiated",
    "insensible": "sensible",
    "inshore": "seaward",
    "inspiring": "uninspiring",
    "institutional": "noninstitutional",
    "institutionalised": "noninstitutionalized",
    "institutionalized": "noninstitutionalized",
    "insubstantial": "substantial",
    "insured": "uninsured",
    "integrative": "disintegrative",
    "interdepartmental": "intradepartmental",
    "interrogative": "declarative",
    "interspecies": "intraspecific",
    "interspecific": "intraspecies",
    "interstate": "intrastate",
    "intra vires": "ultra vires",
    "intracellular": "extracellular",
    "intradepartmental": "interdepartmental",
    "intraspecies": "interspecific",
    "intraspecific": "interspecies",
    "intrastate": "interstate",
    "introversive": "ambiversive",
    "introvertive": "extroversive",
    "invertebrate": "vertebrate",
    "inverted": "amphitropous",
    "invertible": "non-invertible",
    "invigorating": "debilitating",
    "inviolable": "violable",
    "involved": "uninvolved",
    "iodinated": "de-iodinate",
    "iodinating": "de-iodinating",
    "ionic": "nonpolar",
    "ionised": "nonionized",
    "ionized": "unionized",
    "ipsilateral": "contralateral",
    "ironed": "unironed",
    "irremediable": "remediable",
    "irremovable": "removable",
    "irreplaceable": "replaceable",
    "irreproducible": "reproducible",
    "isometric": "isotonic",
    "isosmotic": "hypertonic",
    "isotonic": "isometric",
    "isotropic": "anisotropic",
    "isotropous": "anisotropic",
    "jawed": "jawless",
    "jawless": "jawed",
    "jolly": "unreasonably",
    "judgmental": "nonjudgmental",
    "katabatic": "anabatic",
    "katabolic": "anabolic",
    "key": "atonality",
    "keyed": "keyless",
    "keyless": "keyed",
    "kindly": "unkindly",
    "knotted": "unravel",
    "labeled": "untagged",
    "labelled": "unlabeled",
    "laced": "unlaced",
    "lamented": "unmourned",
    "lap-strake": "carvel-built",
    "lap-straked": "carvel-built",
    "lap-streak": "carvel-built",
    "lap-streaked": "carvel-built",
    "last": "first",
    "lasting": "impermanent",
    "latter": "former",
    "laureled": "unlaurelled",
    "laurelled": "unlaureled",
    "leaded": "unleaded",
    "leadless": "leaded",
    "least": "to the highest degree",
    "leavened": "unraised",
    "lee": "windward",
    "leeward": "windward",
    "left-handed": "right-handed",
    "legged": "legless",
    "legless": "legged",
    "lentic": "lotic",
    "leptorhine": "catarrhine",
    "leptorrhine": "catarrhinian",
    "leptorrhinian": "catarrhine",
    "leptorrhinic": "catarrhine",
    "leptosporangiate": "eusporangiate",
    "less": "to a greater extent",
    "lidded": "lidless",
    "lidless": "lidded",
    "light-duty": "heavy-duty",
    "light-footed": "heavy-footed",
    "lighted": "unlit",
    "likely": "unlikely",
    "limbed": "limbless",
    "limbless": "limbed",
    "lipless": "lipped",
    "lipped": "unlipped",
    "liquified": "unmelted",
    "listed": "unlisted",
    "lit": "unlighted",
    "livable": "unliveable",
    "live": "recorded",
    "live-bearing": "oviparous",
    "liveable": "unlivable",
    "liveried": "unliveried",
    "loamless": "loamy",
    "loamy": "loamless",
    "long-spurred": "short-spurred",
    "lossless": "lossy",
    "lossy": "lossless",
    "lotic": "lentic",
    "loved": "unloved",
    "low-class": "middle-class",
    "low-interest": "high-interest",
    "low-resolution": "high-resolution",
    "low-rise": "high-rise",
    "low-sudsing": "high-sudsing",
    "low-tech": "high-tech",
    "low-tension": "high-tension",
    "low-voltage": "high-tension",
    "lower-class": "upper-class",
    "lowercase": "upper-case letter",
    "lubricated": "unlubricated",
    "machine-made": "handmade",
    "made": "unmade",
    "magnetic": "nonmagnetic",
    "magnetised": "antimagnetic",
    "magnetized": "antimagnetic",
    "maladaptive": "adaptive",
    "maladjusted": "adjusted",
    "maladroit": "adroit",
    "malapropos": "apropos",
    "maleficent": "beneficent",
    "malfunctioning": "functioning",
    "malnourished": "nourished",
    "malted": "unmalted",
    "maltreated": "unabused",
    "manned": "unmanned",
    "many": "few",
    "masochistic": "sadistic",
    "mat": "disentangle",
    "mated": "unmated",
    "matted": "disentangle",
    "maxi": "midi",
    "maximal": "minimal",
    "meager": "ample",
    "meagre": "ample",
    "meatless": "meaty",
    "meaty": "meatless",
    "medullated": "unmyelinated",
    "melted": "unmelted",
    "membered": "memberless",
    "memberless": "membered",
    "merged": "disunify",
    "merging": "disunify",
    "merited": "unmerited",
    "mesic": "hydric",
    "mesomorphic": "pyknic",
    "metabolic": "ametabolous",
    "metabolous": "ametabolic",
    "metal": "nonmetallic",
    "metallic": "nonmetallic",
    "metamorphic": "nonmetamorphic",
    "middle-class": "lower-class",
    "middling": "unreasonably",
    "midi": "mini",
    "militarised": "demilitarize",
    "militarized": "demilitarize",
    "mined": "unmined",
    "mini": "maxi",
    "minimal": "maximal",
    "minus": "plus",
    "miscible": "unmixable",
    "mistreated": "unabused",
    "misused": "used",
    "mixable": "immiscible",
    "modulated": "unmodulated",
    "monaural": "binaural",
    "monecious": "dioecious",
    "moneyed": "moneyless",
    "moneyless": "monied",
    "monied": "moneyless",
    "monochromatic": "polychromatic",
    "monoclinic": "triclinic",
    "monoclinous": "diclinous",
    "monocotyledonous": "dicotyledonous",
    "monoecious": "dioecious",
    "monogamous": "polygamous",
    "monoicous": "dioecious",
    "monolingual": "multilingual",
    "mononuclear": "trinucleated",
    "mononucleate": "binucleate",
    "monophonic": "polyphonic",
    "monoploid": "diploid",
    "monotheistic": "polytheistic",
    "monotone": "nonmonotonic",
    "monotonic": "nonmonotonic",
    "monovalent": "polyvalent",
    "moonless": "moony",
    "moonlit": "moonless",
    "moony": "moonless",
    "more": "to a lesser extent",
    "more than": "less",
    "most": "to the lowest degree",
    "motivated": "unmotivated",
    "motored": "unmotorized",
    "motorial": "afferent",
    "motorised": "unmotorized",
    "motorized": "unmotorized",
    "motorless": "motorized",
    "mouthless": "stomatous",
    "mown": "unmown",
    "multidimensional": "unidimensional",
    "multilane": "single-lane",
    "multilingual": "monolingual",
    "multinucleate": "uninucleate",
    "multiparous": "uniparous",
    "multiple-choice": "true-false",
    "multivalent": "bivalent",
    "muscular": "ectomorphic",
    "myelinated": "unmyelinated",
    "myopic": "farsighted",
    "mystified": "demystify",
    "mystifying": "demystify",
    "narrow-minded": "unshockable",
    "naturalised": "denaturalize",
    "naturalized": "denaturalize",
    "near": "far",
    "nearsighted": "presbyopic",
    "necked": "neckless",
    "neckless": "necked",
    "nidicolous": "nidifugous",
    "nidifugous": "nidicolous",
    "nigh": "far",
    "no": "yes",
    "no-go": "go",
    "nomothetic": "idiographic",
    "non-conducting": "conductive",
    "non-invertible": "invertible",
    "non-miscible": "miscible",
    "nonaddictive": "habit-forming",
    "nonadsorbent": "surface-assimilative",
    "nonadsorptive": "adsorbent",
    "nonalcoholic": "alcoholic",
    "nonarbitrable": "arbitrable",
    "nonarbitrary": "arbitrary",
    "nonarboreal": "tree-living",
    "nonassociative": "associatory",
    "noncausal": "causative",
    "noncausative": "causative",
    "noncollapsable": "collapsible",
    "noncollapsible": "collapsible",
    "noncolumned": "columned",
    "noncombinative": "combinatory",
    "noncommissioned": "commissioned",
    "nonconducting": "conductive",
    "nonconductive": "conductive",
    "nonconformist": "anglican",
    "noncyclic": "cyclical",
    "noncyclical": "cyclic",
    "nondeductible": "deductible",
    "nondisposable": "disposable",
    "nonechoic": "onomatopoetic",
    "noneffervescent": "sparkling",
    "nonexplorative": "exploratory",
    "nonexploratory": "exploratory",
    "nonextensile": "extensile",
    "nonfictional": "fictional",
    "nonfissionable": "fissionable",
    "nonharmonic": "harmonic",
    "nonheritable": "inheritable",
    "nonimitative": "imitative",
    "nonindustrial": "industrial",
    "noninheritable": "inheritable",
    "noninstitutional": "institutional",
    "noninstitutionalised": "institutionalized",
    "noninstitutionalized": "institutionalized",
    "nonionic": "ionic",
    "nonionised": "ionized",
    "nonionized": "ionized",
    "nonjudgmental": "judgmental",
    "nonmagnetic": "magnetic",
    "nonmetal": "metallic",
    "nonmetallic": "metallic",
    "nonmetamorphic": "metamorphic",
    "nonmonotonic": "monotonic",
    "nonoperational": "operational",
    "nonparticulate": "particulate",
    "nonpasserine": "passerine",
    "nonphotosynthetic": "photosynthetic",
    "nonpolar": "ionic",
    "nonpolitical": "political",
    "nonpregnant": "pregnant",
    "nonprehensile": "prehensile",
    "nonprotractile": "extensile",
    "nonpsychoactive": "psychotropic",
    "nonracial": "racial",
    "nonrandom": "random",
    "nonrenewable": "renewable",
    "nonrepetitive": "repetitive",
    "nonrepresentational": "representational",
    "nonresidential": "residential",
    "nonresonant": "reverberant",
    "nonreticulate": "reticulate",
    "nonretractable": "retractile",
    "nonretractile": "retractile",
    "nonreturnable": "returnable",
    "nonruminant": "ruminant",
    "nonsexual": "sexual",
    "nonslippery": "slippy",
    "nonspatial": "spatial",
    "nonsteroidal": "steroidal",
    "nonsuppurative": "suppurative",
    "nonsweet": "sugary",
    "nonsyllabic": "syllabic",
    "nontaxable": "taxable",
    "nontranslational": "translational",
    "nonvolatile": "volatile",
    "nonvolatilisable": "volatile",
    "nonvolatilizable": "volatile",
    "nonwashable": "washable",
    "normotensive": "hypotensive",
    "north": "south",
    "northern": "southern",
    "nosed": "noseless",
    "noseless": "nosed",
    "nourished": "malnourished",
    "numerate": "innumerate",
    "nursed": "bottlefeed",
    "oblate": "watermelon-shaped",
    "obligate": "facultative",
    "obligated": "unobligated",
    "occlusive": "continuant consonant",
    "odorless": "odorous",
    "odorous": "odourless",
    "odourless": "odorous",
    "off": "on",
    "off-line": "online",
    "off-site": "on-site",
    "off-street": "on-street",
    "offending": "unoffending",
    "offshore": "shoreward",
    "offstage": "onstage",
    "oiled": "unoiled",
    "oleophilic": "oleophobic",
    "oleophobic": "oleophilic",
    "omnidirectional": "directional",
    "omnivorous": "insectivorous",
    "on": "offerer",
    "on-line": "off-line",
    "on-site": "off-site",
    "on-street": "off-street",
    "one-dimensional": "multidimensional",
    "one-piece": "three-piece",
    "online": "off-line",
    "onomatopoeic": "nonechoic",
    "onomatopoeical": "nonechoic",
    "onomatopoetic": "nonechoic",
    "onshore": "offshore",
    "onstage": "offstage",
    "open-chain": "cyclic",
    "operable": "inoperable",
    "operational": "nonoperational",
    "opisthognathous": "prognathous",
    "opposable": "unopposable",
    "optimistic": "pessimistic",
    "ordered": "unordered",
    "orientated": "unoriented",
    "orientating": "disorienting",
    "oriented": "unoriented",
    "orienting": "disorienting",
    "original": "unoriginal",
    "orthotropous": "campylotropous",
    "ostentatious": "unpretending",
    "other": "same",
    "outboard": "inboard",
    "outer": "inner",
    "overarm": "underhand",
    "overdressed": "underdress",
    "overhand": "underhanded",
    "overhanded": "underhand",
    "overshot": "undershoot",
    "oviparous": "viviparous",
    "ovoviviparous": "oviparous",
    "owned": "unowned",
    "ownerless": "owned",
    "oxidised": "deoxidize",
    "oxidized": "deoxidize",
    "packaged": "unpackaged",
    "paintable": "unpaintable",
    "palingenetic": "cenogenetic",
    "paradigmatic": "syntagmatic",
    "pardonable": "unpardonable",
    "parented": "unparented",
    "parentless": "parented",
    "part-time": "full-time",
    "particularised": "generalize",
    "particularized": "generalize",
    "particulate": "nonparticulate",
    "parttime": "full-time",
    "passerine": "nonpasserine",
    "patronised": "unpatronized",
    "patronized": "unpatronized",
    "patronless": "patronized",
    "paved": "unpaved",
    "paying attention": "heedless",
    "peaked": "bottom out",
    "pedunculate": "stalkless",
    "penitent": "unremorseful",
    "perinatal": "prenatal",
    "peripteral": "apteral",
    "permanent": "temporary",
    "personalised": "depersonalize",
    "personalized": "depersonalize",
    "pessimistic": "optimistic",
    "petaled": "apetalous",
    "petalled": "apetalous",
    "petalless": "petalous",
    "petalous": "petalless",
    "petty": "grand larceny",
    "photosynthetic": "nonphotosynthetic",
    "pianissimo": "very loudly",
    "pigeon-toed": "splayfooted",
    "pistillate": "acarpelous",
    "placental": "aplacental",
    "planted": "unplanted",
    "plantigrade": "digitigrade",
    "platyrhine": "catarrhine",
    "platyrhinian": "catarrhine",
    "platyrrhine": "catarrhine",
    "platyrrhinian": "catarrhine",
    "platyrrhinic": "catarrhine",
    "plausible": "implausible",
    "playable": "unplayable",
    "pleasing": "displeasing",
    "pleurocarpous": "acrocarpous",
    "plucky": "gutless",
    "plumbable": "unfathomable",
    "plus": "minus",
    "political": "nonpolitical",
    "polychromatic": "monochromatic",
    "polygamous": "monogamous",
    "polyphonic": "monophonic",
    "polyploid": "diploid",
    "polytheistic": "monotheistic",
    "polyvalent": "monovalent",
    "ponderable": "imponderable",
    "posed": "unposed",
    "postmeridian": "antemeridian",
    "postmortal": "antemortem",
    "postmortem": "antemortem",
    "postnatal": "perinatal",
    "postnuptial": "prenuptial",
    "postpartum": "prenatal",
    "postprandial": "preprandial",
    "postwar": "prewar",
    "potable": "undrinkable",
    "potted": "unpotted",
    "powered": "unpowered",
    "precocial": "altricial",
    "predicative": "prenominal",
    "pregnant": "nonpregnant",
    "prehensile": "nonprehensile",
    "premarital": "postnuptial",
    "prenatal": "postpartum",
    "prenominal": "predicative",
    "prenuptial": "postnuptial",
    "preprandial": "postprandial",
    "presbyopic": "nearsighted",
    "presidential": "unpresidential",
    "pretty": "unreasonably",
    "preventable": "unpreventable",
    "prewar": "postwar",
    "principled": "unprincipled",
    "printable": "unprintable",
    "prix fixe": "a la carte",
    "pro-american": "anti-american",
    "pro-choice": "pro-lifer",
    "pro-life": "pro-choice",
    "procaryotic": "eukaryotic",
    "processed": "unrefined",
    "prognathic": "opisthognathous",
    "prognathous": "opisthognathous",
    "prokaryotic": "eukaryotic",
    "prolate": "pumpkin-shaped",
    "pronounceable": "unpronounceable",
    "propitious": "unpropitious",
    "proved": "unproven",
    "proven": "unproved",
    "provident": "improvident",
    "psychoactive": "nonpsychoactive",
    "psychotropic": "nonpsychoactive",
    "publicised": "suppressed",
    "publicized": "suppressed",
    "publishable": "unpublishable",
    "pumpkin-shaped": "prolate",
    "puncturable": "punctureless",
    "punctureless": "puncturable",
    "purebred": "crossbred",
    "purifying": "adulterating",
    "purposeful": "purposeless",
    "purposeless": "purposeful",
    "pyknic": "mesomorphic",
    "pyretic": "antipyretic",
    "quadruped": "bipedal",
    "quadrupedal": "two-footed",
    "quotable": "unrepeatable",
    "racial": "nonracial",
    "radical": "cauline",
    "radio-opaque": "radiolucent",
    "radiolucent": "radiopaque",
    "radiopaque": "radiolucent",
    "random": "nonrandom",
    "raw": "cooked",
    "reactive": "unreactive",
    "ready-made": "custom-made",
    "reasonable": "unreasonable",
    "receptive": "unreceptive",
    "reconstructed": "unreconstructed",
    "recorded": "unrecorded",
    "recusant": "conformist",
    "refined": "unrefined",
    "reflected": "unreflected",
    "regretful": "unregretting",
    "rejective": "acceptive",
    "remediable": "irremediable",
    "remote-controlled": "manned",
    "removable": "irremovable",
    "renewable": "unrenewable",
    "rentable": "unrentable",
    "repeatable": "unrepeatable",
    "repelling": "attract",
    "repetitious": "nonrepetitive",
    "repetitive": "nonrepetitive",
    "replaceable": "unreplaceable",
    "reportable": "unreportable",
    "representational": "nonrepresentational",
    "represented": "undelineated",
    "reprobate": "approbate",
    "reproducible": "unreproducible",
    "requested": "unrequested",
    "residential": "nonresidential",
    "resolved": "unsolved",
    "reticular": "nonreticulate",
    "reticulate": "nonreticulate",
    "retractile": "nonretractile",
    "retrorse": "antrorse",
    "returnable": "nonreturnable",
    "revealing": "concealing",
    "reverberant": "unreverberant",
    "revived": "unrevived",
    "rewarding": "unrewarding",
    "rh-negative": "rh-positive",
    "rh-positive": "rh-negative",
    "rhymed": "unrimed",
    "rhymeless": "rhymed",
    "rhyming": "unrhymed",
    "rifled": "unrifled",
    "rigged": "unrigged",
    "right-handed": "two-handed",
    "rimeless": "rhymed",
    "riming": "unrhymed",
    "rimless": "rimmed",
    "rimmed": "rimless",
    "roly-poly": "thin person",
    "romantic": "classicist",
    "romanticist": "classicist",
    "roofed": "roofless",
    "roofless": "roofed",
    "ruminant": "nonruminant",
    "run-on": "end-stopped",
    "rusted": "rustless",
    "rustless": "rusted",
    "saddled": "unsaddled",
    "sadistic": "masochistic",
    "salable": "unsaleable",
    "saleable": "unsalable",
    "same": "other",
    "sanctified": "desecrate",
    "sandlike": "argillaceous",
    "sandy": "argillaceous",
    "saponified": "unsaponified",
    "sarcastic": "unsarcastic",
    "satiate": "unsatiable",
    "satiated": "insatiate",
    "satisfied": "fall short of",
    "satisfying": "fall short of",
    "scalable": "unscalable",
    "scented": "scentless",
    "scentless": "scented",
    "scheduled": "unscheduled",
    "scrimpy": "ample",
    "scripted": "unscripted",
    "sealed": "unsealed",
    "seamanlike": "unseamanlike",
    "seamanly": "unseamanlike",
    "seasonable": "unseasonable",
    "seasonal": "year-round",
    "seaward": "inshore",
    "seaworthy": "unseaworthy",
    "second": "first",
    "seeded": "unseeded",
    "seedless": "seedy",
    "seedy": "seedless",
    "selected": "unselected",
    "self-asserting": "unassertive",
    "self-assertive": "unassertive",
    "self-centered": "altruistic",
    "self-centred": "altruistic",
    "selfless": "egoistic",
    "sensible": "insensible",
    "sensitised": "desensitize",
    "sensitising": "desensitizing",
    "sensitized": "desensitize",
    "sensitizing": "desensitizing",
    "sent": "unsent",
    "sessile": "vagile",
    "sexual": "nonsexual",
    "shaded": "unshaded",
    "shallow": "deep",
    "shared": "unshared",
    "shaved": "unshaven",
    "shaven": "unshaven",
    "sheared": "unshorn",
    "sheathed": "unsheathed",
    "shell-less": "shelled",
    "shelled": "unshelled",
    "shiny": "unglazed",
    "shockable": "unshockable",
    "shod": "unshoed",
    "shodden": "unshod",
    "shoed": "unshod",
    "shoreward": "offshore",
    "shorn": "unsheared",
    "short-spurred": "long-spurred",
    "shortsighted": "farsighted",
    "shrinkable": "unshrinkable",
    "shut up": "open up",
    "shuttered": "unshuttered",
    "signed": "unsigned",
    "silenced": "unsilenced",
    "single-barreled": "double-barrelled",
    "single-barrelled": "double-barreled",
    "single-breasted": "double-breasted",
    "single-lane": "multilane",
    "sinistral": "dextral",
    "sinkable": "unsinkable",
    "sized": "unsized",
    "skew": "line up",
    "skewed": "align",
    "skinless": "skinned",
    "skinned": "skinless",
    "slight": "much",
    "slippery": "nonslippery",
    "slippy": "nonslippery",
    "smoothbore": "rifled",
    "smoothed": "roughen",
    "smoothened": "roughen",
    "snarled": "disentangle",
    "so-so": "unacceptably",
    "socialist": "capitalistic",
    "socialistic": "capitalistic",
    "soft-boiled": "hardhearted",
    "softhearted": "heartless",
    "sold": "unsolder",
    "soled": "soleless",
    "soleless": "soled",
    "solved": "unsolved",
    "some": "no",
    "sonant": "unvoiced",
    "sonic": "supersonic",
    "sorry": "unregretful",
    "soundable": "unfathomable",
    "soured": "unsoured",
    "south": "north",
    "southern": "northern",
    "spaced": "unspaced",
    "spacial": "nonspatial",
    "spatial": "nonspatial",
    "specialised": "unspecialized",
    "specialized": "unspecialized",
    "spineless": "spiny",
    "spinous": "spineless",
    "spiny": "spineless",
    "spirited": "spiritless",
    "spiritless": "spirited",
    "splayfoot": "pigeon-toed",
    "splayfooted": "pigeon-toed",
    "stabilised": "destabilize",
    "stabilising": "destabilize",
    "stabilized": "destabilize",
    "stabilizing": "destabilize",
    "staged": "unstaged",
    "stained": "unstained",
    "stalked": "sessile",
    "stalkless": "pedunculate",
    "starchless": "starchy",
    "starchy": "starchless",
    "starved": "be full",
    "starving": "be full",
    "statesmanlike": "unstatesmanlike",
    "statesmanly": "unstatesmanlike",
    "stemless": "stemmed",
    "stemmed": "stemless",
    "steroidal": "nonsteroidal",
    "stigmatic": "astigmatic",
    "stimulating": "unstimulating",
    "stimulative": "depressant",
    "stoic": "emotional person",
    "stomatous": "mouthless",
    "stoppable": "unstoppable",
    "stratified": "unstratified",
    "stressed": "unstressed",
    "strong": "weak",
    "structured": "unstructured",
    "subartesian": "artesian",
    "subjacent": "superjacent",
    "submissive": "domineering",
    "subordinating": "coordinative",
    "subordinative": "coordinating",
    "subscript": "superscript",
    "subsonic": "transonic",
    "substantial": "unsubstantial",
    "suckled": "bottlefeed",
    "sugarless": "sugary",
    "sugary": "sugarless",
    "superjacent": "subjacent",
    "supernal": "infernal",
    "superscript": "adscript",
    "supersonic": "subsonic",
    "supervised": "unsupervised",
    "supportive": "unsupportive",
    "suppressed": "publicized",
    "suppurative": "nonsuppurative",
    "surd": "voiced",
    "surface-assimilative": "nonadsorbent",
    "surface-to-air": "air-to-air",
    "swept": "unswept",
    "sworn": "unsworn",
    "sympatric": "allopatric",
    "syncarpous": "apocarpous",
    "syncategorematic": "categorematic",
    "synclinal": "anticlinal",
    "syndetic": "asyndetic",
    "syntagmatic": "paradigmatic",
    "table d'hote": "a la carte",
    "taciturn": "voluble",
    "tactful": "untactful",
    "tactless": "tactful",
    "tagged": "unlabeled",
    "taken": "give",
    "taking": "give",
    "tapped": "untapped",
    "taxable": "nontaxable",
    "temporary": "permanent",
    "textbook": "trade edition",
    "thematic": "unthematic",
    "thermoplastic": "thermosetting",
    "thermoset": "thermoplastic",
    "thermosetting": "thermoplastic",
    "three-piece": "two-piece",
    "tied": "untied",
    "timbered": "untimbered",
    "tipped": "untipped",
    "toed": "toeless",
    "toeless": "toed",
    "tonal": "unkeyed",
    "toned": "toneless",
    "toneless": "toned",
    "tongued": "tongueless",
    "tongueless": "tongued",
    "top-down": "bottom-up",
    "topless": "topped",
    "topped": "topless",
    "traceable": "untraceable",
    "trackable": "untraceable",
    "tracked": "trackless",
    "trackless": "tracked",
    "tramontane": "cismontane",
    "transeunt": "immanent",
    "transient": "immanent",
    "translatable": "untranslatable",
    "translational": "nontranslational",
    "transmontane": "cismontane",
    "transonic": "subsonic",
    "traveled": "untravelled",
    "treated": "untreated",
    "tree-living": "nonarboreal",
    "treeless": "wooded",
    "triclinic": "monoclinic",
    "trimmed": "untrimmed",
    "trinuclear": "mononuclear",
    "trinucleate": "binucleated",
    "trinucleated": "mononuclear",
    "troubled": "untroubled",
    "true-false": "multiple-choice",
    "trustful": "distrustful",
    "trusting": "distrustful",
    "tubed": "tubeless",
    "tubeless": "tubed",
    "tucked": "untucked",
    "tuneful": "untuneful",
    "tuneless": "tuneful",
    "turned": "unturned",
    "two-footed": "quadrupedal",
    "two-handed": "right-handed",
    "two-piece": "one-piece",
    "two-sided": "nonreversible",
    "typical": "untypical",
    "ultra vires": "intra vires",
    "unabridged": "abridged",
    "unabused": "mistreated",
    "unaccommodating": "accommodative",
    "unacquisitive": "acquisitive",
    "unactable": "actable",
    "unaddicted": "addicted",
    "unaddressed": "addressed",
    "unadjusted": "adjusted",
    "unadoptable": "adoptable",
    "unadorned": "decorated",
    "unadvised": "well-advised",
    "unaffected": "affected",
    "unaffixed": "affixed",
    "unairworthy": "airworthy",
    "unalterable": "alterable",
    "unamended": "amended",
    "unanalyzed": "analyzed",
    "unappealable": "appealable",
    "unappendaged": "appendaged",
    "unappetising": "appetizing",
    "unappetizing": "appetizing",
    "unapproachable": "approachable",
    "unarbitrary": "arbitrary",
    "unarticulated": "articulated",
    "unassertive": "self-assertive",
    "unassigned": "assigned",
    "unavailable": "available",
    "unavenged": "avenged",
    "unawakened": "awakened",
    "unawed": "awestruck",
    "unbalconied": "balconied",
    "unbanded": "banded",
    "unbaptised": "baptized",
    "unbaptized": "baptized",
    "unbarreled": "barrelled",
    "unbarrelled": "barreled",
    "unbelted": "belted",
    "unbeneficed": "beneficed",
    "unblemished": "blemished",
    "unblended": "blended",
    "unbodied": "bodied",
    "unbordered": "bordered",
    "unbrainwashed": "brainwashed",
    "unbranded": "branded",
    "unbridgeable": "bridgeable",
    "unburdened": "burdened",
    "unbuttoned": "buttoned",
    "uncamphorated": "camphorated",
    "uncared-for": "cared-for",
    "uncarpeted": "carpeted",
    "uncarved": "carven",
    "uncastrated": "unsexed",
    "uncaulked": "caulked",
    "uncensored": "censored",
    "uncertified": "certified",
    "uncharged": "charged",
    "unchaste": "chaste",
    "unchristian": "christian",
    "unclassified": "classified",
    "unclear": "well-defined",
    "uncleared": "cleared",
    "unclimbable": "scalable",
    "unclothed": "clothed",
    "uncoated": "coated",
    "uncolumned": "columned",
    "uncombed": "combed",
    "uncompartmented": "compartmented",
    "uncomplaining": "complaintive",
    "uncomplete": "complete",
    "unconformist": "conformist",
    "unconquerable": "conquerable",
    "unconsolable": "consolable",
    "unconstipated": "constipated",
    "unconstricted": "constricted",
    "unconsummated": "consummated",
    "uncorrected": "corrected",
    "uncousinly": "cousinly",
    "uncrannied": "crannied",
    "uncrowned": "crowned",
    "uncrystallised": "crystallized",
    "uncrystallized": "crystallized",
    "uncurtained": "curtained",
    "undamaged": "damaged",
    "undatable": "dateable",
    "undeciphered": "deciphered",
    "undeclared": "declared",
    "undecorated": "adorned",
    "undedicated": "dedicated",
    "undelineated": "represented",
    "undemocratic": "democratic",
    "underarm": "overhand",
    "underdressed": "overdress",
    "underhand": "overhanded",
    "underhanded": "overhand",
    "underived": "derived",
    "undershot": "overshoot",
    "undetected": "detected",
    "undifferentiated": "differentiated",
    "undimmed": "dimmer",
    "undocumented": "documented",
    "undrinkable": "potable",
    "unedifying": "edifying",
    "unemployable": "employable",
    "unenclosed": "enclosed",
    "unenforceable": "enforceable",
    "unenforced": "implemented",
    "unenlightened": "enlightened",
    "unenlightening": "informative",
    "unenlivened": "enlivened",
    "unenthusiastic": "enthusiastic",
    "unequipped": "equipt",
    "unexchangeable": "exchangeable",
    "unexpendable": "expendable",
    "unexploited": "exploited",
    "unexplorative": "exploratory",
    "unexploratory": "exploratory",
    "unexportable": "exportable",
    "unexpressible": "expressible",
    "unfaceted": "faceted",
    "unfastened": "fastened",
    "unfastidious": "fastidious",
    "unfathomable": "soundable",
    "unfeathered": "feathered",
    "unfilled": "filled",
    "unfit": "fitter",
    "unfledged": "fledged",
    "unfocused": "focussed",
    "unfocussed": "focused",
    "unforceful": "forceful",
    "unforgettable": "forgettable",
    "unframed": "framed",
    "unfretted": "fretted",
    "unfueled": "fueled",
    "unfunded": "funded",
    "unfurrowed": "furrowed",
    "ungeared": "geared",
    "unglazed": "shiny",
    "ungrammatical": "well-formed",
    "ungreased": "lubricated",
    "ungroomed": "groomed",
    "unguiculate": "ungulated",
    "unguiculated": "ungulate",
    "unguided": "guided",
    "ungulate": "unguiculated",
    "ungulated": "unguiculate",
    "ungusseted": "gusseted",
    "unharmonious": "harmonious",
    "unheaded": "headed",
    "unheeding": "heedful",
    "unicameral": "bicameral",
    "unidentifiable": "identifiable",
    "unidimensional": "multidimensional",
    "unidirectional": "bidirectional",
    "unified": "disunify",
    "unifying": "disunify",
    "unilluminating": "enlightening",
    "unimodal": "bimodal",
    "unimpaired": "impaired",
    "unimpressive": "impressive",
    "uninflected": "inflected",
    "uninformative": "informatory",
    "uninhibited": "inhibited",
    "uninjectable": "injectable",
    "uninspiring": "inspiring",
    "uninsured": "insured",
    "uninucleate": "multinucleate",
    "uninvolved": "involved",
    "unionised": "ionized",
    "unionized": "ionized",
    "uniparous": "multiparous",
    "unipolar": "bipolar",
    "unironed": "ironed",
    "univalent": "multivalent",
    "univalve": "bivalved",
    "unkeyed": "tonal",
    "unkindly": "kindly",
    "unlabeled": "tagged",
    "unlabelled": "labeled",
    "unlaced": "laced",
    "unlamented": "lamented",
    "unlaureled": "laurelled",
    "unlaurelled": "laureled",
    "unleaded": "leaded",
    "unleavened": "leavened",
    "unlighted": "lit",
    "unlipped": "lipped",
    "unlisted": "listed",
    "unlit": "lighted",
    "unlivable": "liveable",
    "unliveable": "livable",
    "unliveried": "liveried",
    "unloved": "loved",
    "unlubricated": "lubricated",
    "unmade": "made",
    "unmalted": "malted",
    "unmanned": "manned",
    "unmarred": "blemished",
    "unmated": "mated",
    "unmelted": "melted",
    "unmentionable": "overgarment",
    "unmerited": "merited",
    "unmined": "mined",
    "unmixable": "miscible",
    "unmodulated": "modulated",
    "unmotivated": "motivated",
    "unmotorised": "motorized",
    "unmotorized": "motorized",
    "unmourned": "lamented",
    "unmown": "mown",
    "unmutilated": "blemished",
    "unmyelinated": "myelinated",
    "unobligated": "obligated",
    "unobliging": "accommodating",
    "unoffending": "offending",
    "unoiled": "oiled",
    "unopposable": "opposable",
    "unordered": "ordered",
    "unoriented": "oriented",
    "unoriginal": "original",
    "unostentatious": "ostentatious",
    "unowned": "owned",
    "unpackaged": "packaged",
    "unpaintable": "paintable",
    "unpardonable": "pardonable",
    "unparented": "parented",
    "unpatronised": "patronized",
    "unpatronized": "patronized",
    "unpaved": "paved",
    "unplanted": "planted",
    "unplayable": "playable",
    "unposed": "posed",
    "unpotted": "potted",
    "unpowered": "powered",
    "unpresidential": "presidential",
    "unpretending": "ostentatious",
    "unpreventable": "preventable",
    "unprincipled": "principled",
    "unprintable": "printable",
    "unprocessed": "refined",
    "unpronounceable": "pronounceable",
    "unpropitious": "propitious",
    "unproved": "proven",
    "unproven": "proved",
    "unpublishable": "publishable",
    "unquotable": "repeatable",
    "unraised": "leavened",
    "unreactive": "reactive",
    "unreasonable": "sensible",
    "unreceptive": "receptive",
    "unrecognisable": "recognizably",
    "unreconstructed": "reconstructed",
    "unrecorded": "recorded",
    "unrefined": "refined",
    "unreflected": "reflected",
    "unregretful": "sorry",
    "unregretting": "regretful",
    "unremorseful": "penitent",
    "unrenewable": "renewable",
    "unrenewed": "revived",
    "unrentable": "rentable",
    "unrepeatable": "repeatable",
    "unreplaceable": "replaceable",
    "unreportable": "reportable",
    "unreproducible": "reproducible",
    "unrequested": "requested",
    "unresolved": "solved",
    "unreverberant": "reverberant",
    "unrevived": "revived",
    "unrewarding": "rewarding",
    "unrhymed": "riming",
    "unrifled": "rifled",
    "unrigged": "rigged",
    "unrimed": "rhymed",
    "unsaddled": "saddled",
    "unsalable": "saleable",
    "unsaleable": "salable",
    "unsaponified": "saponified",
    "unsarcastic": "sarcastic",
    "unsatiable": "satiate",
    "unscalable": "scalable",
    "unscheduled": "scheduled",
    "unscripted": "scripted",
    "unsealed": "sealed",
    "unseamanlike": "seamanly",
    "unseasonable": "seasonable",
    "unseaworthy": "seaworthy",
    "unseeded": "seeded",
    "unselected": "selected",
    "unsent": "sent",
    "unsexed": "uncastrated",
    "unshaded": "shaded",
    "unshared": "shared",
    "unshaved": "shaven",
    "unshaven": "shaven",
    "unsheared": "shorn",
    "unsheathed": "sheathed",
    "unshelled": "shelled",
    "unshockable": "shockable",
    "unshod": "shoed",
    "unshoed": "shod",
    "unshorn": "sheared",
    "unshrinkable": "shrinkable",
    "unshuttered": "shuttered",
    "unsigned": "signed",
    "unsilenced": "silenced",
    "unsinkable": "sinkable",
    "unsized": "sized",
    "unsnarled": "entangle",
    "unsold": "solderer",
    "unsolved": "solved",
    "unsoured": "soured",
    "unspaced": "spaced",
    "unspecialised": "specialized",
    "unspecialized": "specialized",
    "unstaged": "staged",
    "unstained": "stained",
    "unstatesmanlike": "statesmanly",
    "unstimulating": "stimulating",
    "unstoppable": "stoppable",
    "unstratified": "stratified",
    "unstressed": "stressed",
    "unstructured": "structured",
    "unsubstantial": "substantial",
    "unsupervised": "supervised",
    "unsupportive": "supportive",
    "unswept": "swept",
    "unsworn": "sworn",
    "unsyllabic": "syllabic",
    "untactful": "tactful",
    "untagged": "labeled",
    "untapped": "tapped",
    "unthematic": "thematic",
    "unthinking": "thoughtfully",
    "untied": "tied",
    "untimbered": "timbered",
    "untipped": "tipped",
    "untraceable": "trackable",
    "untranslatable": "translatable",
    "untraveled": "traveled",
    "untravelled": "traveled",
    "untreated": "treated",
    "untrimmed": "trimmed",
    "untroubled": "troubled",
    "untucked": "tucked",
    "untuneful": "tuneful",
    "unturned": "turned",
    "untypical": "typical",
    "unventilated": "ventilated",
    "unvoiced": "voiced",
    "unwanted": "wanted",
    "unwaxed": "waxed",
    "unweaned": "weaned",
    "unwearable": "wearable",
    "unwebbed": "webbed",
    "unwieldy": "wieldy",
    "unwooded": "wooded",
    "unwoven": "woven",
    "unwrapped": "wrapped",
    "up": "downwardly",
    "upbeat": "ill-being",
    "upmarket": "downmarket",
    "upper-class": "middle-class",
    "uppercase": "small letter",
    "upstage": "downstage",
    "upstream": "downriver",
    "uptown": "downtown",
    "upward": "down",
    "upwind": "downwind",
    "used": "misused",
    "uxorial": "husbandly",
    "vagile": "sessile",
    "ventilated": "unventilated",
    "vertebrate": "spineless",
    "violable": "inviolable",
    "violated": "conform to",
    "virulent": "avirulent",
    "vitalizing": "devitalize",
    "viviparous": "ovoviviparous",
    "vocalic": "consonantal",
    "voiced": "voiceless",
    "voiceless": "voiced",
    "volatile": "nonvolatilizable",
    "voluble": "taciturn",
    "voteless": "enfranchised",
    "walleyed": "cross-eyed",
    "wanted": "unwanted",
    "warm-blooded": "cold-blooded",
    "warmhearted": "coldhearted",
    "washable": "nonwashable",
    "wasted": "hypertrophied",
    "watermelon-shaped": "oblate",
    "waxed": "unwaxed",
    "weak": "strong",
    "weaned": "unweaned",
    "wearable": "unwearable",
    "webbed": "unwebbed",
    "well-advised": "unadvised",
    "well-defined": "unclear",
    "well-formed": "ungrammatical",
    "west": "east",
    "westerly": "easterly",
    "wheeled": "wheelless",
    "wheelless": "wheeled",
    "white-collar": "blue-collar",
    "whitened": "blacken",
    "wieldy": "unwieldy",
    "wifelike": "husbandly",
    "wifely": "husbandly",
    "wigged": "wigless",
    "wigless": "wigged",
    "windward": "lees",
    "wooded": "unwooded",
    "worst": "best",
    "woven": "unwoven",
    "wrapped": "unwrapped",
    "xenogeneic": "allogeneic",
    "xeric": "mesic",
    "year-around": "seasonal",
    "year-round": "seasonal",
    "zonal": "azonal",
    "zygodactyl": "heterodactyl",
    "zygomorphic": "actinomorphous",
    "zygomorphous": "actinomorphic",
    "abaxially": "adaxially",
    "ably": "incompetently",
    "aborad": "orad",
    "abstractly": "concretely",
    "acceptably": "unacceptably",
    "accurately": "inaccurately",
    "actively": "passively",
    "adaxially": "abaxially",
    "adequately": "inadequately",
    "adroitly": "maladroitly",
    "against the wind": "downwind",
    "agreeably": "disagreeably",
    "alas": "fortunately",
    "allowably": "impermissibly",
    "always": "never",
    "amateurishly": "like an expert",
    "ambiguously": "unequivocally",
    "ambitiously": "unambitiously",
    "amorally": "morally",
    "appealingly": "unappealingly",
    "appreciatively": "unappreciatively",
    "appropriately": "unsuitably",
    "approvingly": "disapprovingly",
    "aptly": "incompetently",
    "aright": "incorrectly",
    "articulately": "ineloquently",
    "as luck would have it": "unfortunately",
    "ashamedly": "unashamedly",
    "assertively": "unassertively",
    "asymmetrically": "symmetrically",
    "at a lower place": "above",
    "at best": "at worst",
    "at least": "at the most",
    "at most": "at the least",
    "at that place": "here",
    "at the best": "at worst",
    "at the least": "at most",
    "at the most": "at least",
    "at the worst": "at best",
    "at worst": "at the best",
    "attractively": "unattractively",
    "audibly": "inaudibly",
    "auspiciously": "unpropitiously",
    "barefacedly": "ashamedly",
    "beautifully": "unattractively",
    "befittingly": "inappropriately",
    "believably": "unbelievably",
    "believingly": "incredulously",
    "below": "to a higher place",
    "beneath": "above",
    "benevolently": "malevolently",
    "beyond control": "in hand",
    "binaurally": "to one ear",
    "bloodily": "bloodlessly",
    "bloodlessly": "bloodily",
    "broad-mindedly": "small-mindedly",
    "broadly": "narrowly",
    "broadly speaking": "narrowly",
    "but then": "on the one hand",
    "by all means": "not by a long sight",
    "by hand": "by machine",
    "by machine": "by hand",
    "by no means": "by all means",
    "by trial and error": "theoretically",
    "capably": "incompetently",
    "ceremonially": "unceremoniously",
    "ceremoniously": "unceremoniously",
    "characteristically": "uncharacteristically",
    "cheaply": "expensively",
    "cheerfully": "cheerlessly",
    "cheerlessly": "cheerfully",
    "chivalrously": "unchivalrously",
    "civilly": "uncivilly",
    "clearly": "unintelligibly",
    "coarsely": "finely",
    "coherently": "incoherently",
    "comfortably": "uncomfortably",
    "comparably": "uncomparably",
    "compatibly": "incompatibly",
    "competently": "incompetently",
    "competitively": "noncompetitively",
    "complainingly": "uncomplainingly",
    "comprehensively": "noncomprehensively",
    "concavely": "convexly",
    "conclusively": "inconclusively",
    "concretely": "abstractly",
    "confidingly": "distrustfully",
    "consciously": "unconsciously",
    "consequentially": "inconsequently",
    "considerately": "inconsiderately",
    "conspicuously": "inconspicuously",
    "constitutionally": "unconstitutionally",
    "controversially": "uncontroversially",
    "conveniently": "inconveniently",
    "conventionally": "unconventionally",
    "convexly": "concavely",
    "convincingly": "unconvincingly",
    "correctly": "incorrectly",
    "courteously": "impolitely",
    "covertly": "overtly",
    "crazily": "sanely",
    "credibly": "unbelievably",
    "credulously": "unbelievingly",
    "critically": "uncritically",
    "deceitfully": "honestly",
    "decently": "indecently",
    "decipherably": "illegibly",
    "decisively": "indecisively",
    "decorously": "unbecomingly",
    "defensively": "offensively",
    "dementedly": "sanely",
    "democratically": "undemocratically",
    "densely": "thinly",
    "dependably": "unfaithfully",
    "deservedly": "undeservedly",
    "determinedly": "unambitiously",
    "detrimentally": "harmlessly",
    "diplomatically": "undiplomatically",
    "disagreeably": "agreeably",
    "disapprovingly": "approvingly",
    "disbelievingly": "credulously",
    "discouragingly": "encouragingly",
    "discourteously": "politely",
    "discreetly": "indiscreetly",
    "dishonestly": "honestly",
    "dishonorably": "uprightly",
    "disloyally": "loyally",
    "displaying incompetence": "competently",
    "disproportionately": "proportionately",
    "disreputably": "reputably",
    "disrespectfully": "respectfully",
    "distrustfully": "trustingly",
    "downriver": "upriver",
    "downwardly": "up",
    "dramatically": "undramatically",
    "e'er": "never",
    "effectively": "inefficaciously",
    "efficaciously": "inefficaciously",
    "efficiently": "inefficiently",
    "egotistically": "unselfishly",
    "elegantly": "inelegantly",
    "eloquently": "ineloquently",
    "emotionally": "unemotionally",
    "empathetically": "unsympathetically",
    "empirically": "theoretically",
    "encouragingly": "discouragingly",
    "enjoyably": "unpleasantly",
    "enthusiastically": "unenthusiastically",
    "equitably": "inequitably",
    "equivocally": "unambiguously",
    "ethically": "unethically",
    "evenly": "unevenly",
    "ever": "never",
    "excitingly": "unexcitingly",
    "excusably": "unpardonably",
    "expediently": "inexpediently",
    "expeditiously": "inefficiently",
    "expensively": "tattily",
    "expertly": "amateurishly",
    "explicitly": "implicitly",
    "expressively": "inexpressively",
    "faithfully": "unreliably",
    "falteringly": "steadily",
    "fashionably": "unfashionably",
    "favorably": "unfavourably",
    "favourably": "unfavorably",
    "feelingly": "unfeelingly",
    "felicitously": "infelicitously",
    "finely": "coarsely",
    "fitly": "inappropriately",
    "fittingly": "inappropriately",
    "flexibly": "inflexibly",
    "foolishly": "wisely",
    "forgivably": "inexcusably",
    "forgivingly": "unforgivingly",
    "formally": "informally",
    "fortuitously": "unfortunately",
    "fortunately": "unluckily",
    "fruitfully": "unproductively",
    "fruitlessly": "productively",
    "gallantly": "unchivalrously",
    "geometrically": "linearly",
    "gleefully": "joylessly",
    "gracefully": "gracelessly",
    "grammatically": "ungrammatically",
    "gratefully": "ungratefully",
    "handily": "inconveniently",
    "harmfully": "harmlessly",
    "harmlessly": "noxiously",
    "hastily": "unhurriedly",
    "heedfully": "unmindfully",
    "helpfully": "unhelpfully",
    "hesitantly": "unhesitatingly",
    "hesitatingly": "unhesitatingly",
    "higher up": "below",
    "hither": "there",
    "honestly": "venally",
    "honorably": "dishonorably",
    "honourably": "dishonorably",
    "hopefully": "hopelessly",
    "hopelessly": "hopefully",
    "hospitably": "inhospitably",
    "humanely": "inhumanely",
    "humorlessly": "humorously",
    "humorously": "humourlessly",
    "humourlessly": "humorously",
    "hurriedly": "unhurriedly",
    "hygienically": "unhygienically",
    "illegally": "lawfully",
    "illegibly": "readably",
    "illegitimately": "licitly",
    "illicitly": "legitimately",
    "illogically": "logically",
    "imaginatively": "unimaginatively",
    "immaturely": "maturely",
    "immodestly": "modestly",
    "immorally": "virtuously",
    "impatiently": "patiently",
    "impenitently": "repentantly",
    "imperceptibly": "perceptibly",
    "impermissibly": "permissibly",
    "impersonally": "personally",
    "implausibly": "credibly",
    "implicitly": "explicitly",
    "impolitely": "politely",
    "imposingly": "unimpressively",
    "impressively": "unimpressively",
    "improbably": "credibly",
    "improperly": "the right way",
    "improvidently": "providently",
    "imprudently": "prudently",
    "in a higher place": "below",
    "in both ears": "monaurally",
    "in good order": "improperly",
    "in hand": "out of hand",
    "in haste": "unhurriedly",
    "in one ear": "binaurally",
    "in that location": "here",
    "in the first place": "secondarily",
    "inaccurately": "accurately",
    "inadequately": "adequately",
    "inadvisably": "inexpediently",
    "inappropriately": "suitably",
    "inarticulately": "eloquently",
    "inaudibly": "audibly",
    "inauspiciously": "propitiously",
    "incoherently": "coherently",
    "incomparably": "comparably",
    "incompatibly": "compatibly",
    "incompetently": "competently",
    "inconclusively": "once and for all",
    "inconsequentially": "consequentially",
    "inconsequently": "consequentially",
    "inconsiderately": "considerately",
    "inconsistently": "consistently",
    "inconspicuously": "conspicuously",
    "inconveniently": "handily",
    "incorrectly": "correctly",
    "incredibly": "probably",
    "incredulously": "credulously",
    "indecently": "decently",
    "indecisively": "decisively",
    "indecorously": "decorously",
    "indiscreetly": "discreetly",
    "ineffectively": "efficaciously",
    "inefficaciously": "efficaciously",
    "inefficiently": "expeditiously",
    "inelegantly": "elegantly",
    "ineloquently": "eloquently",
    "inequitably": "equitably",
    "inexcusably": "pardonably",
    "inexpediently": "inadvisably",
    "inexpensively": "expensively",
    "inexpressively": "expressively",
    "infelicitously": "felicitously",
    "inflexibly": "flexibly",
    "informally": "formally",
    "informatively": "uninstructively",
    "inhospitably": "hospitably",
    "inhumanely": "humanely",
    "injudiciously": "judiciously",
    "inoffensively": "offensively",
    "inopportunely": "opportunely",
    "inorganically": "organically",
    "insanely": "sanely",
    "insecurely": "securely",
    "insensitively": "sensitively",
    "inseparably": "separably",
    "insignificantly": "significantly",
    "insincerely": "unfeignedly",
    "instructively": "uninformatively",
    "intelligently": "unintelligently",
    "intelligibly": "ununderstandably",
    "interestingly": "uninterestingly",
    "into the wind": "downwind",
    "intolerably": "acceptably",
    "intolerantly": "tolerantly",
    "intransitively": "transitively",
    "inwardly": "outwardly",
    "irrationally": "rationally",
    "irrelevantly": "relevantly",
    "irresponsibly": "responsibly",
    "irreverently": "reverently",
    "jejunely": "maturely",
    "joyfully": "joylessly",
    "joylessly": "joyously",
    "joyously": "joylessly",
    "judiciously": "injudiciously",
    "justifiably": "unjustifiably",
    "justifiedly": "unjustly",
    "justly": "unjustly",
    "lawfully": "unlawfully",
    "lawlessly": "lawfully",
    "legally": "unlawfully",
    "legibly": "unreadably",
    "legitimately": "out of wedlock",
    "licitly": "illegitimately",
    "like an expert": "amateurishly",
    "linearly": "geometrically",
    "logically": "illogically",
    "loosely": "narrowly",
    "loyally": "disloyally",
    "luckily": "unfortunately",
    "madly": "sanely",
    "maladroitly": "adroitly",
    "malevolently": "benevolently",
    "manageably": "unmanageably",
    "manfully": "unmanfully",
    "maturely": "jejunely",
    "maximally": "minimally",
    "melodiously": "unmelodiously",
    "memorably": "unmemorably",
    "mendaciously": "truthfully",
    "mindfully": "unmindfully",
    "minimally": "maximally",
    "mistrustfully": "trustfully",
    "modestly": "immodestly",
    "monaurally": "to both ears",
    "morally": "immorally",
    "multilaterally": "unilaterally",
    "musically": "unmusically",
    "narrow-mindedly": "broad-mindedly",
    "narrowly": "loosely",
    "ne'er": "ever",
    "nearer": "far",
    "nearest": "far",
    "never": "ever",
    "nigher": "far",
    "nighest": "far",
    "noncompetitively": "competitively",
    "noncomprehensively": "comprehensively",
    "not by a blame sight": "by all means",
    "not by a long sight": "by all means",
    "noticeably": "imperceptibly",
    "noxiously": "harmlessly",
    "objectively": "subjectively",
    "observably": "imperceptibly",
    "obtrusively": "unobtrusively",
    "offensively": "inoffensively",
    "officially": "unofficially",
    "on one hand": "on the other hand",
    "on the one hand": "then again",
    "on the other hand": "on the one hand",
    "once and for all": "inconclusively",
    "one-sidedly": "multilaterally",
    "opportunely": "inopportunely",
    "optimistically": "pessimistically",
    "orad": "aborad",
    "organically": "inorganically",
    "out of hand": "in hand",
    "out of wedlock": "legitimately",
    "outwardly": "inwardly",
    "overtime": "regulation time",
    "overtly": "covertly",
    "palatably": "unpalatably",
    "pardonably": "inexcusably",
    "passably": "unreasonably",
    "passively": "actively",
    "patiently": "impatiently",
    "patriotically": "unpatriotically",
    "penitentially": "impenitently",
    "penitently": "unrepentantly",
    "perceptibly": "unnoticeably",
    "permissibly": "impermissibly",
    "personally": "impersonally",
    "pessimistically": "optimistically",
    "plausibly": "incredibly",
    "pleasantly": "unpleasantly",
    "please": "displease",
    "polemically": "uncontroversially",
    "politely": "rudely",
    "precedentedly": "unprecedentedly",
    "pretentiously": "unpretentiously",
    "primarily": "secondarily",
    "probably": "incredibly",
    "productively": "unprofitably",
    "profitably": "unproductively",
    "properly": "improperly",
    "propitiously": "inauspiciously",
    "proportionally": "disproportionately",
    "proportionately": "disproportionately",
    "providentially": "imprudently",
    "providently": "improvidently",
    "prudently": "imprudently",
    "rationally": "irrationally",
    "readably": "illegibly",
    "realistically": "unrealistically",
    "reasonably": "unreasonably",
    "recognizably": "unrecognizably",
    "regrettably": "fortunately",
    "relevantly": "irrelevantly",
    "reliably": "unfaithfully",
    "repentantly": "impenitently",
    "reputably": "disreputably",
    "respectfully": "disrespectfully",
    "responsibly": "irresponsibly",
    "reverentially": "irreverently",
    "reverently": "irreverently",
    "righteously": "unrighteously",
    "rightly": "unjustly",
    "romantically": "unromantically",
    "rudely": "politely",
    "sagely": "foolishly",
    "sanely": "madly",
    "seasonably": "unseasonably",
    "secondarily": "primarily",
    "securely": "insecurely",
    "self-consciously": "unselfconsciously",
    "selfishly": "unselfishly",
    "sensibly": "unreasonably",
    "sensitively": "insensitively",
    "sentimentally": "unsentimentally",
    "separably": "inseparably",
    "shamelessly": "ashamedly",
    "significantly": "insignificantly",
    "sincerely": "insincerely",
    "small-mindedly": "broad-mindedly",
    "smilingly": "unsmilingly",
    "sociably": "unsociably",
    "somewhat": "unreasonably",
    "sportingly": "unsportingly",
    "steadily": "unsteadily",
    "subjectively": "objectively",
    "successfully": "unsuccessfully",
    "suitably": "inappropriately",
    "supra": "below",
    "symmetrically": "unsymmetrically",
    "sympathetically": "unsympathetically",
    "tactfully": "tactlessly",
    "tactlessly": "tactfully",
    "tastefully": "tastelessly",
    "tastelessly": "tastily",
    "tastily": "tastelessly",
    "tattily": "expensively",
    "the right way": "improperly",
    "then again": "on the one hand",
    "theoretically": "through empirical observation",
    "there": "hither",
    "thickly": "thinly",
    "thinly": "thickly",
    "thither": "here",
    "thoughtfully": "unthinkingly",
    "thoughtlessly": "thoughtfully",
    "through empirical observation": "theoretically",
    "to a greater extent": "less",
    "to a higher place": "below",
    "to a lesser extent": "more",
    "to a lower place": "above",
    "to both ears": "monaurally",
    "to one ear": "binaurally",
    "to the highest degree": "least",
    "to the lowest degree": "most",
    "tolerably": "unacceptably",
    "tolerantly": "intolerantly",
    "transitively": "intransitively",
    "truly": "insincerely",
    "trustfully": "mistrustfully",
    "trustingly": "distrustfully",
    "truthfully": "untruthfully",
    "tunefully": "unmelodiously",
    "unacceptably": "tolerably",
    "unambiguously": "equivocally",
    "unambitiously": "determinedly",
    "unappealingly": "appealingly",
    "unappreciatively": "gratefully",
    "unashamedly": "ashamedly",
    "unassertively": "assertively",
    "unattractively": "beautifully",
    "unbecomingly": "decorously",
    "unbelievably": "believably",
    "unbelievingly": "credulously",
    "unceremoniously": "ceremoniously",
    "uncertainly": "steadily",
    "uncharacteristically": "characteristically",
    "unchivalrously": "gallantly",
    "uncivilly": "civilly",
    "uncomfortably": "comfortably",
    "uncomparably": "comparably",
    "uncomplainingly": "complainingly",
    "unconsciously": "consciously",
    "unconstitutionally": "constitutionally",
    "uncontroversially": "polemically",
    "unconventionally": "conventionally",
    "unconvincingly": "convincingly",
    "uncritically": "critically",
    "undecipherably": "legibly",
    "undemocratically": "democratically",
    "undependably": "faithfully",
    "understandably": "unintelligibly",
    "undeservedly": "deservedly",
    "undiplomatically": "diplomatically",
    "undramatically": "dramatically",
    "unemotionally": "emotionally",
    "unenthusiastically": "enthusiastically",
    "unequivocally": "ambiguously",
    "unethically": "ethically",
    "unevenly": "evenly",
    "unexcitingly": "excitingly",
    "unfaithfully": "reliably",
    "unfashionably": "fashionably",
    "unfavorably": "favourably",
    "unfavourably": "favorably",
    "unfeelingly": "feelingly",
    "unfeignedly": "insincerely",
    "unforgettably": "unmemorably",
    "unforgivably": "excusably",
    "unforgivingly": "forgivingly",
    "unfortunately": "luckily",
    "ungrammatically": "grammatically",
    "ungratefully": "gratefully",
    "unhelpfully": "helpfully",
    "unhesitatingly": "hesitatingly",
    "unhurriedly": "in haste",
    "unhygienically": "hygienically",
    "unilaterally": "multilaterally",
    "unimaginatively": "imaginatively",
    "unimpressively": "impressively",
    "uninformatively": "instructively",
    "uninstructively": "informatively",
    "unintelligently": "intelligently",
    "unintelligibly": "understandably",
    "uninterestingly": "interestingly",
    "unjustifiably": "justifiably",
    "unjustly": "rightly",
    "unlawfully": "legally",
    "unluckily": "fortunately",
    "unmanageably": "manageably",
    "unmanfully": "manfully",
    "unmelodiously": "tunefully",
    "unmemorably": "unforgettably",
    "unmindfully": "mindfully",
    "unmusically": "musically",
    "unnoticeably": "perceptibly",
    "unobtrusively": "obtrusively",
    "unofficially": "officially",
    "unpalatably": "palatably",
    "unpardonably": "excusably",
    "unpatriotically": "patriotically",
    "unpleasantly": "pleasantly",
    "unprecedentedly": "precedentedly",
    "unpretentiously": "pretentiously",
    "unproductively": "profitably",
    "unprofitably": "productively",
    "unpropitiously": "auspiciously",
    "unreadably": "legibly",
    "unrealistically": "realistically",
    "unreasonably": "somewhat",
    "unrecognizably": "recognizably",
    "unreliably": "faithfully",
    "unrepentantly": "penitently",
    "unrighteously": "righteously",
    "unromantically": "romantically",
    "unseasonably": "seasonably",
    "unselfconsciously": "self-consciously",
    "unselfishly": "selfishly",
    "unsentimentally": "sentimentally",
    "unsmilingly": "smilingly",
    "unsociably": "sociably",
    "unsportingly": "sportingly",
    "unsteadily": "steadily",
    "unsuccessfully": "successfully",
    "unsuitably": "appropriately",
    "unsymmetrically": "symmetrically",
    "unsympathetically": "sympathetically",
    "unthinkingly": "thoughtfully",
    "untruthfully": "truthfully",
    "ununderstandably": "intelligibly",
    "unwarily": "warily",
    "unwisely": "wisely",
    "uprightly": "dishonorably",
    "upriver": "downriver",
    "upwardly": "down",
    "venally": "honestly",
    "very loudly": "pianissimo",
    "very softly": "fortissimo",
    "virtuously": "immorally",
    "warily": "unwarily",
    "wisely": "unwisely",
    "abience": "adience",
    "abruptness": "gradualness",
    "absorbency": "nonabsorbency",
    "abstainer": "drinker",
    "abstractness": "concreteness",
    "ac": "direct current",
    "acanthopterygian": "soft-finned fish",
    "acapnia": "hypercapnia",
    "accelerator": "anticatalyst",
    "acceptability": "unacceptableness",
    "acceptableness": "unacceptability",
    "accessibility": "unavailability",
    "accrual basis": "cash basis",
    "achromatic color": "spectral colour",
    "achromatic colour": "chromatic color",
    "acrocarp": "pleurocarpous moss",
    "acrocarpous moss": "pleurocarp",
    "activator": "inhibitor",
    "active trust": "passive trust",
    "active voice": "passive voice",
    "actual sin": "original sin",
    "acuteness": "obtuseness",
    "adaptability": "unadaptability",
    "adduct": "abduct",
    "adience": "abience",
    "advantageousness": "unfavorableness",
    "advisability": "inadvisability",
    "affectedness": "unaffectedness",
    "agreeability": "disagreeableness",
    "agreeableness": "disagreeableness",
    "aimlessness": "purposefulness",
    "air mail": "surface mail",
    "aliveness": "inanimateness",
    "allogamy": "autogamy",
    "allopatry": "sympatry",
    "alterability": "unalterability",
    "alternating current": "direct electric current",
    "alternating electric current": "direct current",
    "alto relievo": "low relief",
    "alto rilievo": "low relief",
    "altruism": "self-interest",
    "ambiversion": "introversion",
    "amends": "worsen",
    "amenities": "disagreeableness",
    "amenity": "disagreeableness",
    "amiability": "ill humor",
    "amyotonia": "tonicity",
    "analogy": "apophatism",
    "analphabetism": "literacy",
    "anamorphism": "katamorphism",
    "anaphrodisia": "aphrodisia",
    "anapsid": "diapsid reptile",
    "anapsid reptile": "diapsid",
    "anastalsis": "vermiculation",
    "anestrum": "estrus",
    "anestrus": "rut",
    "anglophilia": "anglophobia",
    "anglophobia": "anglophilia",
    "angularity": "roundness",
    "animateness": "inanimateness",
    "anisotropy": "isotropy",
    "anode": "cathode",
    "anoestrum": "estrus",
    "anoestrus": "estrus",
    "anovulation": "ovulation",
    "anticatalyst": "catalyst",
    "aphelion": "perihelion",
    "aphrodisia": "anaphrodisia",
    "apoapsis": "point of periapsis",
    "apogee": "perigee",
    "apojove": "perijove",
    "apolune": "periselene",
    "apophatism": "doctrine of analogy",
    "aposelene": "periselene",
    "appeal": "repel",
    "appetisingness": "unappetizingness",
    "appetizingness": "unappetizingness",
    "appositeness": "inaptness",
    "approachability": "unapproachability",
    "appropriateness": "wrongness",
    "aptness": "inaptness",
    "arabic numeral": "roman numeral",
    "arianism": "athanasianism",
    "aridity": "fruitfulness",
    "artefact": "natural object",
    "artfulness": "artlessness",
    "artifact": "natural object",
    "artificial language": "tongue",
    "artiodactyl mammal": "odd-toed ungulate",
    "artlessness": "artfulness",
    "ascending node": "descending node",
    "assortative mating": "disassortative mating",
    "asynchronism": "synchrony",
    "asynchronous operation": "synchronous operation",
    "asynchrony": "synchronism",
    "athanasianism": "arianism",
    "atomic theory": "holism",
    "atomism": "holistic theory",
    "atomist theory": "holism",
    "atomistic theory": "holism",
    "atonalism": "tonality",
    "atonality": "tonality",
    "atonia": "tonicity",
    "atonicity": "tonus",
    "atony": "tonicity",
    "attentiveness": "inattentiveness",
    "attire": "underdress",
    "atypicality": "typicality",
    "audibility": "inaudibleness",
    "audibleness": "inaudibility",
    "auspiciousness": "unpropitiousness",
    "autogamy": "allogamy",
    "autumnal equinox": "vernal equinox",
    "availability": "inaccessibility",
    "availableness": "inaccessibility",
    "avoirdupois": "leanness",
    "awareness": "incognizance",
    "away game": "home game",
    "back burner": "front burner",
    "backhander": "forehand",
    "bad egg": "good egg",
    "bad guy": "good guy",
    "bad person": "good person",
    "bad weather": "good weather",
    "balefulness": "beneficence",
    "barrenness": "fruitfulness",
    "bas relief": "high relief",
    "baseball diamond": "outfield",
    "basso relievo": "high relief",
    "basso rilievo": "high relief",
    "becomingness": "unbecomingness",
    "bed": "get up",
    "bedding": "get up",
    "beingness": "nonbeing",
    "beneficence": "mischief",
    "benignity": "malignance",
    "bigness": "smallness",
    "biodegradable pollution": "nonbiodegradable pollution",
    "blackening": "whiten",
    "blacking": "whiten",
    "blubber": "leanness",
    "blunt file": "taper file",
    "blurriness": "distinctness",
    "board": "get off",
    "boarding": "get off",
    "boarding school": "day school",
    "boards": "get off",
    "bounded interval": "open interval",
    "boundedness": "infiniteness",
    "boundlessness": "finiteness",
    "brand-name drug": "generic drug",
    "breakableness": "unbreakableness",
    "brine": "fresh water",
    "broad-mindedness": "narrow-mindedness",
    "broadness": "narrowness",
    "butterball": "thin person",
    "cacodaemon": "eudemon",
    "cacodemon": "good spirit",
    "caenogenesis": "palingenesis",
    "cainogenesis": "palingenesis",
    "call": "put option",
    "call option": "put option",
    "capital letter": "lowercase",
    "carinate bird": "ratite",
    "cash account": "margin account",
    "cash basis": "accrual basis",
    "catalyst": "anticatalyst",
    "cataphatism": "apophatism",
    "catch": "unhitch",
    "categorem": "syncategoreme",
    "categoreme": "syncategorem",
    "cathode": "anode",
    "cenobite": "eremite",
    "cenogenesis": "recapitulation",
    "centrifugal force": "centripetal force",
    "centripetal force": "centrifugal force",
    "ceremoniousness": "unceremoniousness",
    "certification": "disenfranchisement",
    "changeability": "changelessness",
    "changeableness": "unchangingness",
    "changelessness": "changeableness",
    "chapelgoer": "anglican",
    "chariness": "unwariness",
    "chromatic color": "achromatic colour",
    "chromatic colour": "achromatic color",
    "circumstantial evidence": "direct evidence",
    "cisc": "reduced instruction set computing",
    "civil law": "law of nations",
    "clabber": "homogenize",
    "classicalism": "romanticism",
    "classicism": "romanticism",
    "classicist": "romanticist",
    "cleanness": "uncleanness",
    "clockwise rotation": "levorotation",
    "closed chain": "open chain",
    "closed circuit": "open circuit",
    "closed interval": "unbounded interval",
    "clot": "homogenize",
    "clotting": "homogenize",
    "coding dna": "intron",
    "coenobite": "eremite",
    "cognisance": "incognizance",
    "cognizance": "incognizance",
    "cold war": "hot war",
    "come": "go away",
    "common noun": "proper noun",
    "commonness": "uncommonness",
    "commonplaceness": "uncommonness",
    "communicativeness": "uncommunicativeness",
    "communisation": "denationalization",
    "communization": "denationalization",
    "complex instruction set computer": "reduced instruction set computing",
    "complex instruction set computing": "risc",
    "comprehensibility": "incomprehensibility",
    "compressibility": "incompressibility",
    "concave polygon": "convex polygon",
    "concerted music": "monophony",
    "conclusiveness": "inconclusiveness",
    "concreteness": "abstractness",
    "congeniality": "uncongeniality",
    "congruence": "incongruity",
    "congruity": "incongruousness",
    "congruousness": "incongruity",
    "connectedness": "unconnectedness",
    "connection": "unconnectedness",
    "connexion": "unconnectedness",
    "conscientiousness": "unconscientiousness",
    "consecutive operation": "parallel operation",
    "considerateness": "inconsideration",
    "consideration": "inconsideration",
    "conspicuousness": "inconspicuousness",
    "constant-width font": "proportional font",
    "constructiveness": "destructiveness",
    "contentment": "discontentment",
    "continuant consonant": "stop consonant",
    "convention": "unconventionality",
    "conventionalism": "unconventionality",
    "conventionality": "unconventionality",
    "convergent thinking": "out-of-the-box thinking",
    "convertibility": "inconvertibility",
    "convex polygon": "concave polygon",
    "cooking apple": "eating apple",
    "coordination": "incoordination",
    "corpuscular theory": "wave theory of light",
    "corpuscular theory of light": "wave theory",
    "corruptibility": "incorruptibility",
    "corruption": "incorruptness",
    "corruptness": "incorruptness",
    "counterclockwise rotation": "dextrorotation",
    "counterfactuality": "factualness",
    "country": "urban area",
    "creative thinking": "uncreativeness",
    "creativeness": "uncreativeness",
    "creativity": "uncreativeness",
    "criminalisation": "decriminalization",
    "criminalization": "decriminalization",
    "crookedness": "straightness",
    "cross-fertilisation": "self-fertilization",
    "cross-fertilization": "self-fertilization",
    "cross-pollination": "self-pollination",
    "cryptogamia": "phanerogamae",
    "curability": "incurableness",
    "curableness": "incurability",
    "curdling": "homogenize",
    "curiousness": "nativeness",
    "curliness": "straightness",
    "dabbler": "diving duck",
    "dabbling duck": "diving duck",
    "dangerousness": "safeness",
    "day game": "night game",
    "day of rest": "workday",
    "day school": "night school",
    "dc": "alternating current",
    "deadly sin": "venial sin",
    "deadness": "responsiveness",
    "debarkation": "embarkation",
    "debenture": "secured bond",
    "debenture bond": "secured bond",
    "deciduous plant": "evergreen plant",
    "decisiveness": "indecisiveness",
    "decriminalisation": "criminalization",
    "decriminalization": "criminalization",
    "dedicated file server": "non-dedicated file server",
    "deepness": "shallowness",
    "deflationary spiral": "inflationary spiral",
    "degaussing": "magnetize",
    "delight": "displease",
    "demonetisation": "monetization",
    "demonetization": "monetization",
    "denationalisation": "nationalization",
    "denationalization": "nationalization",
    "dependability": "unreliableness",
    "dependableness": "undependability",
    "depigmentation": "pigmentation",
    "descending node": "ascending node",
    "descriptive linguistics": "prescriptive linguistics",
    "dessert apple": "cooking apple",
    "destabilisation": "stabilization",
    "destabilization": "stabilization",
    "destructibility": "indestructibility",
    "destructiveness": "constructiveness",
    "desynchronisation": "synchronism",
    "desynchronization": "synchronism",
    "detribalisation": "tribalization",
    "detribalization": "tribalization",
    "dextrorotation": "levorotation",
    "diamond": "outfield",
    "diapsid": "anapsid reptile",
    "diapsid reptile": "anapsid",
    "diffuser": "hard",
    "digestibility": "indigestibleness",
    "digestibleness": "indigestibility",
    "digitigrade mammal": "plantigrade mammal",
    "dimmer": "undimmed",
    "direct current": "alternating electric current",
    "direct discourse": "indirect discourse",
    "direct electric current": "alternating current",
    "direct evidence": "indirect evidence",
    "direct quotation": "indirect discourse",
    "directness": "indirectness",
    "dirtiness": "cleanness",
    "disagreeableness": "amenity",
    "disassortative mating": "assortative mating",
    "disconnectedness": "connectedness",
    "disconnection": "connectedness",
    "discontentedness": "contentment",
    "discontentment": "contentment",
    "disembarkation": "embarkment",
    "disembarkment": "embarkation",
    "disenfranchisement": "enfranchisement",
    "dishonorableness": "honourableness",
    "dishonourableness": "honorableness",
    "disingenuousness": "ingenuousness",
    "disjunction": "connectedness",
    "disjuncture": "connectedness",
    "disorderliness": "orderliness",
    "dispensability": "vitalness",
    "dispensableness": "indispensability",
    "distemper": "good humor",
    "distinctness": "indistinctness",
    "divergent thinking": "convergent thinking",
    "divider": "lumper",
    "diving duck": "dabbling duck",
    "doctrine of analogy": "apophatism",
    "domestic flight": "international flight",
    "domestication": "wildness",
    "dovishness": "hawkishness",
    "downgrade": "upgrade",
    "downtick": "uptick",
    "downtime": "uptime",
    "drinker": "nondrinker",
    "drive": "attract",
    "drove": "attract",
    "drowsiness": "wakefulness",
    "dry-bulb thermometer": "wet-bulb thermometer",
    "dry fly": "wet fly",
    "dry season": "rainy season",
    "dumb bomb": "smart bomb",
    "dysphoria": "euphory",
    "dystopia": "utopia",
    "e-mail": "snail mail",
    "earned run": "unearned run",
    "easy money": "tight money",
    "eating apple": "cooking apple",
    "ebbtide": "rising tide",
    "effectiveness": "ineffectualness",
    "effectivity": "ineffectiveness",
    "effector": "sensory receptor",
    "effectuality": "ineffectiveness",
    "effectualness": "ineffectiveness",
    "effluence": "inflow",
    "effortfulness": "effortlessness",
    "effortlessness": "effortfulness",
    "egocentrism": "altruism",
    "egoism": "selflessness",
    "electrolytic cell": "voltaic cell",
    "electronic mail": "snail mail",
    "elevation": "natural depression",
    "eligibility": "ineligibility",
    "elitist": "equalitarian",
    "email": "snail mail",
    "embarkation": "disembarkment",
    "embarkment": "disembarkation",
    "emotional person": "unemotional person",
    "emotionalism": "unemotionality",
    "emotionality": "unemotionality",
    "emotionlessness": "emotionality",
    "endogamy": "intermarriage",
    "endotoxin": "exotoxin",
    "enfranchisement": "disenfranchisement",
    "environmentalism": "hereditarianism",
    "equalitarian": "elitist",
    "equipping": "disarming",
    "eremite": "coenobite",
    "errancy": "inerrancy",
    "essentiality": "inessentiality",
    "essentialness": "inessentiality",
    "estrus": "anoestrus",
    "ethical drug": "over-the-counter drug",
    "eucaryote": "prokaryote",
    "eudaemon": "cacodemon",
    "eudaemonia": "ill-being",
    "eudaimonia": "ill-being",
    "eudemon": "cacodemon",
    "eukaryote": "prokaryote",
    "euphoria": "dysphoria",
    "euphory": "dysphoria",
    "even-toed ungulate": "perissodactyl mammal",
    "evenness": "unevenness",
    "evergreen plant": "deciduous plant",
    "everydayness": "uncommonness",
    "exactitude": "inexactness",
    "exactness": "inexactness",
    "exaggeration": "understatement",
    "exchangeability": "unexchangeability",
    "exogamy": "inmarriage",
    "exon": "noncoding dna",
    "exotoxin": "endotoxin",
    "expectedness": "unexpectedness",
    "expedience": "inexpedience",
    "expensiveness": "inexpensiveness",
    "expert witness": "lay witness",
    "explicitness": "inexplicitness",
    "extensor": "flexor muscle",
    "extensor muscle": "flexor",
    "externality": "inwardness",
    "extra time": "regulation time",
    "extraordinariness": "ordinariness",
    "extraversion": "ambiversion",
    "extroversion": "introversion",
    "factuality": "counterfactuality",
    "factualness": "counterfactuality",
    "faintheartedness": "stoutheartedness",
    "faintness": "stoutheartedness",
    "fair ball": "foul ball",
    "fall equinox": "vernal equinox",
    "farawayness": "nearness",
    "farness": "nearness",
    "fast lane": "slow lane",
    "fast reactor": "thermal reactor",
    "fat person": "thin person",
    "fatness": "spareness",
    "fatso": "thin person",
    "favorableness": "unfavourableness",
    "favourableness": "unfavorableness",
    "female aristocrat": "male aristocrat",
    "female child": "male child",
    "female offspring": "man-child",
    "female sibling": "male sibling",
    "femaleness": "maleness",
    "feminineness": "maleness",
    "finality": "inconclusiveness",
    "finiteness": "unboundedness",
    "finitude": "infiniteness",
    "firmness of purpose": "irresoluteness",
    "fixed-width font": "proportional font",
    "flexor": "extensor muscle",
    "flexor muscle": "extensor",
    "flightless bird": "carinate",
    "flood": "ebbtide",
    "flood tide": "ebbtide",
    "flying bird": "ratite",
    "fogginess": "distinctness",
    "foreignness": "nativeness",
    "forgoing": "postdate",
    "foul ball": "fair ball",
    "free enterprise": "non-market economy",
    "free state": "slave state",
    "fresh water": "seawater",
    "freshness": "staleness",
    "freshwater": "saltwater",
    "front burner": "back burner",
    "fruitfulness": "fruitlessness",
    "fruitlessness": "fruitfulness",
    "functional disorder": "organic disorder",
    "fungibility": "unexchangeability",
    "fuzziness": "distinctness",
    "gainfulness": "unprofitableness",
    "galvanic cell": "electrolytic cell",
    "gaucherie": "urbanity",
    "general agent": "special agent",
    "general verdict": "special verdict",
    "generic drug": "proprietary drug",
    "gentleness": "abruptness",
    "genuineness": "spuriousness",
    "give": "takings",
    "godliness": "ungodliness",
    "good-neighborliness": "unneighborliness",
    "good-neighbourliness": "unneighborliness",
    "good egg": "bad egg",
    "good guy": "bad guy",
    "good health": "unhealthiness",
    "good humor": "ill humour",
    "good humour": "ill humor",
    "good nature": "ill nature",
    "good part": "weak spot",
    "good person": "bad person",
    "good spirit": "cacodemon",
    "good temper": "ill humor",
    "good weather": "inclementness",
    "grace": "unseemliness",
    "graciousness": "ungraciousness",
    "gradualness": "steepness",
    "grand larceny": "petty larceny",
    "grand theft": "petit larceny",
    "granter": "withholder",
    "gravity bomb": "smart bomb",
    "greenness": "ripeness",
    "gutlessness": "pluckiness",
    "gutsiness": "gutlessness",
    "hairiness": "hairlessness",
    "hairlessness": "pilosity",
    "ham": "underact",
    "hamming": "underact",
    "hand mower": "power mower",
    "handiness": "inaccessibility",
    "hard drug": "soft drug",
    "hard water": "soft water",
    "hardball": "softball game",
    "hawkishness": "dovishness",
    "health problem": "good health",
    "healthfulness": "unhealthfulness",
    "healthiness": "ill health",
    "heaven": "pit",
    "heavens": "hell",
    "heed": "inattentiveness",
    "heedlessness": "attentiveness",
    "heir apparent": "heir presumptive",
    "heir presumptive": "heir apparent",
    "hell": "heavens",
    "hereditarianism": "environmentalism",
    "hereness": "thereness",
    "heterocercal fin": "homocercal fin",
    "heterodactyl foot": "zygodactyl foot",
    "heterozygosity": "homozygosity",
    "high blood pressure": "hypotension",
    "high explosive": "low explosive",
    "high frequency": "low pitch",
    "high pitch": "low pitch",
    "high relief": "low relief",
    "high sea": "territorial waters",
    "high season": "off-season",
    "high status": "lowness",
    "high tide": "low water",
    "high water": "low tide",
    "highness": "lowness",
    "highwater": "low tide",
    "hindu-arabic numeral": "roman numeral",
    "hindu numeral": "roman numeral",
    "hitch": "unhitch",
    "hitchings": "unhitch",
    "holism": "atomistic theory",
    "holistic theory": "atomism",
    "home game": "road game",
    "homocercal fin": "heterocercal fin",
    "homozygosity": "heterozygosity",
    "honorableness": "dishonourableness",
    "honourableness": "dishonorableness",
    "hospitableness": "inhospitableness",
    "hot war": "cold war",
    "humaneness": "inhumanity",
    "hunger": "be full",
    "hush": "louden",
    "hushing": "louden",
    "hydrate": "exsiccate",
    "hypercalcaemia": "hypocalcemia",
    "hypercalcemia": "hypocalcemia",
    "hypercapnia": "hypocapnia",
    "hypercarbia": "hypocapnia",
    "hyperglycaemia": "hypoglycemia",
    "hyperglycemia": "hypoglycemia",
    "hyperkalemia": "hypokalemia",
    "hypernatremia": "hyponatremia",
    "hyperparathyroidism": "hypoparathyroidism",
    "hyperpigmentation": "hypopigmentation",
    "hyperpnea": "hypopnea",
    "hypersomnia": "insomnia",
    "hypertension": "hypotension",
    "hyperthermia": "hypothermia",
    "hyperthermy": "hypothermia",
    "hyperthyroidism": "hypothyroidism",
    "hypertonia": "hypotonus",
    "hypertonicity": "hypotonicity",
    "hypertonus": "hypotonia",
    "hypervolaemia": "hypovolemia",
    "hypervolemia": "hypovolemia",
    "hypocalcaemia": "hypercalcemia",
    "hypocalcemia": "hypercalcemia",
    "hypocapnia": "hypercarbia",
    "hypoglycaemia": "hyperglycemia",
    "hypoglycemia": "hyperglycemia",
    "hypokalemia": "hyperkalemia",
    "hyponatremia": "hypernatremia",
    "hypoparathyroidism": "hyperparathyroidism",
    "hypopigmentation": "hyperpigmentation",
    "hypopnea": "hyperpnea",
    "hypotension": "hypertension",
    "hypothermia": "hyperthermy",
    "hypothyroidism": "thyrotoxicosis",
    "hypotonia": "hypertonus",
    "hypotonicity": "hypertonicity",
    "hypotonus": "hypertonia",
    "hypovolaemia": "hypervolemia",
    "hypovolemia": "hypervolemia",
    "ill-being": "wellbeing",
    "ill health": "healthiness",
    "ill humor": "good temper",
    "ill humour": "good humor",
    "ill nature": "good nature",
    "illiberality": "liberalness",
    "illicitness": "licitness",
    "illiteracy": "literacy",
    "illogic": "logicality",
    "illogicality": "logicalness",
    "illogicalness": "logicality",
    "imbiber": "nondrinker",
    "immotility": "motility",
    "immovability": "movableness",
    "immovableness": "movability",
    "immunocompetence": "immunodeficiency",
    "immunodeficiency": "immunocompetence",
    "immutability": "mutableness",
    "immutableness": "mutability",
    "impalpability": "tangibility",
    "impenetrability": "perviousness",
    "imperceptibility": "perceptibility",
    "imperfectibility": "perfectibility",
    "impermeability": "permeableness",
    "impermeableness": "permeability",
    "impermissibility": "permissibility",
    "imperviousness": "penetrability",
    "impracticability": "practicableness",
    "impracticableness": "practicability",
    "impracticality": "practicality",
    "impreciseness": "preciseness",
    "in-basket": "out-tray",
    "in-tray": "out-basket",
    "inaccessibility": "handiness",
    "inadvisability": "advisability",
    "inanimateness": "animateness",
    "inappositeness": "aptness",
    "inappropriateness": "appropriateness",
    "inaptness": "aptness",
    "inattentiveness": "regard",
    "inaudibility": "audibleness",
    "inaudibleness": "audibility",
    "inauspiciousness": "propitiousness",
    "inclemency": "good weather",
    "inclementness": "good weather",
    "incognizance": "knowingness",
    "incomprehensibility": "understandability",
    "incompressibility": "squeezability",
    "inconclusiveness": "finality",
    "incongruity": "congruousness",
    "incongruousness": "congruity",
    "inconsiderateness": "consideration",
    "inconsideration": "consideration",
    "inconspicuousness": "conspicuousness",
    "inconvertibility": "convertibility",
    "incoordination": "coordination",
    "incorruptibility": "corruptibility",
    "incorruption": "corruptness",
    "incorruptness": "corruptness",
    "incurability": "curableness",
    "incurableness": "curability",
    "indecisiveness": "decisiveness",
    "indestructibility": "destructibility",
    "indigestibility": "digestibleness",
    "indigestibleness": "digestibility",
    "indirect discourse": "direct quotation",
    "indirect evidence": "direct evidence",
    "indirectness": "directness",
    "indiscreetness": "judiciousness",
    "indispensability": "dispensableness",
    "indispensableness": "dispensability",
    "indistinctness": "distinctness",
    "ineffectiveness": "effectualness",
    "ineffectuality": "effectiveness",
    "ineffectualness": "effectiveness",
    "ineligibility": "eligibility",
    "ineptness": "suitability",
    "inerrancy": "errancy",
    "inertia": "activeness",
    "inessentiality": "essentialness",
    "inexactitude": "exactness",
    "inexactness": "exactness",
    "inexpedience": "expedience",
    "inexpensiveness": "expensiveness",
    "inexplicitness": "explicitness",
    "infernal region": "heaven",
    "inferno": "heaven",
    "infield": "outfield",
    "infiniteness": "finitude",
    "infinitude": "finiteness",
    "inflationary spiral": "deflationary spiral",
    "inflow": "outflow",
    "ingenuousness": "disingenuousness",
    "inhibitor": "activator",
    "inhospitableness": "hospitableness",
    "inhumaneness": "humaneness",
    "inhumanity": "humaneness",
    "injudiciousness": "judiciousness",
    "inmarriage": "exogamy",
    "inmate": "outpatient",
    "inopportuneness": "patness",
    "inpatient": "outpatient",
    "insalubriousness": "salubrity",
    "insalubrity": "salubrity",
    "insecureness": "secureness",
    "insensitiveness": "sensitivity",
    "insensitivity": "sensitivity",
    "insentience": "sentience",
    "insomnia": "hypersomnia",
    "insubstantiality": "substantialness",
    "insurability": "uninsurability",
    "intangibility": "tangibleness",
    "intangibleness": "tangibility",
    "interchangeability": "unexchangeability",
    "interchangeableness": "unexchangeability",
    "interestingness": "uninterestingness",
    "intermarriage": "endogamy",
    "internality": "outwardness",
    "international flight": "domestic flight",
    "international law": "civil law",
    "international waters": "territorial waters",
    "internationalism": "nationalism",
    "intractability": "tractableness",
    "intractableness": "tractability",
    "intransitiveness": "transitivity",
    "intransitivity": "transitivity",
    "intron": "exon",
    "introversion": "extroversion",
    "introvert": "extrovert",
    "invariability": "variance",
    "invariableness": "variability",
    "invariance": "variability",
    "inwardness": "outwardness",
    "irrelevance": "relevancy",
    "irrelevancy": "relevance",
    "irresoluteness": "resolve",
    "irresolution": "resoluteness",
    "irreversibility": "reversibility",
    "irreversible process": "reversible process",
    "isotropy": "anisotropy",
    "judgement in personam": "judgment in rem",
    "judgement in rem": "judgment in personam",
    "judgment in personam": "judgment in rem",
    "judgment in rem": "personal judgment",
    "judiciousness": "injudiciousness",
    "juicer": "nondrinker",
    "june 21": "winter solstice",
    "kainogenesis": "palingenesis",
    "katamorphism": "anamorphism",
    "kenogenesis": "palingenesis",
    "kinaesthesia": "kinanesthesia",
    "kinaesthesis": "kinanesthesia",
    "kinanesthesia": "sense of movement",
    "kinesthesia": "kinanesthesia",
    "kinesthesis": "kinanesthesia",
    "kinesthetics": "kinanesthesia",
    "knowingness": "incognizance",
    "lactate": "bottlefeed",
    "lady": "lord",
    "laissez-faire economy": "non-market economy",
    "largeness": "smallness",
    "law of nations": "civil law",
    "lawfulness": "unlawfulness",
    "lay witness": "expert witness",
    "leaded gasoline": "unleaded petrol",
    "leaded petrol": "unleaded gasoline",
    "leanness": "fatness",
    "lee side": "windward",
    "lees": "windward",
    "levorotation": "dextrorotation",
    "lexical ambiguity": "monosemy",
    "liberality": "illiberality",
    "liberalness": "illiberality",
    "libertarian": "necessitarian",
    "licitness": "illicitness",
    "limitlessness": "finiteness",
    "listed security": "unlisted security",
    "literacy": "illiteracy",
    "little girl": "male child",
    "littleness": "largeness",
    "live birth": "stillbirth",
    "liveborn infant": "stillborn infant",
    "loading": "unloading",
    "loftiness": "lowness",
    "logicality": "illogicalness",
    "logicalness": "illogicality",
    "long suit": "weak point",
    "lord": "peeress",
    "low explosive": "high explosive",
    "low frequency": "high pitch",
    "low pitch": "high pitch",
    "low relief": "high relief",
    "low status": "high status",
    "low tide": "highwater",
    "low water": "high tide",
    "lower-case letter": "uppercase",
    "lowliness": "high status",
    "lowness": "loftiness",
    "lucrativeness": "unprofitableness",
    "lumper": "splitter",
    "magnification": "understatement",
    "major surgery": "minor surgery",
    "malacopterygian": "spiny-finned fish",
    "male aristocrat": "female aristocrat",
    "male child": "little girl",
    "male offspring": "female offspring",
    "male sibling": "female sibling",
    "maleficence": "beneficence",
    "maleness": "feminineness",
    "malignance": "benignity",
    "malleability": "unmalleability",
    "man-child": "female offspring",
    "march equinox": "autumnal equinox",
    "margin account": "cash account",
    "market economy": "non-market economy",
    "masochist": "sadist",
    "mates": "disentangle",
    "mating": "disentangle",
    "matting": "disentangle",
    "maximation": "minimization",
    "maximisation": "minimization",
    "maximization": "minimization",
    "meaningfulness": "meaninglessness",
    "meaninglessness": "meaningfulness",
    "mental disease": "mental health",
    "mental health": "psychopathy",
    "mental illness": "mental health",
    "mercifulness": "unmercifulness",
    "mercilessness": "mercy",
    "mercy": "mercilessness",
    "merit system": "spoils system",
    "messiness": "tidiness",
    "metier": "weak point",
    "midsummer": "winter solstice",
    "minimisation": "maximization",
    "minimization": "maximization",
    "minor surgery": "major surgery",
    "miscarriage": "live birth",
    "mischief": "beneficence",
    "misconduct": "behave",
    "misogynism": "philogyny",
    "misogyny": "philogyny",
    "monetisation": "demonetization",
    "monetization": "demonetization",
    "monism": "pluralism",
    "monody": "polyphony",
    "monophonic music": "polyphony",
    "monophony": "polyphony",
    "monosemy": "polysemy",
    "monospaced font": "proportional font",
    "monotheism": "polytheism",
    "morbidity": "wholesomeness",
    "morbidness": "wholesomeness",
    "mortal sin": "venial sin",
    "motility": "immotility",
    "motor mower": "hand mower",
    "movability": "immovableness",
    "movableness": "immovability",
    "multiculturalism": "nationalism",
    "multidimensional language": "one-dimensional language",
    "mundaneness": "naivete",
    "mundanity": "naivete",
    "muscle sense": "kinanesthesia",
    "mutability": "immutableness",
    "mutableness": "immutability",
    "naiveness": "sophistication",
    "naivete": "worldliness",
    "naivety": "sophistication",
    "narrow-mindedness": "broad-mindedness",
    "narrowness": "broadness",
    "nastiness": "niceness",
    "nationalisation": "denationalization",
    "nationalism": "multiculturalism",
    "nationalization": "privatization",
    "nativeness": "foreignness",
    "natural depression": "natural elevation",
    "natural elevation": "natural depression",
    "natural language": "artificial language",
    "natural object": "artifact",
    "naturalness": "unnaturalness",
    "neap": "springtide",
    "neap tide": "springtide",
    "nearness": "remoteness",
    "neatness": "untidiness",
    "necessitarian": "libertarian",
    "negative charge": "positive charge",
    "negativeness": "positivity",
    "negativism": "positivity",
    "negativity": "positivity",
    "neighborliness": "unneighborliness",
    "neighbourliness": "unneighborliness",
    "nether region": "heaven",
    "neurotic depression": "psychotic depression",
    "night game": "day game",
    "night school": "day school",
    "non-dedicated file server": "dedicated file server",
    "non-market economy": "private enterprise",
    "non-proliferation": "proliferation",
    "non-volatile storage": "volatile storage",
    "nonabsorbency": "absorbency",
    "nonbeing": "beingness",
    "nonbiodegradable pollution": "biodegradable pollution",
    "noncoding dna": "exon",
    "nondrinker": "toper",
    "nonproliferation": "proliferation",
    "nonreligious person": "religious person",
    "nonsingular matrix": "singular matrix",
    "nonstarter": "achiever",
    "nonvolatile storage": "volatile storage",
    "northernness": "southernness",
    "nowness": "futurity",
    "nurse": "bottlefeed",
    "nursing": "bottlefeed",
    "object program": "source program",
    "oblique angle": "right angle",
    "oblique triangle": "right triangle",
    "obtrusiveness": "unobtrusiveness",
    "obtuseness": "acuteness",
    "odd-toed ungulate": "even-toed ungulate",
    "oestrus": "anestrus",
    "off-season": "peak season",
    "offerer": "on",
    "one-dimensional language": "multidimensional language",
    "open chain": "rings",
    "open circuit": "closed circuit",
    "open interval": "closed interval",
    "opportuneness": "inopportuneness",
    "orderliness": "disorderliness",
    "ordinariness": "extraordinariness",
    "organic disorder": "functional disorder",
    "original sin": "actual sin",
    "otc security": "listed security",
    "otherworldliness": "worldliness",
    "out-basket": "in-tray",
    "out-of-the-box thinking": "convergent thinking",
    "out-tray": "in-basket",
    "outer garment": "undergarment",
    "outfield": "infield",
    "outflow": "inflow",
    "outpatient": "inpatient",
    "outwardness": "inwardness",
    "over-the-counter drug": "prescription medicine",
    "over-the-counter medicine": "prescription drug",
    "over the counter security": "listed security",
    "overachievement": "underachievement",
    "overacting": "underact",
    "overbid": "underbid",
    "overclothes": "underdress",
    "overgarment": "undergarment",
    "overshoot": "undershoot",
    "overstatement": "understatement",
    "ovulation": "anovulation",
    "painstakingness": "unconscientiousness",
    "palatability": "unpalatableness",
    "palatableness": "unpalatability",
    "palingenesis": "kenogenesis",
    "palpability": "intangibility",
    "paper loss": "paper profit",
    "paper profit": "paper loss",
    "parallel operation": "serial operation",
    "parallelogram": "trapezium",
    "passive trust": "active trust",
    "passive voice": "active voice",
    "pastness": "presentness",
    "patness": "inopportuneness",
    "peak": "bottom out",
    "peak season": "off-season",
    "peeress": "lord",
    "penetrability": "imperviousness",
    "perceptibility": "imperceptibility",
    "perceptiveness": "unperceptiveness",
    "perdition": "heaven",
    "perfectibility": "imperfectibility",
    "periapsis": "point of apoapsis",
    "perigee": "apogee",
    "perihelion": "aphelion",
    "perijove": "apojove",
    "perilune": "aposelene",
    "periselene": "aposelene",
    "perissodactyl": "even-toed ungulate",
    "perissodactyl mammal": "even-toed ungulate",
    "peristalsis": "anastalsis",
    "permeability": "impermeableness",
    "permeableness": "impermeability",
    "permissibility": "impermissibility",
    "permissiveness": "unpermissiveness",
    "personal judgement": "judgment in rem",
    "personal judgment": "judgment in rem",
    "persuasiveness": "unpersuasiveness",
    "perviousness": "impenetrability",
    "petit larceny": "grand theft",
    "petty larceny": "grand larceny",
    "phanerogamae": "cryptogamia",
    "philogyny": "misogyny",
    "pigmentation": "depigmentation",
    "pilosity": "hairlessness",
    "pit": "heaven",
    "plantigrade mammal": "digitigrade mammal",
    "plasticity": "unmalleability",
    "pleasantness": "unpleasantness",
    "pleasingness": "unpleasingness",
    "pleasure-pain principle": "reality principle",
    "pleasure-unpleasure principle": "reality principle",
    "pleasure principle": "reality principle",
    "pleurocarp": "acrocarpous moss",
    "pleurocarpous moss": "acrocarp",
    "plosive": "continuant consonant",
    "plosive consonant": "continuant consonant",
    "plosive speech sound": "continuant consonant",
    "pluckiness": "gutlessness",
    "pluralism": "monism",
    "point": "unpointedness",
    "point of apoapsis": "periapsis",
    "point of periapsis": "apoapsis",
    "pointedness": "unpointedness",
    "political correctitude": "political incorrectness",
    "political correctness": "political incorrectness",
    "political incorrectness": "political correctness",
    "polyphonic music": "monophony",
    "polyphony": "monophony",
    "polysemy": "monosemy",
    "polytheism": "monotheism",
    "poor people": "riches",
    "populated area": "rural area",
    "positive charge": "negative charge",
    "positiveness": "negativity",
    "positivism": "negativity",
    "positivity": "negativity",
    "power": "powerlessness",
    "power mower": "hand mower",
    "powerfulness": "powerlessness",
    "powerlessness": "powerfulness",
    "practicability": "impracticableness",
    "practicableness": "impracticability",
    "practicality": "impracticality",
    "precipitousness": "gradualness",
    "preciseness": "impreciseness",
    "predictability": "unpredictability",
    "prescription drug": "over-the-counter medicine",
    "prescription medicine": "over-the-counter drug",
    "prescriptive linguistics": "descriptive linguistics",
    "presentness": "pastness",
    "pretension": "unpretentiousness",
    "pretentiousness": "unpretentiousness",
    "primary cell": "electrolytic cell",
    "private enterprise": "non-market economy",
    "privatisation": "nationalization",
    "privatization": "nationalization",
    "pro-lifer": "pro-choice",
    "procaryote": "eukaryote",
    "productiveness": "unproductiveness",
    "productivity": "unproductiveness",
    "profitability": "unprofitableness",
    "profitableness": "unprofitableness",
    "profoundness": "shallowness",
    "profundity": "superficiality",
    "prokaryote": "eukaryote",
    "proliferation": "nonproliferation",
    "pronation": "supination",
    "proper name": "common noun",
    "proper noun": "common noun",
    "propitiousness": "inauspiciousness",
    "proportional font": "typewriter font",
    "proprietary drug": "generic drug",
    "psychopathy": "mental health",
    "psychotic depression": "neurotic depression",
    "purposefulness": "purposelessness",
    "purposelessness": "sense of purpose",
    "push back": "attract",
    "put option": "call option",
    "radial asymmetry": "radial symmetry",
    "radial symmetry": "radial asymmetry",
    "rainy season": "dry season",
    "ratite": "flying bird",
    "ratite bird": "carinate",
    "ravel": "untangle",
    "raveling": "ravel",
    "ravelling": "ravel",
    "reality principle": "pleasure principle",
    "recapitulation": "cenogenesis",
    "receptor": "effector",
    "recto": "verso",
    "reduced instruction set computer": "complex instruction set computing",
    "reduced instruction set computing": "complex instruction set computing",
    "reducing": "blow up",
    "reentering angle": "salient angle",
    "reentrant angle": "salient angle",
    "regard": "inattentiveness",
    "regulation time": "extra time",
    "relapse": "get well",
    "relapsing": "get well",
    "relatedness": "unrelatedness",
    "relevance": "irrelevancy",
    "relevancy": "irrelevance",
    "reliableness": "undependability",
    "religious person": "nonreligious person",
    "remoteness": "nearness",
    "repulse": "attract",
    "resoluteness": "irresolution",
    "resolve": "irresoluteness",
    "responsiveness": "unresponsiveness",
    "rest day": "working day",
    "restrictiveness": "permissiveness",
    "reversibility": "irreversibility",
    "reversible process": "irreversible process",
    "rich people": "poor people",
    "riches": "poor people",
    "ricketiness": "steadiness",
    "right-angled triangle": "oblique triangle",
    "right angle": "oblique angle",
    "right triangle": "oblique triangle",
    "righteousness": "unrighteousness",
    "rightness": "wrongness",
    "ring": "open chain",
    "rings": "open chain",
    "ripeness": "greenness",
    "risc": "complex instruction set computing",
    "rising tide": "ebbtide",
    "rising trot": "sitting trot",
    "road game": "home game",
    "roman numeral": "hindu numeral",
    "romantic movement": "classicism",
    "romanticism": "classicism",
    "roundness": "angularity",
    "rural area": "urban area",
    "rusticity": "urbanity",
    "rut": "anestrus",
    "sadist": "masochist",
    "safeness": "dangerousness",
    "salient angle": "reentrant angle",
    "saltwater": "freshwater",
    "salubriousness": "insalubrity",
    "salubrity": "insalubrity",
    "sanitariness": "unsanitariness",
    "satisfactoriness": "unsatisfactoriness",
    "scent": "deodorize",
    "school text": "trade edition",
    "schoolbook": "trade edition",
    "scrag": "fat person",
    "scrupulousness": "unscrupulousness",
    "seasonableness": "unseasonableness",
    "seawater": "fresh water",
    "secured bond": "unsecured bond",
    "secureness": "insecureness",
    "seemliness": "unseemliness",
    "self-centeredness": "altruism",
    "self-concern": "altruism",
    "self-consciousness": "unselfconsciousness",
    "self-fertilisation": "cross-fertilization",
    "self-fertilization": "cross-fertilization",
    "self-interest": "altruism",
    "self-pollination": "cross-pollination",
    "selflessness": "egoism",
    "sense of movement": "kinanesthesia",
    "sense of purpose": "purposelessness",
    "sense organ": "effector",
    "sensitiveness": "insensitivity",
    "sensitivity": "insensitivity",
    "sensory receptor": "effector",
    "sentience": "insentience",
    "september equinox": "vernal equinox",
    "sequential operation": "parallel operation",
    "serial operation": "simultaneous operation",
    "shallowness": "profoundness",
    "sheathing": "unsheathe",
    "simultaneous operation": "serial operation",
    "singular matrix": "nonsingular matrix",
    "sitter": "stander",
    "sitting trot": "rising trot",
    "skillfulness": "unskillfulness",
    "skim milk": "whole milk",
    "skimmed milk": "whole milk",
    "skin and bones": "fat person",
    "slave state": "free state",
    "sleepiness": "wakefulness",
    "sleeplessness": "sleepiness",
    "slow lane": "fast lane",
    "small letter": "uppercase",
    "smallness": "largeness",
    "smart bomb": "gravity bomb",
    "snail mail": "email",
    "sociability": "unsociableness",
    "sociableness": "unsociability",
    "soft-finned fish": "spiny-finned fish",
    "soft drug": "hard drug",
    "soft spot": "good part",
    "soft water": "hard water",
    "softball": "hardball",
    "softball game": "hardball",
    "solderer": "unsold",
    "solvability": "unsolvability",
    "somnolence": "wakefulness",
    "sophistication": "naivety",
    "source program": "target program",
    "southernness": "northernness",
    "spareness": "fatness",
    "special agent": "universal agent",
    "special verdict": "general verdict",
    "speciality": "weak point",
    "specialty": "weak point",
    "spectral color": "achromatic color",
    "spectral colour": "achromatic color",
    "spell": "unspell",
    "spelling": "unspell",
    "spelt": "unspell",
    "spiny-finned fish": "soft-finned fish",
    "spiritism": "worldliness",
    "spiritualism": "worldliness",
    "spirituality": "worldliness",
    "split ticket": "straight ticket",
    "splitter": "lumper",
    "spoils system": "merit system",
    "sponginess": "incompressibility",
    "spontaneous abortion": "live birth",
    "spring equinox": "autumnal equinox",
    "springtide": "neap tide",
    "spuriousness": "genuineness",
    "squeezability": "incompressibility",
    "stabilisation": "destabilization",
    "stabilization": "destabilization",
    "staleness": "freshness",
    "stander": "sitter",
    "steadiness": "unsteadiness",
    "steepness": "gradualness",
    "stillbirth": "live birth",
    "stillborn infant": "liveborn infant",
    "stop consonant": "continuant consonant",
    "stoutheartedness": "faintness",
    "straight ticket": "split ticket",
    "straightness": "waviness",
    "stratified language": "unstratified language",
    "strong point": "weak point",
    "strong suit": "weak point",
    "substantiality": "insubstantiality",
    "substantialness": "insubstantiality",
    "suck": "bottlefeed",
    "sucking": "bottlefeed",
    "suckling": "bottlefeed",
    "suitability": "unsuitableness",
    "suitableness": "unsuitability",
    "summer solstice": "winter solstice",
    "superficiality": "profundity",
    "supination": "pronation",
    "surface mail": "air mail",
    "surprisingness": "expectedness",
    "sweetness": "unpleasantness",
    "sympatry": "allopatry",
    "syncategorem": "categoreme",
    "syncategoreme": "categorem",
    "synchroneity": "asynchronism",
    "synchronicity": "asynchronism",
    "synchronisation": "asynchronism",
    "synchronism": "desynchronization",
    "synchronization": "asynchronism",
    "synchronous operation": "asynchronous operation",
    "synchrony": "asynchronism",
    "tact": "tactlessness",
    "tactfulness": "tactlessness",
    "tactlessness": "tactfulness",
    "take": "give",
    "takings": "give",
    "tameness": "wildness",
    "tangibility": "intangibleness",
    "tangibleness": "intangibility",
    "tangle": "unravel",
    "taper file": "blunt file",
    "target program": "source program",
    "tastefulness": "tastelessness",
    "tastelessness": "tastefulness",
    "technophile": "technophobe",
    "technophobe": "technophile",
    "territorial waters": "international waters",
    "terseness": "verbosity",
    "text": "trade edition",
    "text edition": "trade edition",
    "thereness": "hereness",
    "thermal reactor": "fast reactor",
    "thin person": "fatso",
    "throne": "dethrone",
    "thyrotoxicosis": "hypothyroidism",
    "tidiness": "untidiness",
    "tight money": "easy money",
    "time off": "work time",
    "tonality": "atonality",
    "tone": "atonicity",
    "tongue": "artificial language",
    "tonicity": "atony",
    "tonus": "atonicity",
    "toper": "nondrinker",
    "tractability": "intractableness",
    "tractableness": "intractability",
    "trade book": "text edition",
    "trade edition": "text edition",
    "transitiveness": "intransitivity",
    "transitivity": "intransitivity",
    "trapezium": "parallelogram",
    "tribalisation": "detribalization",
    "tribalization": "detribalization",
    "trustiness": "untrustworthiness",
    "trustworthiness": "untrustworthiness",
    "typewriter font": "proportional font",
    "typicality": "untypicality",
    "unacceptability": "acceptableness",
    "unacceptableness": "acceptability",
    "unadaptability": "adaptability",
    "unaffectedness": "affectedness",
    "unalterability": "alterability",
    "unappetisingness": "appetizingness",
    "unappetizingness": "appetizingness",
    "unapproachability": "approachability",
    "unavailability": "accessibility",
    "unbecomingness": "becomingness",
    "unbounded interval": "closed interval",
    "unboundedness": "finiteness",
    "unbreakableness": "breakableness",
    "unceremoniousness": "ceremoniousness",
    "unchangeability": "changeableness",
    "unchangeableness": "changeableness",
    "unchangingness": "changeableness",
    "uncleanness": "cleanness",
    "uncommonness": "everydayness",
    "uncommunicativeness": "communicativeness",
    "uncongeniality": "congeniality",
    "unconnectedness": "connexion",
    "unconscientiousness": "painstakingness",
    "unconventionality": "conventionality",
    "uncreativeness": "creativity",
    "undependability": "reliableness",
    "undependableness": "dependability",
    "underachievement": "overachievement",
    "undergarment": "overgarment",
    "understandability": "incomprehensibility",
    "understatement": "overstatement",
    "undulatory theory": "corpuscular theory",
    "unearned run": "earned run",
    "unemotional person": "emotional person",
    "unemotionality": "emotionality",
    "unevenness": "invariability",
    "unexchangeability": "interchangeableness",
    "unexpectedness": "expectedness",
    "unfavorableness": "profitableness",
    "unfavourableness": "favorableness",
    "ungodliness": "godliness",
    "ungraciousness": "graciousness",
    "unhealthfulness": "healthfulness",
    "unhealthiness": "good health",
    "uninsurability": "insurability",
    "uninterestingness": "interestingness",
    "universal agent": "special agent",
    "unlawfulness": "lawfulness",
    "unleaded gasoline": "leaded petrol",
    "unleaded petrol": "leaded gasoline",
    "unlisted security": "listed security",
    "unloading": "loading",
    "unmalleability": "plasticity",
    "unmercifulness": "mercifulness",
    "unnaturalness": "naturalness",
    "unneighborliness": "neighbourliness",
    "unobtrusiveness": "obtrusiveness",
    "unpalatability": "palatableness",
    "unpalatableness": "palatability",
    "unperceptiveness": "perceptiveness",
    "unpermissiveness": "permissiveness",
    "unpersuasiveness": "persuasiveness",
    "unpleasantness": "sweetness",
    "unpleasingness": "pleasingness",
    "unpointedness": "pointedness",
    "unpredictability": "predictability",
    "unpretentiousness": "pretentiousness",
    "unproductiveness": "productivity",
    "unprofitability": "profitableness",
    "unprofitableness": "profitability",
    "unpropitiousness": "auspiciousness",
    "unrelatedness": "relatedness",
    "unreliableness": "dependability",
    "unresponsiveness": "responsiveness",
    "unrighteousness": "righteousness",
    "unsanitariness": "sanitariness",
    "unsatisfactoriness": "satisfactoriness",
    "unscrupulousness": "scrupulousness",
    "unseasonableness": "seasonableness",
    "unsecured bond": "secured bond",
    "unseemliness": "seemliness",
    "unselfconsciousness": "self-consciousness",
    "unskillfulness": "skillfulness",
    "unsnarling": "entangle",
    "unsociability": "sociableness",
    "unsociableness": "sociability",
    "unsolvability": "solvability",
    "unsteadiness": "steadiness",
    "unstratified language": "stratified language",
    "unsuccessful person": "achiever",
    "unsuitability": "suitableness",
    "unsuitableness": "suitability",
    "untangling": "ravel",
    "untidiness": "tidiness",
    "untrustiness": "trustworthiness",
    "untrustworthiness": "trustworthiness",
    "untypicality": "typicality",
    "unusualness": "usualness",
    "unvariedness": "variedness",
    "unwariness": "wariness",
    "unwholesomeness": "wholesomeness",
    "unworthiness": "worthiness",
    "upgrade": "downgrade",
    "upper-case letter": "lowercase",
    "uprising": "sit down",
    "upstager": "downstage",
    "uptick": "downtick",
    "uptime": "downtime",
    "urban area": "rural area",
    "urbanity": "rusticity",
    "usualness": "unusualness",
    "utopia": "dystopia",
    "valgus": "varus",
    "variability": "invariance",
    "variableness": "invariability",
    "variance": "invariability",
    "variedness": "unvariedness",
    "varus": "valgus",
    "venial sin": "mortal sin",
    "verboseness": "terseness",
    "verbosity": "terseness",
    "vermiculation": "anastalsis",
    "vernal equinox": "september equinox",
    "verso": "recto",
    "vitalness": "dispensability",
    "volatile storage": "nonvolatile storage",
    "voltaic cell": "electrolytic cell",
    "wakefulness": "somnolence",
    "wariness": "unwariness",
    "wave theory": "corpuscular theory of light",
    "wave theory of light": "corpuscular theory",
    "waviness": "straightness",
    "weak part": "good part",
    "weak point": "strong suit",
    "weak spot": "good part",
    "welfare": "ill-being",
    "well-being": "ill-being",
    "wellbeing": "ill-being",
    "wester": "east",
    "wet-bulb thermometer": "dry-bulb thermometer",
    "wet-nurse": "bottlefeed",
    "wet fly": "dry fly",
    "whiteness": "blacken",
    "whitening": "blacken",
    "whiting": "blacken",
    "whole milk": "skimmed milk",
    "wholesomeness": "unwholesomeness",
    "wildness": "tameness",
    "winter solstice": "summer solstice",
    "wish": "resent",
    "wishing": "begrudge",
    "withholder": "granter",
    "work day": "rest day",
    "work time": "time off",
    "workday": "rest day",
    "working day": "rest day",
    "worldliness": "spirituality",
    "worthiness": "unworthiness",
    "wrongness": "rightness",
    "yang": "yin",
    "yes": "no",
    "yin": "yang",
    "zip": "unzip",
    "zipper": "unzip",
    "zygodactyl foot": "heterodactyl foot",
    "abduct": "adduct",
    "adjust": "skew",
    "align": "skewed",
    "aline": "skew",
    "alkalify": "acidify",
    "alkalise": "acidify",
    "alkalize": "acidify",
    "ameliorate": "worsen",
    "amend": "worsen",
    "anaesthetise": "bring to",
    "anaesthetize": "bring to",
    "anesthetise": "bring to",
    "anesthetize": "bring to",
    "antecede": "postdate",
    "antedate": "postdate",
    "approbate": "reprobate",
    "arise": "sit down",
    "arouse": "fall asleep",
    "attract": "repel",
    "avouch": "disavow",
    "avow": "disavow",
    "basify": "acidify",
    "be quiet": "open up",
    "beat back": "attract",
    "begrudge": "wish well",
    "behave": "misdemean",
    "belt up": "open up",
    "bestride": "hop out",
    "blacken": "whiten",
    "bottlefeed": "suckle",
    "bottom out": "top out",
    "bounce back": "get worse",
    "breastfeed": "bottlefeed",
    "bring around": "anesthetize",
    "bring back": "anesthetize",
    "bring round": "anesthetize",
    "bring to": "put under",
    "button up": "open up",
    "calcify": "decalcify",
    "carry to term": "miscarry",
    "cast off": "cast on",
    "cast on": "cast off",
    "check in": "check out",
    "check out": "sign in",
    "clam up": "open up",
    "climb on": "hop out",
    "clock in": "punch out",
    "clock off": "clock in",
    "clock on": "clock out",
    "clock out": "punch in",
    "colonise": "decolonize",
    "colonize": "decolonize",
    "come alive": "fall asleep",
    "come up": "go",
    "comport": "misbehave",
    "conform to": "violate",
    "contract in": "contract out",
    "contract out": "contract in",
    "crawl in": "get up",
    "curdle": "homogenize",
    "de-energise": "energize",
    "de-energize": "energize",
    "de-iodinate": "iodinate",
    "de-ionate": "ionate",
    "decalcify": "calcify",
    "deck out": "underdress",
    "deck up": "underdress",
    "decolonise": "colonize",
    "decolonize": "colonize",
    "deconsecrate": "consecrate",
    "degauss": "magnetize",
    "deglycerolise": "glycerolize",
    "deglycerolize": "glycerolize",
    "dehumanise": "humanize",
    "dehumanize": "humanize",
    "dehumidify": "moisturize",
    "dehydrate": "hydrate",
    "dehydrogenate": "hydrogenate",
    "demagnetise": "magnetize",
    "demagnetize": "magnetize",
    "demilitarise": "militarize",
    "demilitarize": "militarize",
    "demulsify": "emulsify",
    "demystify": "mystify",
    "demythologise": "mythologize",
    "demythologize": "mythologize",
    "denationalise": "nationalize",
    "denationalize": "nationalize",
    "denaturalise": "naturalize",
    "denaturalize": "naturalize",
    "denazify": "nazify",
    "denitrify": "nitrify",
    "deodorise": "odorize",
    "deodorize": "odourise",
    "deodourise": "odorize",
    "deoxidise": "oxidize",
    "deoxidize": "oxidize",
    "depersonalise": "personalize",
    "depersonalize": "personalize",
    "depressurise": "pressurize",
    "depressurize": "pressurize",
    "desalinate": "salinate",
    "desalinise": "salinate",
    "desalinize": "salinate",
    "desalt": "salinate",
    "desecrate": "sanctify",
    "desensitise": "sensitize",
    "desensitize": "sensitize",
    "destabilise": "stabilize",
    "destabilize": "stabilize",
    "destalinise": "stalinize",
    "destalinize": "stalinize",
    "dethrone": "throne",
    "detransitivise": "transitivize",
    "detransitivize": "transitivize",
    "devitalise": "vitalize",
    "devitalize": "vitalize",
    "dine in": "eat out",
    "dine out": "eat in",
    "disavow": "avow",
    "disenfranchise": "enfranchise",
    "disentangle": "entangle",
    "disfranchise": "enfranchise",
    "dishearten": "recreate",
    "disincarnate": "incarnate",
    "displease": "delight",
    "dissatisfy": "gratify",
    "disunify": "unify",
    "dope off": "wake up",
    "download": "upload",
    "doze off": "wake up",
    "draw in": "repel",
    "dress down": "dress up",
    "dress up": "dress down",
    "drift off": "wake up",
    "drop off": "wake up",
    "drowse off": "wake up",
    "dry up": "hydrate",
    "dummy up": "open up",
    "eat in": "eat out",
    "eat out": "eat in",
    "embolden": "dishearten",
    "emulsify": "demulsify",
    "enfranchise": "disfranchise",
    "entangle": "straighten out",
    "exsiccate": "hydrate",
    "fall asleep": "come alive",
    "fall short of": "satisfy",
    "famish": "be full",
    "fancy up": "underdress",
    "fig out": "underdress",
    "fig up": "underdress",
    "file in": "file out",
    "file out": "file in",
    "flake out": "wake up",
    "force back": "attract",
    "foredate": "postdate",
    "forego": "postdate",
    "forgo": "postdate",
    "fulfil": "fall short of",
    "fulfill": "fall short of",
    "generalise": "specify",
    "generalize": "specify",
    "get off": "get on",
    "get on": "get off",
    "get over": "get worse",
    "get up": "turn in",
    "get well": "get worse",
    "get worse": "get well",
    "give suck": "bottlefeed",
    "gladden": "sadden",
    "glycerolise": "deglycerolize",
    "glycerolize": "deglycerolize",
    "go against": "conform to",
    "go away": "come",
    "go off": "go on",
    "go to bed": "get up",
    "go to sleep": "get up",
    "gratify": "dissatisfy",
    "gussy up": "underdress",
    "hallow": "desecrate",
    "ham it up": "underact",
    "hand-wash": "machine wash",
    "handwash": "machine wash",
    "hearten": "put off",
    "hit the hay": "get up",
    "hit the sack": "get up",
    "hole up": "estivate",
    "homogenise": "curdle",
    "homogenize": "curdle",
    "hop on": "hop out",
    "hop out": "mount up",
    "humanise": "dehumanize",
    "humanize": "dehumanize",
    "humidify": "dehumidify",
    "hush up": "louden",
    "hydrogenate": "dehydrogenate",
    "improve": "worsen",
    "individualise": "depersonalize",
    "individualize": "depersonalize",
    "inspan": "outspan",
    "intransitivise": "transitivize",
    "intransitivize": "transitivize",
    "iodinate": "de-iodinate",
    "ionate": "de-ionate",
    "jump on": "hop out",
    "keep mum": "open up",
    "keep track": "lose track",
    "kip down": "get up",
    "leave office": "take office",
    "let out": "take in",
    "lie down": "arise",
    "line up": "skew",
    "literalise": "spiritualize",
    "literalize": "spiritualize",
    "live in": "sleep out",
    "live out": "sleep in",
    "live up to": "fall short of",
    "log-in": "log out",
    "log in": "log out",
    "log off": "log in",
    "log on": "log out",
    "log out": "log on",
    "lose track": "keep track",
    "louden": "quieten",
    "machine-wash": "handwash",
    "machine wash": "handwash",
    "magnetise": "demagnetize",
    "magnetize": "demagnetize",
    "mark down": "mark up",
    "mark up": "mark down",
    "melanise": "whiten",
    "melanize": "whiten",
    "meliorate": "worsen",
    "merge": "disunify",
    "militarise": "demilitarize",
    "militarize": "demilitarize",
    "misbehave": "comport",
    "misdemean": "behave",
    "moisturise": "dehumidify",
    "moisturize": "dehumidify",
    "mount up": "hop out",
    "move in": "move out",
    "move out": "move in",
    "mystify": "demystify",
    "mythicise": "demythologize",
    "mythicize": "demythologize",
    "mythologise": "demythologize",
    "mythologize": "demythologize",
    "nationalise": "denationalize",
    "nationalize": "denationalize",
    "naturalise": "denaturalize",
    "naturalize": "denaturalize",
    "nazify": "denazify",
    "nigrify": "whiten",
    "nitrify": "denitrify",
    "nod off": "wake up",
    "objectify": "personalize",
    "occidentalise": "orientalize",
    "occidentalize": "orientalize",
    "odorize": "deodourise",
    "odourise": "deodorize",
    "orientalise": "occidentalize",
    "orientalize": "westernize",
    "outbid": "underbid",
    "outspan": "inspan",
    "overact": "underplay",
    "overclothe": "underdress",
    "overdress": "underdress",
    "overexpose": "underexpose",
    "overplay": "underact",
    "overspend": "underspend",
    "overvalue": "undervalue",
    "oxidate": "deoxidize",
    "oxidise": "deoxidize",
    "oxidize": "deoxidize",
    "particularise": "generalize",
    "particularize": "generalize",
    "personalise": "depersonalize",
    "personalize": "objectify",
    "phase in": "phase out",
    "phase out": "phase in",
    "pipe down": "louden",
    "plug in": "unplug",
    "plug into": "unplug",
    "pop in": "pop out",
    "pop out": "pop in",
    "postdate": "predate",
    "predate": "postdate",
    "pressurise": "depressurize",
    "pressurize": "depressurize",
    "prink": "underdress",
    "pull in": "pull out",
    "pull out": "move in",
    "punch in": "clock out",
    "punch out": "clock in",
    "put off": "hearten",
    "put out": "bring to",
    "put under": "bring to",
    "quiesce": "louden",
    "quiet down": "louden",
    "quieten": "louden",
    "ravel out": "ravel",
    "recreate": "dishearten",
    "repel": "pull in",
    "resent": "wish",
    "resign": "take office",
    "rig out": "underdress",
    "roll up": "unfurl",
    "sack out": "get up",
    "sadden": "gladden",
    "salinate": "desalt",
    "sanctify": "desecrate",
    "satisfy": "fall short of",
    "scale down": "scale up",
    "scale up": "scale down",
    "sensibilise": "desensitize",
    "sensibilize": "desensitize",
    "sensify": "desensitize",
    "sensitise": "desensitize",
    "sensitize": "desensitize",
    "sheathe": "unsheathe",
    "sign in": "check out",
    "sit down": "uprise",
    "sleep in": "live out",
    "sleep out": "live in",
    "slip off": "slip on",
    "slip on": "slip off",
    "smoothen": "roughen",
    "specify": "generalize",
    "spiritualise": "literalize",
    "spiritualize": "literalize",
    "stabilise": "destabilize",
    "stabilize": "destabilize",
    "stalinise": "destalinize",
    "stalinize": "destalinize",
    "stand up": "sit down",
    "step down": "take office",
    "straighten out": "entangle",
    "suckle": "bottlefeed",
    "summerise": "winterize",
    "summerize": "winterize",
    "switch off": "turn on",
    "switch on": "turn out",
    "take office": "step down",
    "talk into": "talk out of",
    "talk out of": "talk into",
    "tog out": "underdress",
    "tog up": "underdress",
    "top out": "bottom out",
    "transitivise": "detransitivize",
    "transitivize": "intransitivize",
    "trick out": "underdress",
    "trick up": "underdress",
    "turn in": "get up",
    "turn off": "switch on",
    "turn on": "switch off",
    "turn out": "switch on",
    "underact": "overplay",
    "underbid": "outbid",
    "underdress": "trick up",
    "underexpose": "overexpose",
    "underplay": "overact",
    "undershoot": "overshoot",
    "underspend": "overspend",
    "undervalue": "overvalue",
    "unfurl": "roll up",
    "unhallow": "consecrate",
    "unhitch": "hitchings",
    "unify": "disunify",
    "unpick": "ravel",
    "unplug": "plug into",
    "unravel": "tangle",
    "unsheathe": "sheathe",
    "unsolder": "sold",
    "unspell": "spelt",
    "untangle": "ravel",
    "unzip": "zip up",
    "upload": "download",
    "uprise": "sit down",
    "violate": "conform to",
    "vitalise": "devitalize",
    "vitalize": "devitalize",
    "westernise": "orientalize",
    "westernize": "orientalize",
    "whiten": "nigrify",
    "winterise": "summerize",
    "winterize": "summerize",
    "wish well": "begrudge",
    "zip up": "unzip",
    "worsen": "meliorate",
    "unappealing": "appealing",
    "heterogenous": "autogenous",
    "uncomplimentary": "complimentary",
    "synchronic": "diachronic",
    "hard": "diffuser",
    "be full": "famish",
    "estivate": "hole up",
    "congruent": "incongruent",
    "unlikely": "likely",
    "all": "no",
    "sparkling": "noneffervescent",
    "syllabic": "unsyllabic",
    "insectivorous": "omnivorous",
    "open up": "keep mum",
    "much": "slight",
    "roughen": "smoothen",
    "nonreversible": "two-sided",
    "best": "worst",
    "gracelessly": "gracefully",
    "consistently": "inconsistently",
    "malignity": "benignity",
    "disarming": "equipping",
    "activeness": "inertia",
    "wideness": "narrowness",
    "niceness": "nastiness",
    "being": "nonbeing",
    "achiever": "unsuccessful person",
    "futurity": "presentness",
    "blow up": "reducing",
    "acidify": "basify",
    "miscarry": "carry to term",
    "energize": "de-energize",
    "enthrone": "dethrone",
    "wake up": "nod off",
    "go on": "go off",
    "take in": "let out",
}
